#
# spec file for package libqt5-qtbase
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt5_snapshot 1
%define journald 1

%ifarch %arm aarch64
%global gles 1
%else
%global gles 0
%endif

%global vulkan 1
%bcond_without harfbuzz

Name:           libqt5-qtbase
Version:        5.15.16+kde130
Release:        1.1
Summary:        C++ Program Library, Core Components
License:        LGPL-3.0-only or GPL-3.0-with-Qt-Company-Qt-exception-1.1
Group:          System/Libraries
Url:            https://www.qt.io
%define base_name libqt5
%define real_version 5.15.16
%define so_version 5.15.16
%define tar_version qtbase-everywhere-src-%{version}
Source:         %{tar_version}.tar.xz
# to get mtime of file:
Source1:        libqt5-qtbase.changes
Source2:        macros.qt5
Source3:        baselibs.conf
Source4:        qtlogging.ini
Source99:       libqt5-qtbase-rpmlintrc
# patches 0-999 are openSUSE and/or non-upstream(able) patches #
Patch1:         0001-Revert-QGnomeTheme-Allow-Space-Return-Enter-and-Sele.patch
Patch2:         big-endian-scroll.patch
Patch3:         0001-Revert-QMenu-hide-when-a-QWidgetAction-fires-the-tri.patch
# Proposed: https://bugreports.qt.io/browse/QTBUG-88491
Patch4:         0001-Avoid-SIGABRT-on-platform-plugin-initialization-fail.patch
# PATCH-FIX-OPENSUSE disable-rc4-ciphers-bnc865241.diff bnc#865241-- Exclude rc4 ciphers from being used by default
Patch6:         disable-rc4-ciphers-bnc865241.diff
Patch8:         tell-the-truth-about-private-api.patch
# PATCH-FIX-OPENSUSE libqt5-prioritise-gtk2-platformtheme.patch boo#1002900 -- Give Gtk2 Platform Theme (from qtstyleplugins) a priority over Gtk3 PT which currently lacks QGtk3Style.
Patch10:        libqt5-prioritise-gtk2-platformtheme.patch
# PATCH-FEATURE-OPENSUSE 0001-Add-remote-print-queue-support.patch fate#322052 -- Automatically recognize and allow printing to remote cups servers
Patch12:        0001-Add-remote-print-queue-support.patch
# PATCH-FIX-OPENSUSE
Patch21:        0001-Don-t-white-list-recent-Mesa-versions-for-multithrea.patch
Patch24:        fix-fixqt4headers.patch
# patches 1000-2000 and above from upstream 5.15 branch #
# patches 2000-3000 and above from upstream qt6/dev branch #
# Not accepted yet, https://codereview.qt-project.org/c/qt/qtbase/+/255384
Patch2001:      0002-Synthesize-Enter-LeaveEvent-for-accepted-QTabletEven.patch
BuildRequires:  cups-devel
BuildRequires:  double-conversion-devel
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  libmysqlclient-devel
BuildRequires:  libpng-devel
BuildRequires:  libproxy-devel
BuildRequires:  lksctp-tools-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(mtdev)
%if %qt5_snapshot
#to create the forwarding headers
BuildRequires:  perl
%endif
BuildRequires:  postgresql-devel
BuildRequires:  sqlite3-devel
BuildRequires:  unixODBC-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
%if %gles
BuildRequires:  Mesa-libGLESv3-devel
BuildRequires:  pkgconfig(glesv2)
%endif
BuildRequires:  pkgconfig(icu-i18n)
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  tslib-devel
%if %{vulkan}
BuildRequires:  vulkan-devel
%endif

BuildRequires:  pkgconfig(pango)
# Not packaged yet
#BuildRequires:  pkgconfig(md4c)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(xcb-randr)
BuildRequires:  pkgconfig(xcb-renderutil)
BuildRequires:  pkgconfig(xcb-render)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-shm)
BuildRequires:  pkgconfig(xcb-sync)
BuildRequires:  pkgconfig(xcb-util)
BuildRequires:  pkgconfig(xcb-xfixes)
BuildRequires:  pkgconfig(xcb-xinerama)
BuildRequires:  pkgconfig(xcb-xkb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-glx)
BuildRequires:  pkgconfig(xcb-image)
BuildRequires:  pkgconfig(xcb-icccm)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  xz
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
%if %{with harfbuzz}
BuildRequires:  pkgconfig(harfbuzz)
%endif
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(libinput)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xkbcommon) >= 0.4.1
BuildRequires:  pkgconfig(xkbcommon-x11) >= 0.4.1
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(libzstd)
%if %journald
BuildRequires:  pkgconfig(libsystemd)
%endif
# to get cmake(...) autoprovides
BuildRequires:  cmake

%description
Qt is a set of libraries for developing applications.

This package contains base tools, like string, xml, and network
handling.

%define libqt5_prefix		%{_prefix}
%define libqt5_libdir		%{_libdir}
%define libqt5_archdatadir	%{_libdir}/qt5
%define libqt5_bindir		%{libqt5_archdatadir}/bin
%define libqt5_datadir		%{_datadir}/qt5
%define libqt5_docdir		%{_docdir}/qt5
%define libqt5_examplesdir	%{libqt5_archdatadir}/examples
%define libqt5_includedir	%{_includedir}/qt5
%define libqt5_importdir	%{libqt5_archdatadir}/imports
%define libqt5_libexecdir	%{_libexecdir}/qt5
%define libqt5_plugindir	%{libqt5_archdatadir}/plugins
%define libqt5_sysconfdir	%{_sysconfdir}/xdg
%define libqt5_translationdir	%{libqt5_datadir}/translations

%prep
%autosetup -p1 -n %{tar_version}

# be sure not to use them
rm -rf src/3rdparty/{libjpeg,freetype,zlib}

%package devel
Summary:        Development files for the Qt5 base library
Group:          Development/Libraries/X11
# External deps shall be found via pkgconfig
Requires:       %{name}-common-devel
Requires:       libQt5Concurrent-devel = %{version}
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5DBus-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       libQt5Network-devel = %{version}
Requires:       libQt5OpenGL-devel = %{version}
Requires:       libQt5PlatformHeaders-devel = %{version}
Requires:       libQt5PrintSupport-devel = %{version}
Requires:       libQt5Sql-devel = %{version}
Requires:       libQt5Test-devel = %{version}
Requires:       libQt5Widgets-devel = %{version}
Requires:       libQt5Xml-devel = %{version}

%description devel
You need this package if you want to compile programs with Qt. It
contains the "Qt Crossplatform Development Kit". It does contain
include files and development applications like GUI designers,
translator tools and code generators.

%package common-devel
Summary:        Qt 5 Core Development Binaries
Group:          Development/Libraries/X11
Requires:       gcc-c++
Requires:       pkg-config
# to get cmake(...) autoprovides
Requires:       cmake

%description common-devel
Qt 5 Core Development Binaries. It contains Qt5's moc, qmake,
rcc, uic and syncqt.pl binaries.

%package -n libQt5Core5
Summary:        Qt 5 Core Library
Group:          Development/Libraries/X11
Provides:       libqt5-qtbase = %{version}
Obsoletes:      libqt5-qtbase < %{version}
Recommends:     libqt5-qttranslations

%description -n libQt5Core5
The Qt 5 Core library. It adds these features to C++:

* a mechanism for object communication called signals and slots
* queryable and designable object properties
* hierarchical and queryable object trees that organize
* object ownership in a natural way with guarded pointers (QPointer)
* a dynamic cast that works across library boundaries

%package -n libQt5Core-devel
Summary:        Development files for the Qt5 core library
Group:          Development/Libraries/X11
Requires:       %{name}-common-devel = %{version}
Requires:       libQt5Core5 = %{version}

%description -n libQt5Core-devel
Development files for the Qt5 core library.

%package -n libQt5Core-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 core library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-devel = %{version}

%description -n libQt5Core-private-headers-devel
This package provides private headers of libQt5Core that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5Concurrent5
Summary:        Qt 5 Concurrent Library
Group:          Development/Libraries/X11
Requires:       libQt5Core5 = %{version}

%description -n libQt5Concurrent5
The QtConcurrent namespace provides high-level APIs that help write
multi-threaded programs without using low-level threading primitives
such as mutexes, read-write locks, wait conditions, or semaphores.
Programs written with QtConcurrent automatically adjust the number of
threads used according to the number of processor cores available.

QtConcurrent includes functional programming style APIs for parallel
list processing, including a MapReduce and FilterReduce
implementation for shared-memory (non-distributed) systems, and
classes for managing asynchronous computations in GUI applications.

%package -n libQt5Concurrent-devel
Summary:        Development files for the Qt5 Concurrent library
Group:          Development/Libraries/X11
Requires:       libQt5Concurrent5 = %{version}
Requires:       libQt5Core-devel = %{version}

%description -n libQt5Concurrent-devel
Development files for the Qt5 Concurrent library.

%package -n libQt5DBus5
Summary:        Qt5 D-Bus library
Group:          Development/Libraries/X11
Requires:       libQt5Core5 = %{version}

%description -n libQt5DBus5
The Qt D-Bus module is a library that can be used to perform
inter-process communication using the D-Bus protocol.

%package -n libQt5DBus-devel
Summary:        Development files for the Qt5 D-Bus library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5DBus5 = %{version}

%description -n libQt5DBus-devel
Development files for the Qt5 D-Bus library. This package also
contains Qt5's qdbusxml2cpp and qdbuscpp2xml binaries.

%package -n libQt5DBus-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 D-Bus library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5DBus-devel = %{version}

%description -n libQt5DBus-private-headers-devel
This package provides private headers of libQt5DBus that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5Network5
Summary:        Qt 5 Network Library
Group:          Development/Libraries/X11
Requires:       libQt5Core5 = %{version}
Requires:       libQt5DBus5 = %{version}

%description -n libQt5Network5
Qt Network provides a set of APIs for programming applications that
use TCP/IP. Operations such as requests, cookies, and sending data
over HTTP are handled by various C++ classes.

%package -n libQt5Network-devel
Summary:        Development files for the Qt5 network library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Network5 = %{version}

%description -n libQt5Network-devel
Development files for the Qt5 network library.

%package -n libQt5Network-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 network library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Network-devel = %{version}

%description -n libQt5Network-private-headers-devel
This package provides private headers of libQt5Network that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5OpenGL5
Summary:        Qt 5 OpenGL Library
Group:          Development/Libraries/X11
Requires:       libQt5Widgets5 = %{version}

%description -n libQt5OpenGL5
The Qt OpenGL module provides an OpenGL widget class that can be used
like any other Qt widget, except that it opens an OpenGL display
buffer where the OpenGL API can be used to render the contents.

%package -n libQt5OpenGL-devel
Summary:        Development files for the Qt5 OpenGL library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       libQt5OpenGL5 = %{version}
Requires:       libQt5Widgets-devel = %{version}
%if %gles
Requires:       Mesa-libGLESv3-devel
Requires:       pkgconfig(glesv2)
%else
Requires:       pkgconfig(gl)
%endif

%description -n libQt5OpenGL-devel
Development files for the Qt5 OpenGL library.

Warning: This module should not be used anymore for new code. Please
use the corresponding OpenGL classes in Qt GUI.

%package -n libQt5OpenGL-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 OpenGL library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5OpenGL-devel = %{version}
Requires:       libQt5Widgets-private-headers-devel = %{version}

%description -n libQt5OpenGL-private-headers-devel
This package provides private headers of libQt5OpenGL that are
normally not used by application development and that do not have any
ABI or API guarantees. The packages that build against these have to
require the exact Qt version.

%package -n libQt5PrintSupport5
Summary:        Qt 5 Print Support Library
Group:          Development/Libraries/X11
Requires:       libQt5Widgets5 = %{version}

%description -n libQt5PrintSupport5
An abstraction over the platform-specific printing systems. Using
this library, Qt applications can print to attached printers and
across networks to remote printers. Qt's printing system also
supports PDF file generation, providing the foundation for basic
report generation facilities.

%package -n libQt5PrintSupport-devel
Summary:        Development files for the Qt5 print support library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       libQt5PrintSupport5 = %{version}
Requires:       libQt5Widgets-devel = %{version}

%description -n libQt5PrintSupport-devel
Development files for the Qt5 print support library.

%package -n libQt5PrintSupport-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 print support library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5PrintSupport-devel = %{version}
Requires:       libQt5Widgets-private-headers-devel = %{version}
# Includes <cups/ppd.h> in qprint_p.h
Requires:       cups-devel

%description -n libQt5PrintSupport-private-headers-devel
This package provides private headers of libQt5PrintSupport that are
normally not used by application development and that do not have any
ABI or API guarantees. The packages that build against these have to
require the exact Qt version.

%package -n libQt5Xml5
Summary:        Qt 5 Xml Library
Group:          Development/Libraries/X11
Requires:       libQt5Core5 = %{version}

%description -n libQt5Xml5
The Qt XML module provides C++ implementations of the SAX and DOM
standards for XML.

%package -n libQt5Xml-devel
Summary:        Development files for the Qt5 XML library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Xml5 = %{version}

%description -n libQt5Xml-devel
Development files for the Qt5 XML library.

(The module is not actively maintained anymore. Please use the
QXmlStreamReader and QXmlStreamWriter classes in Qt Core instead.)

%package -n libQt5Test5
Summary:        Qt 5 Test Library
Group:          Development/Libraries/X11
Requires:       libQt5Core5 = %{version}

%description -n libQt5Test5
Qt Test is a framework for unit testing Qt based applications and
libraries. Qt Test provides functionality commonly found in unit
testing frameworks as well as extensions for testing graphical user
interfaces.

%package -n libQt5Test-devel
Summary:        Development files for the Qt5 testing library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Test5 = %{version}

%description -n libQt5Test-devel
Development files for the Qt5 testing library.

%package -n libQt5Test-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 test library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Test-devel = %{version}

%description -n libQt5Test-private-headers-devel
This package provides private headers of libQt5Test that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5Widgets5
Summary:        Qt 5 Widgets Library
Group:          Development/Libraries/X11
Requires:       libQt5Gui5 = %{version}

%description -n libQt5Widgets5
The Qt Widgets Module provides a set of UI elements to create classic
desktop-style user interfaces.

%package -n libQt5Widgets-devel
Summary:        Development files for the Qt5 widgets library
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       libQt5Widgets5 = %{version}

%description -n libQt5Widgets-devel
Development files for the Qt5 widgets library.

%package -n libQt5Widgets-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 widgets library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5Widgets-devel = %{version}

%description -n libQt5Widgets-private-headers-devel
This package provides private headers of libQt5Widgets that are
normally not used by application development and that do not have any
ABI or API guarantees. The packages that build against these have to
require the exact Qt version.

%package -n libQt5Sql5-sqlite
Summary:        Qt 5 sqlite plugin
Group:          Development/Libraries/C and C++
Requires:       libQt5Sql5 = %{version}
Provides:       libqt5-sql-sqlite = %{version}
Provides:       libqt5_sql_backend = %{version}
Obsoletes:      libqt5-sql-sqlite < %{version}

%description -n libQt5Sql5-sqlite
The Qt SQL module uses driver plugins to communicate with the
different database APIs.

The Qt SQLite plugin makes it possible to access SQLite databases.
SQLite is an in-process database, which means that it is not
necessary to have a database server. SQLite operates on a single
file, which must be set as the database name when opening a
connection.

%package -n libQt5Sql5-unixODBC
Summary:        Qt 5 unixODBC plugin
Group:          Development/Libraries/C and C++
Requires:       libQt5Sql5 = %{version}
Provides:       libqt5-sql-unixODBC = %{version}
Provides:       libqt5_sql_backend = %{version}
Obsoletes:      libqt5-sql-unixODBC < %{version}

%description -n libQt5Sql5-unixODBC
The Qt SQL module uses driver plugins to communicate with the
different database APIs.

The QODBC driver allows to connect to an ODBC driver manager and
access the available data sources. Note that you also need to install
and configure ODBC drivers for the ODBC driver manager that is
installed on your system.

%package -n libQt5Sql5-postgresql
Summary:        Qt 5 PostgreSQL plugin
Group:          Development/Libraries/C and C++
Requires:       libQt5Sql5 = %{version}
Provides:       libqt5-sql-postgresql = %{version}
Provides:       libqt5_sql_backend = %{version}
Obsoletes:      libqt5-sql-postgresql < %{version}

%description -n libQt5Sql5-postgresql
The Qt SQL module uses driver plugins to communicate with the
different database APIs.

The QPSQL driver supports version 7.3 and higher of the PostgreSQL
server.

%package -n libQt5Sql5-mysql
Summary:        Qt 5 MySQL support
Group:          Development/Libraries/C and C++
Requires:       libQt5Sql5 = %{version}
Provides:       libqt5-sql-mysql = %{version}
Provides:       libqt5_sql_backend = %{version}
Obsoletes:      libqt5-sql-mysql < %{version}

%description -n libQt5Sql5-mysql
A plugin to support MySQL server in Qt applications.

%package -n libQt5Gui5
Summary:        Qt 5 GUI related libraries
Group:          Development/Libraries/C and C++
Recommends:     libqt5-qtimageformats = %{version}
Requires:       libQt5Core5 = %{version}
Requires:       libQt5DBus5 = %{version}
Provides:       libqt5-qtbase-platformtheme-gtk2 = %{version}
Obsoletes:      libqt5-qtbase-platformtheme-gtk2 < %{version}

%description -n libQt5Gui5
The Qt GUI module provides classes for windowing system integration,
event handling, OpenGL and OpenGL ES integration, 2D graphics, basic
imaging, fonts and text. These classes are used internally by Qt's
user interface code and can also be used directly, for instance, to
write applications using low-level OpenGL ES graphics APIs.

For application developers writing user interfaces, Qt provides
higher level APIs, like Qt Quick, which are much more suitable than
the enablers found in the Qt GUI module.

%package platformtheme-gtk3
Summary:        Qt 5 gtk3 plugin
Group:          Development/Libraries/C and C++
Supplements:    packageand(libQt5Gui5:libgtk-3-0)
Requires:       libQt5Gui5 = %{version}

%description platformtheme-gtk3
Qt 5 plugin for better integration with gtk3-based desktop enviroments.

%package platformtheme-xdgdesktopportal
Summary:        Qt 5 XDG Desktop Portal Plugin
Group:          Development/Libraries/C and C++
Requires:       libQt5Gui5 = %{version}
Obsoletes:      %{name}-platformtheme-flatpak < %{version}
Provides:       %{name}-platformtheme-flatpak = %{version}

%description platformtheme-xdgdesktopportal
Qt 5 plugin for integration with flatpak and snap.

%package -n libQt5Gui-devel
Summary:        Development files for the Qt5 GUI library
Group:          Development/Libraries/C and C++
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui5 = %{version}
%if %gles
Requires:       Mesa-libGLESv3-devel
Requires:       pkgconfig(gbm)
Requires:       pkgconfig(glesv2)
%else
Requires:       pkgconfig(gl)
%endif
%if %{vulkan}
Requires:       vulkan-devel
%endif
Requires:       pkgconfig(egl)
Requires:       pkgconfig(libdrm)

%description -n libQt5Gui-devel
Development files for the Qt5 GUI library.

%package -n libQt5Gui-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 GUI library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-devel = %{version}

%description -n libQt5Gui-private-headers-devel
This package provides private headers of libQt5Gui that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5Sql5
Summary:        Qt 5 SQL related libraries
Group:          Development/Libraries/C and C++
Recommends:     libqt5_sql_backend = %{version}
Suggests:       libqt5-sql-sqlite
Requires:       libQt5Core5 = %{version}

%description -n libQt5Sql5
Qt 5 libraries which are used for connection with an SQL server. You
will need also a plugin package for a supported SQL server.

%package -n libQt5Sql-devel
Summary:        Development files for the Qt5 SQL library
Group:          Development/Libraries/C and C++
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Sql5 = %{version}
Suggests:       libQt5Sql5-mysql = %{version}
Suggests:       libQt5Sql5-postgresql = %{version}
Suggests:       libQt5Sql5-sqlite = %{version}
Suggests:       libQt5Sql5-unixODBC = %{version}

%description -n libQt5Sql-devel
Qt 5 libraries which are used for connection with an SQL server. You
will need also a plugin package for a supported SQL server.

%package -n libQt5Sql-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 SQL library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Sql-devel = %{version}

%description -n libQt5Sql-private-headers-devel
This package provides private headers of libQt5Sql that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package private-headers-devel
Summary:        Non-ABI stable experimental API
Group:          Development/Libraries/C and C++
BuildArch:      noarch
Requires:       %{name}-devel = %{version}
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5DBus-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5KmsSupport-private-headers-devel = %{version}
Requires:       libQt5Network-private-headers-devel = %{version}
Requires:       libQt5OpenGL-private-headers-devel = %{version}
Requires:       libQt5PlatformSupport-private-headers-devel = %{version}
Requires:       libQt5PrintSupport-private-headers-devel = %{version}
Requires:       libQt5Sql-private-headers-devel = %{version}
Requires:       libQt5Test-private-headers-devel = %{version}
Requires:       libQt5Widgets-private-headers-devel = %{version}

%description private-headers-devel
This package provides private headers of libqt5-qtbase-devel that are normally
not used by application development and that do not have any ABI or
API guarantees. The packages that build against these have to require
the exact Qt version.

%package -n libQt5Bootstrap-devel-static
Summary:        Qt Bootstrap module
Group:          Development/Libraries/C and C++
Requires:       %{name}-common-devel = %{version}

%description -n libQt5Bootstrap-devel-static
Qt Bootstrap module.

%package -n libQt5OpenGLExtensions-devel-static
Summary:        Qt OpenGLExtensions module
Group:          Development/Libraries/C and C++
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
# List the below ones manually - they are private, but this is a static lib
Requires:       pkgconfig(gl)

%description -n libQt5OpenGLExtensions-devel-static
Qt OpenGLExtensions module.

%package -n libQt5PlatformSupport-devel-static
Summary:        Qt PlatformSupport module
Group:          Development/Libraries/C and C++
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       libQt5PlatformHeaders-devel = %{version}
# List the below ones manually - they are private, but this is a static lib
Requires:       tslib-devel
Requires:       pkgconfig(Qt5DBus)
Requires:       pkgconfig(egl)
Requires:       pkgconfig(fontconfig)
Requires:       pkgconfig(freetype2)
Requires:       pkgconfig(gl)
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(libinput)
Requires:       pkgconfig(libudev)
Requires:       pkgconfig(mtdev)
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xext)
Requires:       pkgconfig(xkbcommon) >= 0.4.1
Requires:       pkgconfig(xkbcommon-x11) >= 0.4.1
Requires:       pkgconfig(xrender)

%description -n libQt5PlatformSupport-devel-static
Qt PlatformSupport module.

%package -n libQt5PlatformSupport-private-headers-devel
Summary:        Non-ABI stable experimental API for the  Qt5 platform support library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5PlatformSupport-devel-static = %{version}

%description -n libQt5PlatformSupport-private-headers-devel
This package provides private headers of libQt5PlatformSupport that
are normally not used by application development and that do not have
any ABI or API guarantees. The packages that build against these have
to require the exact Qt version.

%package -n libQt5KmsSupport-devel-static
Summary:        Qt KMS support module
Group:          Development/Libraries/X11
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}

%description -n libQt5KmsSupport-devel-static
Qt module to support Kernel Mode Setting.

%package -n libQt5KmsSupport-private-headers-devel
Summary:        Non-ABI stable experimental API for the Qt5 KMS support library
Group:          Development/Libraries/X11
BuildArch:      noarch
Requires:       libQt5Core-private-headers-devel = %{version}
Requires:       libQt5Gui-private-headers-devel = %{version}
Requires:       libQt5KmsSupport-devel-static = %{version}

%description -n libQt5KmsSupport-private-headers-devel
This package provides private headers of libQt5KmsSupport that are
normally not used by application development and that do not have any
ABI or API guarantees. The packages that build against these have to
require the exact Qt version.

%package -n libQt5PlatformHeaders-devel
Summary:        Qt 5 PlatformHeaders
Group:          Development/Libraries/X11
# NOTE this needs to be checked on every update - package provides only a low number of headers, so check which 3rd party, or other qtbase includes are used
Requires:       libQt5Core-devel = %{version}
Requires:       libQt5Gui-devel = %{version}
Requires:       pkgconfig(egl)
Requires:       pkgconfig(x11)
%if %gles
Requires:       Mesa-libGLESv3-devel
Requires:       pkgconfig(glesv2)
%else
Requires:       pkgconfig(gl)
%endif

%description -n libQt5PlatformHeaders-devel
Qt 5 PlatformHeaders.

%package examples
Summary:        Qt5 base examples
Group:          Development/Libraries/X11
Recommends:     libqt5-qtbase-devel

%description examples
Examples for the libqt5-qtbase modules.

%build
%define _lto_cflags %{nil}
%ifarch ppc64
  RPM_OPT_FLAGS="%{optflags} -mminimal-toc"
%endif
export CXXFLAGS="$CXXFLAGS %{optflags} -DOPENSSL_LOAD_CONF"
export CFLAGS="$CFLAGS %{optflags} -DOPENSSL_LOAD_CONF"
export MAKEFLAGS="%{?_smp_mflags}"
%define xkbconfigroot %(pkg-config --variable=xkb_base xkeyboard-config)
#if %qt5_snapshot
#force the configure script to generate the forwarding headers (it checks whether .git directory exists)
mkdir .git
#endif
# Record mtime of changes file instead of build time
export CHANGES=`stat --format="%y" %{SOURCE1}|cut --characters=1-10`
sed -i 's|qt_instdate=`date +%Y-%m-%d`|qt_instdate=$CHANGES|g' configure
# so non-qt5 apps/libs don't get stripped
sed -i -e 's|^\(QMAKE_STRIP.*=\).*$|\1|g' mkspecs/common/linux.conf

# -no-feature-relocatable is needed to support /usr/lib/sse2 etc., see QTBUG-78948
# -reduce-relocations means copy relocations aren't allowed, and so special
# flags like -fPIC need to be passed when building an application. This breaks
# with LTO (PIE overrides that) and CMake (doesn't pass -fPIC when linking).
# Due to a binutils bug/misunderstanding, this option didn't do as much before 2.35,
# so just disable it for now until a proper alternative appears.

./configure \
	-prefix %{_prefix} \
	-L %{libqt5_libdir} \
	-libdir %{libqt5_libdir} \
	-archdatadir %{libqt5_archdatadir} \
	-bindir %{libqt5_bindir} \
	-datadir %{libqt5_datadir} \
	-docdir %{libqt5_docdir} \
	-examplesdir %{libqt5_examplesdir} \
	-headerdir %{libqt5_includedir} \
	-importdir %{libqt5_importdir} \
	-libexecdir %{libqt5_libexecdir} \
	-plugindir %{libqt5_plugindir} \
	-sysconfdir %{libqt5_sysconfdir} \
	-translationdir %{libqt5_translationdir} \
	-verbose \
	-no-reduce-relocations \
	-accessibility \
	-no-strip \
	-opensource \
	-confirm-license \
	-no-separate-debug-info \
	-force-debug-info \
	-shared \
	-xkbcommon \
	-no-bundled-xcb-xinput \
	-dbus-linked \
	-sm \
	-no-rpath \
	-system-libjpeg \
	-openssl-linked \
	-system-libpng \
%if %{with harfbuzz}
	-system-harfbuzz \
%endif
	-fontconfig \
	-system-freetype \
	-cups \
	-system-zlib \
	-zstd \
	-no-pch \
	-glib \
	-sctp \
	-system-sqlite \
%if %journald
	-journald \
%endif
	-libproxy \
	-xcb \
	-egl \
	-eglfs \
%if %gles
	-kms \
	-opengl es2 \
%else
	-opengl desktop \
%endif
	-release \
	-plugin-sql-sqlite -nomake tests \
	-plugin-sql-psql -I/usr/include/pgsql/ -I/usr/include/pgsql/server \
	-plugin-sql-odbc \
	-plugin-sql-mysql -I/usr/include/mysql/ \
	-xcb-native-painting \
	-no-feature-relocatable \
	QMAKE_CFLAGS+="$CFLAGS" \
	QMAKE_CXXFLAGS+="$CXXFLAGS"

make %{?_smp_mflags}

%install
make INSTALL_ROOT=%{buildroot} install

install -D -m644 %{SOURCE2} %{buildroot}%{_rpmconfigdir}/macros.d/macros.qt5
# argggh, qmake is such a piece of <censored>
find %{buildroot}%{libqt5_libdir} -type f -name '*prl' -exec perl -pi -e "s, -L$RPM_BUILD_DIR/\S+,,g" {} +
find %{buildroot}%{libqt5_libdir} -type f -name '*prl' -exec sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" {} +
find %{buildroot}%{libqt5_libdir} -type f -name '*la' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} +
# insanity ...
find %{buildroot}%{libqt5_libdir} -type f -name '*pc' -print -exec perl -pi -e "s, -L$RPM_BUILD_DIR/?\S+,,g" {} + -exec sed -i -e "s,^moc_location=.*,moc_location=%libqt5_bindir/moc," -e "s,uic_location=.*,uic_location=%libqt5_bindir/uic," {} +
find %{buildroot}%{libqt5_libdir}/ -name 'lib*.a' -exec chmod -x -- {} +
# kill .la files
rm -fv %{buildroot}%{libqt5_libdir}/lib*.la

# Not sure why these are deleted, but apparently we don't need them?
rm -fv %{buildroot}%{libqt5_libdir}/cmake/Qt5*/Q*Plugin.cmake

# This is only for Apple platforms and has a python2 dep
rm -r %{buildroot}%{libqt5_archdatadir}/mkspecs/features/uikit

# Link all the binaries with -qt5 suffix to %{_bindir}
mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{libqt5_bindir}
for i in * ; do
  case "${i}" in
    moc|qdbuscpp2xml|qdbusxml2cpp|qmake|rcc|syncqt|uic)
      ln -s %{libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}-qt5
      ;;
   *)
      # No conflict with Qt4, so keep the original name for compatibility
      ln -s %{libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}-qt5
      ln -s %{libqt5_bindir}/$i %{buildroot}%{_bindir}/${i}
      ;;
  esac
done
popd

chmod 644 %{buildroot}%{libqt5_docdir}/global/template/images/*.png

# Silence logging of xcb errors and qml deprecated connection
# warnings by default
install -Dm644 %{SOURCE4} %{buildroot}%{libqt5_datadir}/qtlogging.ini

%post -n libQt5Core5 -p /sbin/ldconfig

%post -n libQt5Concurrent5 -p /sbin/ldconfig

%post -n libQt5DBus5 -p /sbin/ldconfig

%post -n libQt5Network5 -p /sbin/ldconfig

%post -n libQt5OpenGL5 -p /sbin/ldconfig

%post -n libQt5PrintSupport5 -p /sbin/ldconfig

%post -n libQt5Xml5 -p /sbin/ldconfig

%post -n libQt5Gui5 -p /sbin/ldconfig

%post -n libQt5Sql5 -p /sbin/ldconfig

%post -n libQt5Test5 -p /sbin/ldconfig

%post -n libQt5Widgets5 -p /sbin/ldconfig

%postun -n libQt5Core5 -p /sbin/ldconfig

%postun -n libQt5Concurrent5 -p /sbin/ldconfig

%postun -n libQt5DBus5 -p /sbin/ldconfig

%postun -n libQt5Network5 -p /sbin/ldconfig

%postun -n libQt5OpenGL5 -p /sbin/ldconfig

%postun -n libQt5PrintSupport5 -p /sbin/ldconfig

%postun -n libQt5Xml5 -p /sbin/ldconfig

%postun -n libQt5Gui5 -p /sbin/ldconfig

%postun -n libQt5Sql5 -p /sbin/ldconfig

%postun -n libQt5Test5 -p /sbin/ldconfig

%postun -n libQt5Widgets5 -p /sbin/ldconfig

%files common-devel
%license LICENSE.*
%doc *.txt
%{_rpmconfigdir}/macros.d/macros.qt5
%{_bindir}/moc*
%{libqt5_bindir}/moc*
%{_bindir}/qmake*
%{libqt5_bindir}/qmake*
%{_bindir}/rcc*
%{libqt5_bindir}/rcc*
%{_bindir}/uic*
%{libqt5_bindir}/uic*
%{_bindir}/qvkgen*
%{libqt5_bindir}/qvkgen*
%{_bindir}/tracegen*
%{libqt5_bindir}/tracegen*
%{_bindir}/syncqt.pl*
%{_bindir}/fixqt4headers.pl*
%{libqt5_bindir}/syncqt.pl*
%{libqt5_bindir}/fixqt4headers.pl*
%{_bindir}/qlalr*
%{libqt5_bindir}/qlalr*
%{libqt5_archdatadir}/mkspecs/
%dir %{libqt5_libdir}/cmake
%dir %{libqt5_includedir}
%dir %{libqt5_archdatadir}
%dir %{libqt5_bindir}

%files -n libQt5Core5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Core.so.*
%dir %{libqt5_datadir}
%{libqt5_datadir}/qtlogging.ini

%files -n libQt5Core-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Core.so
%{libqt5_libdir}/libQt5Core.prl
%{libqt5_libdir}/cmake/Qt5Core/
%{libqt5_libdir}/cmake/Qt5/
%{libqt5_libdir}/pkgconfig/Qt5Core.pc
%{libqt5_includedir}/QtCore/
%dir %{libqt5_libdir}/metatypes/
%{libqt5_libdir}/metatypes/qt5core_metatypes.json
%exclude %{libqt5_includedir}/QtCore/%{so_version}
%{libqt5_docdir}

%files -n libQt5Concurrent5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Concurrent.so.*

%files -n libQt5Concurrent-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Concurrent.so
%{libqt5_libdir}/libQt5Concurrent.prl
%{libqt5_libdir}/cmake/Qt5Concurrent/
%{libqt5_libdir}/pkgconfig/Qt5Concurrent.pc
%{libqt5_includedir}/QtConcurrent/

%files -n libQt5DBus5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5DBus.so.*

%files -n libQt5DBus-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5DBus.so
%{libqt5_libdir}/libQt5DBus.prl
%{libqt5_libdir}/cmake/Qt5DBus/
%{libqt5_libdir}/pkgconfig/Qt5DBus.pc
%{libqt5_includedir}/QtDBus/
%exclude %{libqt5_includedir}/QtDBus/%{so_version}
%{libqt5_bindir}/qdbusxml2cpp*
%{_bindir}/qdbusxml2cpp*
%{libqt5_bindir}/qdbuscpp2xml*
%{_bindir}/qdbuscpp2xml*

%files -n libQt5Network5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Network.so.*
%dir %{libqt5_libdir}/qt5
%dir %{libqt5_plugindir}
%{libqt5_plugindir}/bearer

%files -n libQt5Network-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Network.so
%{libqt5_libdir}/libQt5Network.prl
%{libqt5_libdir}/cmake/Qt5Network/
%{libqt5_libdir}/pkgconfig/Qt5Network.pc
%{libqt5_includedir}/QtNetwork/
%exclude %{libqt5_includedir}/QtNetwork/%{so_version}

%files -n libQt5OpenGL5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5OpenGL.so.*

%files -n libQt5OpenGL-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5OpenGL.so
%{libqt5_libdir}/libQt5OpenGL.prl
%{libqt5_libdir}/cmake/Qt5OpenGL/
%{libqt5_libdir}/pkgconfig/Qt5OpenGL.pc
%{libqt5_includedir}/QtOpenGL/
%exclude %{libqt5_includedir}/QtOpenGL/%{so_version}

%files -n libQt5PrintSupport5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5PrintSupport.so.*
%{libqt5_plugindir}/printsupport

%files -n libQt5PrintSupport-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5PrintSupport.so
%{libqt5_libdir}/libQt5PrintSupport.prl
%{libqt5_libdir}/cmake/Qt5PrintSupport/
%{libqt5_libdir}/pkgconfig/Qt5PrintSupport.pc
%{libqt5_includedir}/QtPrintSupport/
%exclude %{libqt5_includedir}/QtPrintSupport/%{so_version}

%files -n libQt5Xml5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Xml.so.*

%files -n libQt5Xml-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Xml.so
%{libqt5_libdir}/libQt5Xml.prl
%{libqt5_libdir}/cmake/Qt5Xml/
%{libqt5_libdir}/pkgconfig/Qt5Xml.pc
%{libqt5_includedir}/QtXml/

%files -n libQt5Test5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Test.so.*

%files -n libQt5Test-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Test.so
%{libqt5_libdir}/libQt5Test.prl
%{libqt5_libdir}/cmake/Qt5Test/
%{libqt5_libdir}/pkgconfig/Qt5Test.pc
%{libqt5_includedir}/QtTest/
%exclude %{libqt5_includedir}/QtTest/%{so_version}

%files -n libQt5Widgets5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Widgets.so.*

%files -n libQt5Widgets-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Widgets.so
%{libqt5_libdir}/libQt5Widgets.prl
%{libqt5_libdir}/cmake/Qt5Widgets/
%{libqt5_libdir}/pkgconfig/Qt5Widgets.pc
%{libqt5_includedir}/QtWidgets/
%{libqt5_libdir}/metatypes/qt5widgets_metatypes.json
%exclude %{libqt5_includedir}/QtWidgets/%{so_version}

%files -n libQt5Gui5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Gui.so.*
%{libqt5_libdir}/libQt5EglFSDeviceIntegration.so.*
%{libqt5_libdir}/libQt5EglFsKmsSupport.so.*
%{libqt5_libdir}/libQt5XcbQpa.so.*
%{libqt5_plugindir}/generic
%{libqt5_plugindir}/imageformats
%{libqt5_plugindir}/platforminputcontexts
%{libqt5_plugindir}/platforms
%{libqt5_plugindir}/egldeviceintegrations
%{libqt5_plugindir}/xcbglintegrations

%files platformtheme-gtk3
%license LICENSE.*
%doc *.txt
%dir %{libqt5_plugindir}/platformthemes
%{libqt5_plugindir}/platformthemes/libqgtk3.so

%files platformtheme-xdgdesktopportal
%license LICENSE.*
%doc *.txt
%dir %{libqt5_plugindir}/platformthemes
%{libqt5_plugindir}/platformthemes/libqxdgdesktopportal.so

%files -n libQt5Gui-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Gui.so
%{libqt5_libdir}/libQt5Gui.prl
%{libqt5_libdir}/libQt5EglFSDeviceIntegration.so
%{libqt5_libdir}/libQt5EglFSDeviceIntegration.prl
%{libqt5_libdir}/cmake/Qt5EglFSDeviceIntegration/
%{libqt5_libdir}/libQt5EglFsKmsSupport.prl
%{libqt5_libdir}/libQt5EglFsKmsSupport.so
%{libqt5_libdir}/cmake/Qt5EglFsKmsSupport/
%{libqt5_libdir}/libQt5XcbQpa.so
%{libqt5_libdir}/libQt5XcbQpa.prl
%{libqt5_libdir}/cmake/Qt5XcbQpa/
%{libqt5_libdir}/cmake/Qt5Gui/
%{libqt5_libdir}/pkgconfig/Qt5Gui.pc
%{libqt5_includedir}/QtGui/
%{libqt5_includedir}/QtEglFSDeviceIntegration/
%{libqt5_includedir}/QtXkbCommonSupport
%{libqt5_libdir}/metatypes/qt5gui_metatypes.json
%exclude %{libqt5_includedir}/QtGui/%{so_version}
%exclude %{libqt5_includedir}/QtEglFSDeviceIntegration/%{so_version}
%exclude %{libqt5_includedir}/QtXkbCommonSupport/%{so_version}

%files devel
%license LICENSE.*
%doc *.txt

%files private-headers-devel
%license LICENSE.*
%doc *.txt

%files -n libQt5Sql5
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Sql.so.*
%dir %{libqt5_plugindir}/sqldrivers

%files -n libQt5Sql-devel
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Sql.so
%{libqt5_libdir}/libQt5Sql.prl
%{libqt5_libdir}/cmake/Qt5Sql/
%{libqt5_libdir}/pkgconfig/Qt5Sql.pc
%{libqt5_includedir}/QtSql/
%exclude %{libqt5_includedir}/QtSql/%{so_version}

%files -n libQt5Sql5-sqlite
%license LICENSE.*
%doc *.txt
%{libqt5_plugindir}/sqldrivers/libqsqlite*.so

%files -n libQt5Sql5-unixODBC
%license LICENSE.*
%doc *.txt
%{libqt5_plugindir}/sqldrivers/libqsqlodbc*.so

%files -n libQt5Sql5-postgresql
%license LICENSE.*
%doc *.txt
%{libqt5_plugindir}/sqldrivers/libqsqlpsql*.so

%files -n libQt5Sql5-mysql
%license LICENSE.*
%doc *.txt
%{libqt5_plugindir}/sqldrivers/libqsqlmysql*.so

%files -n libQt5Bootstrap-devel-static
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5Bootstrap.a
%{libqt5_libdir}/libQt5Bootstrap.prl

%files -n libQt5OpenGLExtensions-devel-static
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5OpenGLExtensions.a
%{libqt5_libdir}/libQt5OpenGLExtensions.prl
%{libqt5_libdir}/cmake/Qt5OpenGLExtensions/
%{libqt5_libdir}/pkgconfig/Qt5OpenGLExtensions.pc
%{libqt5_includedir}/QtOpenGLExtensions/

%files -n libQt5PlatformSupport-devel-static
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5XkbCommonSupport.a
%{libqt5_libdir}/libQt5XkbCommonSupport.prl
%{libqt5_libdir}/cmake/Qt5XkbCommonSupport/
%{libqt5_libdir}/libQt5AccessibilitySupport.a
%{libqt5_libdir}/libQt5AccessibilitySupport.prl
%{libqt5_libdir}/cmake/Qt5AccessibilitySupport/
%{libqt5_libdir}/libQt5DeviceDiscoverySupport.a
%{libqt5_libdir}/libQt5DeviceDiscoverySupport.prl
%{libqt5_libdir}/cmake/Qt5DeviceDiscoverySupport/
%{libqt5_libdir}/libQt5EglSupport.a
%{libqt5_libdir}/libQt5EglSupport.prl
%{libqt5_libdir}/cmake/Qt5EglSupport/
%{libqt5_libdir}/libQt5EventDispatcherSupport.a
%{libqt5_libdir}/libQt5EventDispatcherSupport.prl
%{libqt5_libdir}/cmake/Qt5EventDispatcherSupport/
%{libqt5_libdir}/libQt5FbSupport.a
%{libqt5_libdir}/libQt5FbSupport.prl
%{libqt5_libdir}/cmake/Qt5FbSupport/
%{libqt5_libdir}/libQt5FontDatabaseSupport.a
%{libqt5_libdir}/libQt5FontDatabaseSupport.prl
%{libqt5_libdir}/cmake/Qt5FontDatabaseSupport/
%ifnarch %arm aarch64
%{libqt5_libdir}/libQt5GlxSupport.a
%{libqt5_libdir}/libQt5GlxSupport.prl
%{libqt5_libdir}/cmake/Qt5GlxSupport/
%endif
%{libqt5_libdir}/libQt5InputSupport.a
%{libqt5_libdir}/libQt5InputSupport.prl
%{libqt5_libdir}/cmake/Qt5InputSupport/
%{libqt5_libdir}/libQt5LinuxAccessibilitySupport.a
%{libqt5_libdir}/libQt5LinuxAccessibilitySupport.prl
%{libqt5_libdir}/cmake/Qt5LinuxAccessibilitySupport/
%{libqt5_libdir}/libQt5PlatformCompositorSupport.a
%{libqt5_libdir}/libQt5PlatformCompositorSupport.prl
%{libqt5_libdir}/cmake/Qt5PlatformCompositorSupport/
%{libqt5_libdir}/libQt5ServiceSupport.a
%{libqt5_libdir}/libQt5ServiceSupport.prl
%{libqt5_libdir}/cmake/Qt5ServiceSupport/
%{libqt5_libdir}/libQt5ThemeSupport.a
%{libqt5_libdir}/libQt5ThemeSupport.prl
%{libqt5_libdir}/cmake/Qt5ThemeSupport/
%{libqt5_libdir}/libQt5EdidSupport.a
%{libqt5_libdir}/libQt5EdidSupport.prl
%{libqt5_libdir}/cmake/Qt5EdidSupport/
%if %{vulkan}
%{libqt5_libdir}/libQt5VulkanSupport.a
%{libqt5_libdir}/libQt5VulkanSupport.prl
%{libqt5_libdir}/cmake/Qt5VulkanSupport/
%endif
%{libqt5_includedir}/QtAccessibilitySupport/
%{libqt5_includedir}/QtDeviceDiscoverySupport/
%{libqt5_includedir}/QtEglSupport/
%{libqt5_includedir}/QtEventDispatcherSupport/
%{libqt5_includedir}/QtFbSupport/
%{libqt5_includedir}/QtFontDatabaseSupport/
%ifnarch %arm aarch64
%{libqt5_includedir}/QtGlxSupport/
%endif
%{libqt5_includedir}/QtInputSupport/
%{libqt5_includedir}/QtLinuxAccessibilitySupport/
%{libqt5_includedir}/QtPlatformCompositorSupport/
%{libqt5_includedir}/QtServiceSupport/
%{libqt5_includedir}/QtThemeSupport/
%{libqt5_includedir}/QtEdidSupport/
%if %{vulkan}
%{libqt5_includedir}/QtVulkanSupport/
%endif
%exclude %{libqt5_includedir}/QtAccessibilitySupport/%{so_version}/
%exclude %{libqt5_includedir}/QtDeviceDiscoverySupport/%{so_version}/
%exclude %{libqt5_includedir}/QtEglSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtEventDispatcherSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtFbSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtFontDatabaseSupport/%{so_version}/
%ifnarch %arm aarch64
%exclude %{libqt5_includedir}/QtGlxSupport/%{so_version}/
%endif
%exclude %{libqt5_includedir}/QtInputSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtLinuxAccessibilitySupport/%{so_version}/
%exclude %{libqt5_includedir}/QtPlatformCompositorSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtServiceSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtThemeSupport/%{so_version}/
%exclude %{libqt5_includedir}/QtEdidSupport/%{so_version}/
%if %{vulkan}
%exclude %{libqt5_includedir}/QtVulkanSupport/%{so_version}/
%endif

%files -n libQt5KmsSupport-devel-static
%license LICENSE.*
%doc *.txt
%{libqt5_libdir}/libQt5KmsSupport.a
%{libqt5_libdir}/libQt5KmsSupport.prl
%{libqt5_libdir}/cmake/Qt5KmsSupport/
%exclude %{libqt5_includedir}/QtKmsSupport/%{so_version}/
%{libqt5_includedir}/QtKmsSupport/

%files -n libQt5Core-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtCore/%{so_version}/

%files -n libQt5DBus-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtDBus/%{so_version}/

%files -n libQt5Gui-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtGui/%{so_version}/
%{libqt5_includedir}/QtEglFSDeviceIntegration/%{so_version}
%{libqt5_includedir}/QtXkbCommonSupport/%{so_version}

%files -n libQt5KmsSupport-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtKmsSupport/%{so_version}/

%files -n libQt5Network-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtNetwork/%{so_version}/

%files -n libQt5OpenGL-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtOpenGL/%{so_version}/

%files -n libQt5PlatformSupport-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtAccessibilitySupport/%{so_version}/
%{libqt5_includedir}/QtDeviceDiscoverySupport/%{so_version}/
%{libqt5_includedir}/QtEglSupport/%{so_version}/
%{libqt5_includedir}/QtEventDispatcherSupport/%{so_version}/
%{libqt5_includedir}/QtFbSupport/%{so_version}/
%{libqt5_includedir}/QtFontDatabaseSupport/%{so_version}/
%ifnarch %arm aarch64
%{libqt5_includedir}/QtGlxSupport/%{so_version}/
%endif
%{libqt5_includedir}/QtInputSupport/%{so_version}/
%{libqt5_includedir}/QtLinuxAccessibilitySupport/%{so_version}/
%{libqt5_includedir}/QtPlatformCompositorSupport/%{so_version}/
%{libqt5_includedir}/QtServiceSupport/%{so_version}/
%{libqt5_includedir}/QtThemeSupport/%{so_version}/
%{libqt5_includedir}/QtEdidSupport/%{so_version}/
%if %{vulkan}
%{libqt5_includedir}/QtVulkanSupport/%{so_version}/
%endif

%files -n libQt5PrintSupport-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtPrintSupport/%{so_version}/

%files -n libQt5Sql-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtSql/%{so_version}/

%files -n libQt5Test-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtTest/%{so_version}/

%files -n libQt5Widgets-private-headers-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtWidgets/%{so_version}/

%files -n libQt5PlatformHeaders-devel
%license LICENSE.*
%doc *.txt
%{libqt5_includedir}/QtPlatformHeaders/

%files examples
%license LICENSE.*
%doc *.txt
%{libqt5_examplesdir}/

%changelog
* Mon Nov 25 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.16+kde130, rebased upstream:
  * xcb: Sync XCB connection after reparenting window
  * xcb: check validity of RandR output info before using it
  * QDuplicateTracker: fix redundant ;
  * qxmlstreamparser_p.h: fix -Wshadow in parse()
  * Fix -Wdouble-promotion in FP overload of convertDoubleTo()
  * Protect headers against min/max macros
  * Add __attribute__((format(printf()))) to q(v)nprintf()
  * qsavefile_p.h: fix missing qsavefile.h include
  * qendian_p.h: fix -Wshadow warning
  * qtextstream_p.h: fix -Wshadow in QDeviceClosedNotifier
  * QFutureInterface: fix build with GCC14/C++20: template-id not allowed
  * qfuturewatcher_p.h: fix missing qfuturewatcher.h include
  * qhttpmultipart_p.h: add missing qiodevice.h include
  * Fix crash in font distancefield computation
  * Avoid crash in font distancefield computation
  * Revert "Update Harfbuzz to 7.2.0"
  * Revert "Update Harfbuzz to 7.2.0"
  * Fix WinRT/ARM build
  * Update Harfbuzz to version 8.2.2
  * Upgrade Harfbuzz to version 8.2.0
  * Update bundled libjpeg-turbo to version 3.0.1
  * SQLite: Update SQLite to v3.43.2
  * Add a script for updating from publicsuffix/list.git
  * Fix undefined symbol qt_version_tag with lld(16.0) for non core lib
  * QInputMethod: check if focusobject supports the "new" IM function before calling it
  * Un-deprecate qSwap()
  * Doc: state that models are not thread-safe
  * Fix android build error
  * xcb: replace a warning with debug info
  * qurl-generateTLDs: filter empty and comment lines
  * qurltlds_p.h: support easier automatic updates
  * SQLite: Update SQLite to v3.43.1
  * Upgrade to Freetype 2.13.2
  * Fix crash when reading corrupt font data (CVE-2023-43114)
  * qmake: Don't error out if QMAKE_DEFAULT_LIBDIRS is empty on macOS
  * qxkbcommon: Keep lower case as Qt key when upper case is not in Latin1
  * Doc: Fix documented default for QCalendarWidget maximumDate, minimumDate
  * QDataStream: clarify QDataStream::operator>>(char *&s) API docs
  * doc: Remove QSettings' paths for embedded linux
  * Update bundled zlib to version 1.3
  * tst_QDtls: use DTLS v 1.0 test data conditionally
  * Bump version to 5.15.16
  * Android: fix handling of tree content uri with sub-document
  * QTextFormat: documentation fix
  * SQLite: Update SQLite to v3.43.0
  * tst_QSslSocket: skip tests requiring TLS v 1.0 downgrade
  * Update to Harfbuzz 8.1.1
  * Update version of FreeType attribution
  * tst_QHashFunctions: use actual seed in consistent() test function
  * Android: fix content URI handling for non-ascii file names
  * Upgrade Harfbuzz to 7.3.0
  * Update download location for Harfbuzz as well
- Commits dropped by the rebase:
  * Add missing line continuations for memory_resource opt-out on Apple systems
  * Fix CVE-2023-43114
* Wed Sep  4 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.15+kde127, rebased upstream:
  * Add LGPL header to qcalendar.cpp
  * Move some flaky text tests into Lancelot
  * Update Harfbuzz to 7.2.0
  * doc: Make docs for ElideNone a bit more precise
  * tst_QImageReader: fix missing checks for "newly"-added ImageOptions
  * tst_QMainWindow: for UB (use of reserved names)
  * Update bundled libjpeg-turbo to version 3.0.0
  * Update to Freetype 2.13.1
  * [docs] Link from QtConcurent::run() to QThreadPool::start(Callable&&)
  * Docs: State that OpenSSL3 is available from 5.15.1
  * Simplify (and fix) initialization of a list of time-zones
  * ODBC/MySQL: fix compilation with MySQL < 5.7.9
  * SQLite: Update SQLite to v3.42.0
  * tst_QHostInfo: fix mem-leaks in threadSafetyAsynchronousAPI()
  * tst_QSortFilterProxyModel: fix mem-leaks II: sortStable()
  * tst_QNetworkDiskCache: fix mem-leak
  * tst_QAbstractItemModelTester: fix mem-leak
  * tst_QSortFilterProxyModel: fix mem-leaks
  * Fix screens not always updating if order changes
  * Update the list of CLDR-based files
  * Return TZ time-zone backend's tranCache() as a const reference
  * tst_QTcpSocket: fix mem-leak
  * tst_QNetworkCookieJar: fix memleak
  * tst_QParallelAnimationGroup: fix memleak
  * tst_QXmlStream::tokenErrorHandling() - register test directory in CMake
  * Fix transparency in 16 bit and 24 bit ico files
  * QVariant: always compare floating point with double precision
  * Doc: Document QMAKE_APPLE_DEVICE_ARCHS
  * Update bundled libpng to version 1.6.40
  * fbconvenience: use smart pointer for QFbCursor
  * Doc: Clarify that the rich text engine has limited support for HTML tags
  * autotest: Blacklist tst_QTableView::columnViewportPosition for winrt
  * autotest: Blacklist QTimeLine::interpolation for winrt
  * QFuture: mention the work-stealing algorithm in the docs
  * QtDoc Global: Add macros for Qt Design Studio in qtdoc
  * Fix specific overflow in qtextlayout
  * Remove QEglFSCursor's inheritance of QOpenGLFunctions
  * tst_QPixmapCache: QVERIFY a failed replace()
  * tst_QPixmapCache: check insert() reports failure
  * QPixmapCache: add a comment on how failed insert() invalidates cacheKey
  * tst_QPixmapCache: rewrite QVERIFY(x != 0) to QVERIFY(x)
  * QVariant: remove outdated docs about reimplementing clear()
  * Bump version to 5.15.15
  * Update The-Qt-Company-Commercial
  * Fix crash on QLocale::monthName().simplified()
  * Android: fix QDir::entryInfoList() with content URIs
  * Android: fix content url handling of filenames with spaces
- Commits dropped by the rebase:
  * tst_QXmlStream: remove unneeded _ba UDLs
  * Fix specific overflow in qtextlayout (CVE-2023-32763)
* Mon Jul 22 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.14+kde143:
  * HTTP2: Delay any communication until encrypted() can be responded to
    (bsc#1227426, CVE-2024-39936)
  * Add missing line continuations for memory_resource opt-out on Apple systems
  * a11y atspi: Add null checks in table iface methods
* Wed May 29 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.14+kde140, rebased upstream:
  * xcb: Avoid repeatedly registering xsettings callbacks
  * Opt out of standard library memory_resource on macOS < 14 and iOS < 17
  * QPainter: fix assert when drawing bitmaps at very near to .5 coord
  * XCB: Unset the connection's mousePressWindow if it's this window
  * SQL/ODBC: Pass correct length to SQLColAttribute()
  * qxkbcommon: fix isKeypad
  * QObjectPrivate::Signal: initialize all members
  * gui: fix build against gcc-14 (-Werror=calloc-transposed-args)
  * QTest::WatchDog: fix missing timeout resets on test function change
  * tst_bench_QCryptographicHash: add benchmarks for QMessageAuthenticationCode
  * Hsts: match header names case insensitively
  * Blacklist tst_NetworkSelfTest::smbServer on openSUSE 15.4
  * Blacklist tst_QGlyphRun::drawRightToLeft on openSUSE 15.4
  * Match deadcode elimination with cpu feature check
  * Update public suffix list for QUrl/QtNetwork
  * QProcess: remove the note that it freezes threads on QNX
  * Update public suffix list for QUrl/QtNetwork
  * QNAM: Fix double-connect for manual redirect handling
  * Android: fix build error for Qt 5.15 with NDK r24+
  * Bump tested macOS SDK to version 13
  * Darwin: Explicitly link to IOKit, as used by QSysInfo::machineUniqueId()
  * Update Copyright year to 2023
  * SQLite: Update SQLite to v3.41.2
  * Android: remove getRootWindowInsets
  * Blacklist tst_QItemDelegate::editorKeyPress for SLES 15.4
  * BLACKLIST tst_QListView::internalDragDropMove for SLES 15.4
  * Blacklist tst_QWindow:testInputEvents on SLES 15.4
  * Blacklist tst_gestures tests for SLES 15.4
  * Blacklist tst_QOpenGLWidget::stackWidgetOpaqueChildIsVisible for SLES 15.4
  * Blacklist tst_qwidget::widgetAt and tst_qwidget_window::tst_dnd_events
  * BLACKLIST: tst_QApplication::sendEventsOnProcessEvents for SLES 15.4
  * Blacklist: tst_QGraphicsAnchorLayout::layoutDirection for SLES 15.4
  * Doc: Fix typo
  * Android: allow using string based versions in compileSdkVersion
  * QListView: No-op, when a list item is dropped directly behind itself
  * Android: don't break when finding opengl plugin
  * Change android target SDK version to 31
  * git: ignore ._* files
  * Android: fix manual deployment with ANDROID_DEPLOYMENT_DEPENDENCIES
  * QMessageAuthenticationCode: fix result() non-re-entrancy
  * QMessageAuthenticationCode: Extract Methods finalize{,Unchecked}() from result()
  * tst_bench_QCryptographicHash: use QMetaEnum trick
  * tst_bench_QCryptographicHash: port to QTest::addRow()
  * tst_qtconcurrentrun: fix UB (uninit'ed values)
  * QComboBox: Disable items marked as disabled in native popups
  * tst_QSslSocket_onDemandCertificates_member: Blacklist & debug
  * QSQL/ODBC: fix regression (trailing NUL) (boo#1227513)
  * SQLite: Update SQLite to v3.41.1
  * Android: demistify the "No platform plugin" androiddeployqt error
  * QTest::WatchDog: Extract Method setExpectation()
  * Tidy up qtestcase.cpp's WatchDog
  * Fix thread-sanitizer warning about a data race
  * macOS: Guard text input client from destroyed QCocoaWindow
  * Accept full-width parentheses in removeMnemonics()
  * Fix listed files for sha3_keccak
  * Fix overflow in SHA-3/Keccak
  * tst_QCryptographicHash: Extract Method ensureLargeData()
  * QCryptographicHash: fix UB (data race on concurrent result()) [2nd try]
  * QVarLengthArray: fix UBs in insert(it, n, v) ([basic.life], invariants)
  * Add q_points_into_range to container utilities
  * qstrncpy(): document that we don't implement strncpy() fill-all-[dst,len)
  * QThread/Unix: fix compilation with C++11
  * QDBusError: don't refer to a QT_NAMESPACE'ed get() as ::get()
  * Update to Freetype 2.13.0
  * Android: fix and document QStandardPaths behavior on different versions
  * tst_qvarlengtharray: add test for QVLA(n) ctor
  * Android: avoid duplicate paths from QStandardPaths::standardLocations()
  * Android: document limitation for QFile::copy() operation for content uri
  * Bump version to 5.15.14
  * SQLite: Update SQLite to v3.41.0
  * tst_QMessageAuthenticationCode: check that setKey() reset()s
  * Avoid resetting CMAKE_AUTOMOC_MACRO_NAMES
  * Set GenerateDebugInformation to true in vcproj if at least /DEBUG is set
  * QCryptographicHash: add a mutex to writing to the results
  * SQL/OCI: Correctly calculate utc offset string when icu is not available
  * QVarLengthArray: Extract Method QtPrivate::q_rotate()
  * Specify Android architecture in gradle files
  * Logging: fix crash when decoding a symbol that isn't a function
  * qstrncpy: NUL-terminate even when src is nullptr
  * Blacklist a test in the GUI form of tst_QTimer on ubuntu-20.04
  * Blacklist tst_QTimer::zeroTimer in its Gui form
  * Text: fix Soft hyphen rendering in QTextLayout::glyphRuns()
* Tue Mar 19 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.13+kde138, rebased upstream:
  * QVarLengthArray: fix UBs in emplace()/insert() ([basic.life], broken class invariant)
  * Android: use test QFileInfo fileName() instead of completeBaseName()
  * Fix few QFileInfo and QDir calls
  * savegame ex.: fix include order [2/2]: game.h
  * savegame ex.: use NSDMI, =default the default ctor
  * savegame ex.: fix include order
  * savegame ex.: fix extra ';' after Q_GADGET
  * tst_qvarlengtharray: fix MyBase trackers for swap()
  * Apple: Add CFBundleAllowMixedLocalizations=YES to Info.plist files
  * qmake: Add CFBundleDevelopmentRegion to iOS Info.plist
  * Update bundled libjpeg-turbo to version 2.1.5
  * Revert "Copy only files that belongs to QML module"
  * savegame ex.: make Level ctor explicit
  * macOS: Skip deployment target runtime check when detecting compat version
  * Apple: Use 'en' instead of 'English' as development region
  * qmake: Add CFBundleDevelopmentRegion to the macOS Info.plist
  * Update comments in QQuaternion::getEulerAngles
  * QtGui/math3d: Fix QQuaternion::getEulerAngles for GimbalLock cases
  * Pass short time format to GetTimeFormat from GetLocaleInfo
  * Android: fix height calculation
  * SQL/ODBC: fix some users of toSQLTCHAR() to not assume identical UTF-8/16/32 string lengths
  * ODBC SQL driver: fix conversion of QByteArray to QVLA<SQLTCHAR>
  * Docs:Android: Add docs notes about support for content Uris
  * QODBC: correctly fill cache when index() is called
  * Fix ignored name filter in QFileDialog::getOpenFileContent()
  * GTK3 theme: simplify code
  * Fix ContextInfo example crashing on Android
  * ibus: check object validity before honoring `inputMethodAccepted()`
  * ODBC SQL driver: deal with different sizes of SQLTCHAR correctly
  * Doc: Update copyright year
  * Android: pass EXTRA_INITIAL_URI to native FileDialog
  * Doc: Only list qt core classes in qt core io group
  * QFileSystemEngine: URL encode path in trash info, use relative path
  * [doc] Warn users about data races regarding qt_ntfs_permission_lookup
  * [doc] QSharedPointer: add some missing docs
  * Disable feature vkgen if vulkan was explicitly disabled
  * Android: handle move operation with content uris
  * Android: handle rename() operation with content uris
  * Android: Add facilities to handle more content URIs operations
  * Fix infinite loop when iterating content uri sub-files/dirs
  * Return the QFileInfo::baseName/QDir::dirName() from fileEngine impl
  * SQLite: Update SQLite to v3.40.1
  * Fix cache maybe invalid while the signal is actived from queue
  * Android A11Y: Only access the main thread when it is not blocked
  * ibus: support high dpi for cursor rectangle
  * QString: use inheritance, not template aliases, for arg() constraints
  * Fix the ref-counting for the std::function version of tryStart()
  * Android: Fix UI is scaled smaller than before
  * Android: fix Android assets handler not listing dirs with only sub dirs
  * Android: fix deprecations for getDrawable() on QtMessageDialogHelper
  * Android: Fix deprecations AlertDialog.setButton()
  * Bump version to 5.15.13
  * Doc: Increase Test Function Timeout
  * QtMiscUtils: add missing toAsciiUpper(), use it in moc
  * QLatin1/String/View: don't decay the arg() arguments
  * QBuffer: test and document open() behavior
  * SQLite: Update SQLite to v3.40.0
  * tst_qmlstream: re-use QBuffer instance in readBack()
  * iOS a11y: Ensure parent elements are stacked below their children
  * qmake: Document that QMAKE_PRE_LINK does not work with Xcode
  * Blacklist: test cases blacklisted in tst_Gestures:
  * Android: Fix incorrect dimensions - part 2
  * PCRE2: upgrade to 10.42
  * QNetworkRequest: don't assume QByteArray::constData() is NUL-terminated
  * QNetworkRequest: Make header parsing locale-independent
  * Doc: Change links from froglogic to qt domain
  * Backport QtMiscUtils::toAsciiLower() from dev
- Commits dropped by the rebase:
  * Apply CVE-2023-24607-qtbase-5.15.diff
  * correctly set up ref counting in QThreadPool::tryStart(std::function)
* Fri Feb 16 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.12+kde151:
  * Improve KTX file reading memory safety (CVE-2024-25580, boo#1219996)
  * Revert "xcb: only set base size when it's valid"
  * Fix potential leak of QPropertyAnimation in QLineEditIconButton
  * QBitArray: correct inline keyword
* Wed Jan  3 2024 alarrosa@suse.com
- Update to version 5.15.12+kde147:
  * Http2: fix potential overflow in assemble_hpack_block()
    (bsc#1218413, CVE-2023-51714)
  * HPack: fix incorrect integer overflow check
  * HPack: fix a Yoda Condition
* Fri Dec 29 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.12+kde144, rebased upstream:
  * QMimeDatabase: handle buggy type definitions with circular inheritance
  * xcb: only set base size when it's valid
  * QPixmapCache: fix leaking of QStrings and Keys on clear()
  * OpenFile portal: do not use O_PATH fds
  * QSystemTrayIcon: properly disconnect old menu in setContextMenu()
  * Guard QTabBar against nested event processing during moving tabs
  * QDial: don't crash when min==max and setting a value != min & max
  * QStandardItemModel: don't leak in mimeData()
  * SQL/MySQL: properly initialize variable
  * QWidgetTextControl: ignore invalid input method event
  * Update the LGPL license header
  * SQL/MySQL: fix handling of json column
  * Remove QMAKE_RANLIB and QMAKE_LINK_SHLIB from android/default_pre.prf
  * macOS: Fix less common writing systems on Catalina and later
  * Blacklist 1 tests in tst_QFtp on ubuntu-20.04
  * Update bundled libpng to version 1.6.39
  * Android: Fix signing of APKs that are generated when an AAB is also built
  * Update bundled zlib to version 1.2.13
  * doc: update the limitation of QSystemTrayIcon on X11
  * Blacklist 1 tests in tst_QTimer on ubuntu-20.04
  * Add benchmarks for QLocale number parsing
  * Add benchmarks for QString number parsing
  * Android: Fix incorrect fullscreen dimensions
  * Gtk3Theme: set XCURSOR_SIZE and XCURSOR_THEME for wayland sessions
  * xcb: Flush Display when processing xcb events
  * xcb: Add xlib wrapper for XFlush()
  * QHostAddress: Fix incorrect comparison against 'Any'
  * QSsl[OpenSSL/Android]: Fix hardcoded 1_1 suffix
  * BLACKLIST: tst_QApplication::sendEventsOnProcessEvents for RHEL 9.0
  * QMacStyle: do not set white color for grayed out button
  * Work round macOS's omission of en_DE from its own uiLanguages()
  * Suppress a deprecation warning in tst_QDateTime::toString_enumformat()
  * QJsonValue: fix incorrect to{Array,Object} when the value is empty
  * QGtk3Dialog: remove the #include for empty moc
  * Remove unneeded QWindow from QGtk3Dialog
  * tst_QSslSocket: Delete sslOptions
  * tst_QSslServer: Make the in-process server use TLS1.2
  * Android: fix Gradle warning about using enableUncompressedNativeLibs
  * Mention  limitation of QDir::drives() on Windows
  * QFileSystemEngine/Win: fix incorrect buffer size in currentPath()
  * Android: properly retrieve mime type of uri to for openUrl()
  * Android: Fix clipboard issue with urls
  * Android: Add a way to disable accessibility via an environment var
  * Update bundled libpng to version 1.6.38
  * QIOSMessageDialog::exec - work around 'windowsless' exec
  * QIosScreen: retain the right window
  * tst_Q{BitArray,ContiguousCache}: check not only count(), but size(), too
  * QIosTextResponder: stop using deprecated constants and type
  * qcompilerdetection.h: detect Coverity
  * Android: Fix Display.getRealMetrics deprecation
  * Fix broken Text rendering when noantialiased NativeRendering is used
  * forkfd: fix Clang 15 ATOMIC_VAR_INIT deprecation warning
  * eglfs: Add env.var. to disable the dedicated drmHandleEvent thread
  * doc: Don't put strings into QVector<double>
  * Remove focusProxyAndInputMethods from tst_QWidget
  * Bump version to 5.15.12
  * Update documentation of qWaitForWindowActive / qWaitForWindowExposed
  * QtHttp: Lower the severity of some log output
  * StyleSheetStyle: Fix color of placeholder texts in text edits
  * Android: Fix flickering on split screen mode
  * Update url to IAccessible2 Specification
* Thu Oct 19 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde138:
  * QLibraryPrivate: Actually merge load hints
  * QPluginLoader: report the right load hints
  * xkb: fix build with libxkbcommon 1.6.0 and later
  * a11y atspi: Map ButtonMenu role to AT-SPI equivalent
* Fri Oct  6 2023 Christophe Marin <christophe@krop.fr>
- Enable the experimental native painting feature to improve
  remote desktop performances (boo#1214915)
  exporting QT_XCB_NATIVE_PAINTING is required to use the feature.
* Fri Oct  6 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.11+kde134, rebased upstream:
  * Revert "Windows QPA: Add support to UiaRaiseNotificationEvent()"
  * FileChooser portal: Make sure filter.name is not empty
  * QPersistentModelIndex: fix UB (op< on unrelated pointers)
  * Avoid crash when keysymToQtKey(keysym, Qt::ControlModifier) is called
  * a11y atspi: translate coords for GetOffsetAtPoint the right way
  * a11y atspi: Take dialog into account as top-level window
  * a11y atspi: Fix incorrect use of x instead of y position
  * macOS: Handle asynchronous deminiaturizing of windows
  * QTranslator: generalize a UNIX-only path
  * iOS, input panel: be more careful before enabling QIOSKeyboardListener
  * Android: Fix flickering on window resize and show keyboard
  * Android A11Y: Check for active surface before calling into native code
  * xcb: Delete touch points without target windows
  * Blacklist 1 tests in tst_QDBusConnection on ubuntu-20.04
  * Fix CMake builds without ANDROID_SDK
  * Blacklist 2 tests in tst_Http2 on ubuntu-20.04
  * Blacklist 1 tests in tst_QSqlQuery on macos
  * Defer creating the special shaders in the texture blitter
  * tst_QSslSocket::serverCipherPreferencies - fix for OpenSSL v3
  * QTemporaryFile: document rename() differences from QFile
  * Doc: 3rd party: Fix reference to FreeType LICENSE.txt
  * Update bundled libjpeg-turbo to version 2.1.4
  * tst_QSsSocket: fix verifyClientCertificate with OpenSSL 3
  * tst_QSslSocket: regenerate certificate used for setLocalCertificateChain
  * tst_QSslSocket::protocolServerSide - make it work with OpenSSL v3
  * tst_QSslSocket::oldErrorsOnSocketReuse - make it work with OpenSSL v3
  * Update zconf.h prefixes to match zlib v1.2.12 update
  * xcb: fix D&D in same xembed client
  * xcb: use global coordinates for position of D&D for xembed client
  * Doc: Update QMetaType::metaObject() descriptions
  * BLACKLIST: tst_QGlyphRun::mixedScripts for Ubuntu 22.04
  * BLACKLIST tst_qfont for Ubuntu 22.04
  * BLACKLIST tst_QMenuBar::check_menuPosition for Ubuntu 22.04
  * tst_QDtls::verifyClientCertficiate - update certs for OpenSSL v3
  * QSslCertificate::toText(): add a file to compare against
  * Fix the spelling of the word "combination"
  * tst_QSslCertificate::pkcs12 - skip the test if OpenSSL version >= 3
  * Android A11Y: Fix TalkBack scrolling behavior
  * Android A11Y: Notify android about scroll events
  * QCocoaDrag: don't add pasteboard items with non-absolute URLs
  * QDirPrivate: pass input QList by cref
  * tst_qbytearray: remove qCompress_data for QT_NO_COMPRESS
  * QDeviceDiscoveryUDev: use NSDMI
  * QAuthenticator: Fix crash when using NTLM / Negotiate
  * Provide a native interface instance in minimal platform plugin
  * Android: document the supported clipboard mimetypes
  * Windows: Account for not finding child windows when calling ChildWindowFromPointEx
  * iOS: Send touch events asynchronously to avoid deadlocking UIKit event loop
  * Disable bitcode for iOS
  * macOS: Ignore deprecation for ReleaseIconRef
  * BLACKLIST tst_QApplication::sendEventsOnProcessEvents for Ubuntu 22.04
  * Convert Latin1 to UTF-16 before passing to ICU API
  * Doc: Remove repetition of word in text
  * eglfs: Fix screen cloning when atomic is enabled
  * Fix printing of dpr>1 images on Windows
  * QHttp: Fix handling of redirect loaded from cache
  * Doc: Fix return type of QLEInteger/QBEInteger post-in/decrement ops
  * qmake: Fix installation of separate debug info for plugins
  * iOS: ensure we close inputpanel after clearing focusobject
  * Convert Latin1 to UTF-16 before passing to ICU API
  * qputenv: defend against non-NUL-terminated QByteArray values
  * QFontSubset: remove unused glyphName() overload
  * Statically assert that the __mips_dsp code is only active on 32-bit
  * QGtk3Theme: Ensure gtk uses the same windowing system as Qt
  * tst_QFocusFrame: fix -Wparantheses
  * Sync Vulkan device features between QVulkanWindow and QRhi
  * SQLite: Update SQLite to v3.39.2
  * Update freetype to 2.12.1
  * corelib: Fix typos in documentation
  * QAtomicInteger docs: mention bool and char8_t as 8-bit types
  * qgraphicsitem_cast: replace 0 with nullptr
  * Doc: Hide weak overload template magic from documentation
  * Revert "QDateTime: fix adjusted datetime handling"
  * Fix select handles disappears issues
  * tst_QSslKey: prepare for the migration to OpenSSL v3
  * tst_qnetworkreply: replace server.pem/key pair
  * Disable unit testing setting up QTcpServer on special Apple interfaces
  * qmake/msbuild: Turn off "use full paths in diagnostics" by default
  * qmake/msbuild: Support all /DEBUG:xxx linker options
  * qmake/msbuild: Support all /LTCG:xxx options
  * Android A11Y: Add content change type to content change event
  * Enabler for fractional scaling of text in Qt Quick
  * macOS: Override logical DPI to 72
  * Add QDom internalSubset implementation
  * Fix tst_AndroidAssets, broken by recent changes on assets load speed
  * Android: Improve loading speed of individual assets
  * Darwin: Replace deprecated symbol kIOMasterPortDefault with equivalent
  * macOS: Remove code for handling logical DPI changes
  * Fix an incorrect invocation of llvm-readobj
  * macOS: Ignore deprecation for kOnSystemDisk icon domain
  * Copy only files that belongs to QML module
  * Android: fix wrong position of cursor handle and editpopup menu in split screen
  * Doc: Document QML_IMPORTS_PATH and QMLPATHS
  * Add the missing RCC_DIR to '.qrc' paths when generating deployment settings
  * Android: Fix the offset of the EditPopupMenu
  * xcb: update xkb_state mask as much as possible
  * QDom: Stop treating non-BMP characters as invalid
  * Android 13: Fix warnings on starting an application
  * qxkbcommon: Map Super/Hyper to Meta early enough to have an effect
  * macOS: Ignore update requests for offline displays
  * macOS: Avoid recursively updating screens when window moves screen
  * qmake/MinGW: Install separate debug info of DLLs next to the DLL
  * QMainWindow: fix restoreState() for toolbars
  * Make two QDT benchmarks data-driven and add more rows
  * Fix doc and example of QLoggingCategory::installCategory()
  * qmake: Document Xcode behavior when bundling translation files
  * Android: Fix missing import
  * QByteArray: more GCC 12 -Werror=array-bound whack-a-mole
  * CMake: Fix android sdk version propagation
  * Restore C++20-deprecated mixed-enum bitwise operators
  * Android: Fix ANR when QtService and QtActivity load in same process
  * Fix restart QtActivity
  * QArrayData::data(): do type-punning via quintptr, not char *
  * QIOSTextResponder: recreate responder upon reset
  * QSslSocket: make it work with OpenSSL v3
  * QFileSystemModelPrivate: de-inline ctor and dtor
  * Network: update Public Suffix List
  * macOS: Ensure proper quoting when calling otool in objc_namespace script
  * QKeySequence: Fix the one-off error in the mac glyph array size
- Commits dropped by the rebase:
  * Apply CVE-2022-27404-27405-27406-qtbase-5.15.diff
  * QArrayData: fix UB via reinterpret_cast (crash with FORTIFY_SOURCE=3)
  * Adapt for q_EVP_PKEY_base_id → q_EVP_PKEY_get_base_id rename in OpenSSL 3
  * Don't use a deprecated function if built/linked with OpenSSL v3
* Thu Sep 28 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.10+kde159 (bsc#1214327, CVE-2023-37369):
  * Fix CVE-2023-43114
  * QMimeDatabase: fix detection of pattern conflict in different prefixes
  * Fix highdpi conversion of QTabletEvent coordinates on xcb
  * widget: set WA_X11NetWmWindowType* after xcb window was created
  * Fix crash when setting override cursor on multiple clients
  * QAccessibleWidget: Remove pointless ZWSP in warning message
  * Android A11Y: Fix deadlock in QtAndroidAccessibility::runInObjectContext()
  * Correctly parse non BMP char refs in the sax parser
  * Clear the _X version of alongside the enum deprecator
  * Fix UB (signed char passed to <cctype> function)
  * Qt3DRender: includemocs
  * Fix capitalization error in auto-generated qdbusmacros.h include
  * QColorDialog: Ignore mouse move events when no mouse button is pressed
  * QHostInfo: fix remaining slotObj leaks
  * QXmlStreamReader: Raise error on unexpected tokens (CVE-2023-38197,
    QTBUG-92113, QTBUG-95188, bsc#1213326)
  * QTextLayout: Reconsider cursor drawing on TextObject
  * Ensure consistent cursor width under fractional scaling
  * Fix QTextEdit cursor rectangle vertical positioning
  * Return 0 in QWindow::winId in case of failed platform window creation
  * Doc: note QWindow::winId() will cause platform window creation
  * QSslDiffieHellmanParameters: fix mem-leak
  * QHostInfo: fix leaking slot object
  * Make sure we don't count down past 0 QT_FATAL_CRITICALS
  * QLogging: DRY isFatal(QtMsgType)
  * tst_QXmlStream: remove unneeded _ba UDLs
  * Fix typo in QXmlStreamReader error message
  * QXmlStreamReader: make fastScanName() indicate parsing status to callers
  * QXmlStreamReader: change fastScanName() to take a Value*
  * Fix Croatia's currency
  * SSL: upgrade the default DH parameters
* Thu Sep 28 2023 Marcus Meissner <meissner@suse.com>
- switch icu-devel requires to pkgconfig to allow switching libicu
  versions
* Wed Jun 28 2023 Callum Farmer <gmbr3@opensuse.org>
- Change %%_libqt5_libexecdir to %%_libexecdir/qt5 (bsc#1174075)
* Tue Jun 13 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.10+kde129, rebased upstream:
  * Ssl: Copy the on-demand cert loading bool from default config
  * Schannel: Reject certificate not signed by a configured CA certificate (boo#1211994, CVE-2023-34410)
  * qnetworkreplyfileimpl_p.h: fix header guard name
  * Revert "Draw the cursor considering the descent is 0"
  * Use pkgconfig in order to find libproxy configuration
  * Upgrade PCRE2 to 10.40
  * Android A11Y: handle LocationChanged event only for focused element
  * Port binary JSON to new special integer bitfields
  * INTEGRITY: enable C99 globally
  * QObject: mark two error reporting functions COLD
  * Endian: Provide special integer bitfield unions
  * Android: set useLegacyPackaging to true in build.gradle
  * QWidgetTextControl: port to new-style connects (faster)
  * Sync qxmlstream.g with qxmlstreamparser_p.h [1/2]: switched lines
  * tst_QNetworkReply try stabilize autoDeleteReplies tests
  * Remove duplicated include for <limits>
  * Fix recursion crash when calling setStyleSheet with `qproperty-styleSheet`
  * qwindowsxpstyle: Fix typos in documentation
  * Correct prefix reported for end element in QXmlStreamReader
  * Android A11Y: Add supported role infos to A11yNodeInfo
  * Fix handling of DateTime values in QSettings
  * Fix off-by-one for "typically" lowest value INT_MIN
  * xml: Fix typos in documentation
  * QWindowsWindow: Fix typo in documentation
  * includemocs (updated script)
  * widgets: Fix typos in documentation
  * cocoa: Fix typo in debug messages
  * Only scroll QMenu when there is a valid active action
  * QTimer: Add note in documentation
  * Fix QListView assert when the last row is moved in IconMode
  * QFileDialog: Fix adding default suffix when file path contains dot
  * QLineEdit: account for the placeholderText when computing lineRect
  * QFileDialog::saveFileContent crashes on accept
  * QCompleter: QCompleter unexpectedly changes QLineEdit text
  * Fix build error on iOS with the configure option -qtnamespace
  * Draw the cursor considering the descent is 0
  * Remove pure-virtual-signals.h include from tst_moc.cpp
  * plugins: image formats - fix odr violation
  * dbus: Fix typos
  * qwindowsdialoghelpers: Fix typo in documentation
  * QTableView: Document the customizations applied to QHeaderView
  * Unicodetools: compile
  * eglfs_x11: Fix running flag linkage
  * qcompilerdetection.h: add Q_CC_{GNU,MSVC,CLANG}_ONLY macros
  * Fix CMake warning about "missing closing ' quote"
  * Fix alignment of next/prev links in offline style
  * QtDBus: includemocs
  * Image Plugins: includemocs(-ish)
  * QtGui: includemocs
  * QXcbNativeInterface: remove unused field m_sysTraySelectionAtom
  * Windows QPA: Fix slowdown with large table/tree views with accessibility
  * Macstyle: fix the text color on the disabled button
  * QMacStyle: fix tool buttons (in checked mode)
  * QTeamCityLogger: fix .arg() placeholder injection
  * QAbstractTestLogger: disable copying
  * Fix errorMessageFromComError()
  * QtNetwork: includemocs
  * AppleUnifiedLogger: Remove manually managed os_log_t cache
  * examples: add WindowStaysOnBottomHint into preview text
  * QSharedPointer: Use matching new/delete
  * QIbusPlatformInputContextPlugin: includemocs
  * QGtk3ThemePlugin: includemocs
  * QTuioTouchPlugin: includemocs
  * QtWidgets: includemocs v2022
  * QMYSQLDriverPlugin: includemocs
  * QtDeviceDiscoverySupportPrivate: includemocs
  * QLinuxFbIntegrationPlugin: includemocs
  * QtPrintSupport: includemocs
  * QSQLiteDriverPlugin: includemocs
  * QtFbSupportPrivate: includemocs
  * QXdgDesktopPortalThemePlugin: includemocs
  * QtTest: includemocs
  * QComposePlatformInputContextPlugin: includemocs
  * QtSql: includemocs
  * QVncIntegrationPlugin: includemocs
  * Fix backingstore fractional DPR glitches for widgets in child windows
  * Include <limits> where std::numeric_limits is used
  * QtInputSupportPrivate: includemocs
  * Document the default value of QSFPM::sortOrder()
  * Better document how to enable sorting in QSPFM
  * Correct documentation of INI format's loss of type information
  * Android: add missing properties in AndroidManifest.xml
  * Fix assertion failure when parsing a doubly-invalid date-time text
  * Windows QPA: Correct mistake when calculating minmaxinfo
  * Android: replace ndk.dir with android.ndkVersion in build.gradle
  * Android: remove the old copy of gradle.properties after reading it
  * CMake Android Support: Fix signing of APKs
  * Android: fix A11Y object description
  * macOS: Fix warning about comparing different types in QCocoaScreen::isOnline
  * Fix qmake build on FreeBSD
  * Update documentation of enum Qt::DockWidgetArea
  * xcb: recreate xcb window under some conditions
  * objc_namespace: Add support for universal binaries
  * objc_namespace: Fix misspelled argument for silencing output
  * objc_namespace: Update parsing logic to account for otool changes
  * Blacklist passwordAuth for Ubuntu 20.04
  * Android: wrap QAndroidInputContext's m_focusObject in a QPointer
  * Fix compilation with GCC 12 (and on Fedora 35 and newer)
  * Chip example: fix an accidental bool->int conversion when using PMF connections
  * qmake: Add support for C++23
  * Android: use BCP 47 tag to create a correct Locale for QTimeZone::displayName()
  * QDateTime: fix adjusted datetime handling
  * Fix crash in tst_qmltc_examples on Android
  * macOS: Remove dead code for focus ring handling in Mac style
  * Detach for colortransforms of indexed formats
  * tst_QTcpSocket::connectToHostError - handle possible timeouts
  * CoreText: Avoid populating font family aliases if family was populated
  * Graphicsview: Avoid background clearing glitches under fractional DPR
  * Windows QPA: Avoid slowdown with UI Automation name change notification
  * Windows QPA: Avoid sending accessibility notifications before activation
  * Windows: Fix potential crash when retrieving default printer
  * Make Ubuntu with its non-standard security level happy
  * Android: Blacklist failing tests on tst_QGraphicsProxyWidget
  * Update LA 4.4.1
  * iOS A11Y: Set more accessibilityTraits
  * QNX: Fix compiler warning by when FEATURE_clipboard is not enabled
  * Document that native file dialogs might not show a title
  * Doc: Remove mentionings of overflows from QElapsedTimer
  * QTextMarkdownImporter: don't apply text char format to list item block
- Commits dropped by the rebase:
  * QBuffer: add missing <limits> include
  * Fix developer build
* Wed May 24 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.9+kde154:
  * Hsts: match header names case insensitively (CVE-2023-32762,
    QTBUG-113392, bsc#1211797)
  * Fix specific overflow in qtextlayout (CVE-2023-32763,
    QTBUG-113337, bsc#1211798)
  * QDnsLookup/Unix: make sure we don't overflow the buffer
    (CVE-2023-33285, boo#1211642)
* Tue May  9 2023 Fabian Vogt <fvogt@suse.com>
- Amend patch to fix mouse grabbing as well (bsc#1211024):
  * big-endian-scroll.patch
* Fri Apr 21 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.9+kde151, rebased upstream:
  * QCborValue: fix incorrect to{Array,Map} when the value is empty
  * QMargins: fix a missing "full stop" in the docs
  * QLibrary: restore translated string
  * QLibrary: fix possible arg() format clobbering
  * iOS: Use python3 for enumerating test target devices
  * Android: Treat ACTION_CANCEL as TouchCancelEvent
  * Doc: Fix broken formatting
  * QFileSystemEngine: fix potential formatting error
  * QString::asprintf: check that passing field widths as arguments works
  * Backport recent QFlags tests
  * network: Fix typos in documentation
  * Fix accuracy with screen composition
  * Doc: Update documentation for QElapsedTimer's in Windows
  * Document that QStandardPath::findExecutable works with absolute paths
  * macOS: Use native resize cursors for diagonal resize
  * Fix clipped glyphs in text rendering of QGraphicsTextItem
  * Change comparison data type to fix int overflow
  * Add missing Q_WEAK_OVERLOAD definition
  * Update QFileInfo docs to mention macOS aliases
  * Distinguish macOS aliases from normal symbolic links
  * Windows QPA: Fix frameless maximize on secondary screens
  * Rewrite tst_qdataurl as a data-driven test
  * Fix compilation for wasm
  * QIOSFileDialog/QIOSDocumentPickerController - handle dismissed view controller
  * Fix QDockWidget's dock area permissions after hovering
  * Fix C++20 ambiguous relational operators between QJsonValue{,Ref}
  * Android: make sure that orientationChange is reported after resize
  * Android: set all QScreen's geometry-related parameters together
  * Blacklist: test cases blacklisted in tst_QDBusConnection:
  * wasm:  fix issue with passing username/password to network request
  * macOS: Pass multi arch flags when linking qmake
  * QCocoaFileDialogHelper: Always enable symlinks and aliases to directories
  * Android: terminate argv passed to main() with nullptr
  * Update bundled libjpeg-turbo to version 2.1.3
  * ANGLE: Load the DirectX libraries from the system path directly
  * SQLite: Update SQLite to v3.37.2
  * Fix compiler warnings about unused parameters
  * Fix getsockopt option_value initial initialization
  * Http2: Fix redirect-handling
  * Android A11Y: Fix value rounding
  * Android A11Y: Announce value together with element name when focused
  * Android A11Y: handle valueChanged events
  * tst_QSystemSemaphore: give proper path to test-helper
  * QNX: Silence compiler warning by initializing variable
  * Update LICENSE.QT-LICENSE-AGREEMENT
  * winrt appxmanifest: Properly replace VCLibs version for newer MSVC versions
  * QAbstractSocket: Don't pretend pause and resume is a stack
  * Gui: test also depends for clipboard feature
  * QDesktopServices: deprecate destroying URL handlers w/o explicit unsetUrlHandler()
  * macOS: Respect QMAKE_APPLE_DEVICE_ARCHS when building qmake
  * HTTP: Make redirect response parsing more generic
  * BLACKLIST: tst_QGlyphRun::mixedScripts for Ubuntu 20.04
  * Android A11Y: populate child elements when constructing node info
  * Fix issue where readyRead() could happen after disconnected()
  * QStringView: add missing constexpr so we can use is_constant_evaluated
  * Use Android's View.generateViewId() for generating ids for views/surfaces
  * Remove documentation of non-existing QAccessible state
  * Doc: Fix snippet to match actual QFileInfo behavior
  * Android: Re-focus focused accessibility node after orientation change
  * Android A11Y: execute C++ code on main Qt thread
  * Android: extract parentId for hidden object in advance
  * xcb: Show valuator atom names properly in categorized logging
  * Android: replace stacktrace with debug message in search for setService
  * Better document attaching a QFutureWatcher to a started QFuture
  * doc: Update GenericDataLocation location on iOS
  * BLACKLIST test_Gestures tests for RHEL-8.4
  * QPlainTestLogger: do not print "failure location" if there's no failure
  * QAbstractItemView: do not access invalid model indices (3/N)
  * Win32: always allow the event loop to be woken up by posted events
  * rhi: d3d11: Use __uuidof where we can
  * Don't QEXPECT_FAIL tst_QLineEdit::testQuickSelectionWithMouse on macOS ARM
  * Network: Emit authenticationRequired when using Ntlm
  * testlib: Disable window restoration on macOS in a non-persistent way
  * QAbstractItemView: do not access invalid model indices (2/N)
  * QAbstractItemView: do not access invalid model indices (1/N)
  * QAbstractItemView: code tidies
  * Update float16 part of TestLib selftest
  * QGuiApplication: constant-initialize lastCursorPosition
  * Blacklist tst_QFileSystemWatcher::signalsEmittedAfterFileMoved on all Windows versions
  * [Android]: Handle the screen name, modes and refreshRate properly
  * QVersionNumber: remove the "pure" attribute from commonPrefix()
  * QEvent: initialize the static userEventTypeRegistry constexprly
  * Let QXcbGlxWindow::createVisual fallback to QXcbWindow::createVisual
  * Android A11Y: fix content update notification when object is hidden
  * Android: explicitly remove accessibility focus when element is hidden
  * BLACKLIST tst_qfont for Red Hat 8.4 and Ubuntu 20.04
  * QtCore: includemocs
  * Fix memory leak in QtConcurrent::run when called with a NULL QThreadPool
  * INTEGRITY: Prevent deletion of virtual functions
  * QMake: replace a Q_ASSERT() with a Q_UNREACHABLE()
  * QTransform benchmark: measure what was promised
  * QStaticByteArrayMatcher: add a useful comment
  * QMacStyle: use the 'momentary push in' type for push buttons
  * qopengl.h: Move C header #include(s) out of the QT_NAMESPACE
  * Enable all supported 1.0 device features in QVulkanWindow
  * Fix queue passed to vkQueuePresent
  * QFusionStyle: don't draw an invalid outline for up/down buttons
  * Doc: Make QListIterator snippets more robust
  * QVersionNumber: don't detach() in rvalue QList/QVector ctor
  * QNetworkRequest: Document how Qt handles 301 and 302 status codes
  * Convert date-time to UTC before claiming it's in GMT
  * Remove execute permission from XML files
  * Add test case for style sheet selectors for enum properties
  * FreeType: allow falling back to synthesized bold if desired
  * Fix an assertion failure in massageAdjustedDateTime()
  * Relax tst_qvulkan::vulkanVersionRequest to make it compatible with 1.1
  * Doc: Replace "C:Documents and Settings" paths
  * QOrderedMutexLocker: fix compilation with C++11
  * QHttpNetworkConnection: Always set proxy settings to all channels
  * Add a markdown writer test for a checklist item ending with `code`
  * Use QTextCharFormat::fontFixedPitch to remember Markdown backtick spans
  * QWizardLayoutInfo: make == and != operators const
  * Revert "Android: Fix screen flicker issues"
  * macOS: Handle momentum scroll NSEventPhaseBegan when scroll had ended
  * SQLite: Update SQLite to v3.37.0
  * Update copyright year to 2022
  * QTzTimeZonePrivate: use ctor delegation instead of init()
  * QTzTimeZonePrivate: fix permanently-detaching m_icu
  * tst_QGraphicsView: fix memleak
  * Doc: Update external links to Qt Creator Manual
  * macOS: assume an unidentified tablet device is a stylus
  * tst_QItemModel: fix memleaks
  * tst_qanimationgroup: fix memleaks
  * QAbstractAnimation: add missing forward-declaration
  * [doc] QCoreApplication::installTranslator() doesn't take ownership
  * tst_qtranslator: fix memleak
  * QTestData: fix streaming of u8 string literals in C++20 mode
  * QThread/Unix: extract duplicate code
  * QWindowPrivate: fix inconsistent inline on some methods
  * tst_QStringList: check that join(u'0') embeds NULs
  * macOS: Sanitize scroll deltas for NSEventPhaseCancelled
  * tst_qsharedmemory: skip readOnly() test under asan
  * QXmlStreamReader: update test distribution
  * QZipReader: update to unzip partly broken archives
  * Deliver context menu event with correct coordinates to widgets in popups
  * QTextHtmlParser: fix prefix lookahead and html comments
  * QtConcurrent::run crashes on program exit
  * tst_QPropertyAnimation: fix leaks occurring under normal operation
  * tst_QPropertyAnimation: fix wrong comment
  * QLogging: fix potential missing NUL-terminator when calling OutputDebugString
  * Fix qt_scrollRectInImage when scrolling outside of the image
- Commits dropped by the rebase:
  * Fix compile with Qt5: Use QString::mid instead of QString::sliced
  * Restore C++11 compatibility after e8b9f4c28d3ab5e960dc54f2dc0c4b749b0b50e0
  * QDateTime: Don't require c++17
* Mon Apr  3 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.8+kde185:
  * QFSFileEngine: fix overflow bug when using lseek64
  * Add QImage null check when QOpenGLTexture converts
- Add patch to fix return key handling in QGroupBox on GNOME (bsc#1209364):
  * 0001-Revert-QGnomeTheme-Allow-Space-Return-Enter-and-Sele.patch
- Add patch to fix XInput2 events in big-endian X11 clients (bsc#1204883, QTBUG-105157):
  * big-endian-scroll.patch
* Thu Mar 16 2023 Fabian Vogt <fvogt@suse.com>
- Update to version 5.15.8+kde183:
  * Add nullptr guard in QStyleSheetStyle::drawPrimitive(PE_PanelLineEdit)
  * QAbstractItemView: don't access invalid indexes on copy-key
  * Apply CVE-2023-24607-qtbase-5.15.diff (CVE-2023-24607,
    bsc#1209616)
  * QXcbConnection::getTimestamp: do not return stale timestamp
  * QToolButton: Elide text when constraints prevent from showing whole text
  * correctly set up ref counting in QThreadPool::tryStart(std::function)
  * Do not set Qt::ToolTip flag for QShapedPixmapWindow
  * Fix deletion order also for QImageReader/Writer::setDevice()
  * Fix deletion order in QImageReader/Writer destructors
  * QNetworkReply: Fix typos in the documentation
  * Doc: Fix typo in the online documentation template
  * Doc: Link to page documenting Qt trademarks in the copyright footer
  * [doc] Fix typo in QBuffer::setBuffer() description
  * qwindowsdrag: Fix typo in documentation
  * openglblacklists: Fix typo in description
  * qxcbscreen: Fix typo in documentation
  * Fix typos in SQL driver documentation
  * qxcbwindow.cpp: Fix sign-compare and another warnings
  * QToolButton: reimplement the fix for QTBUG-95255
  * QSysInfo::prettyProductName(): Add macOS Ventura product name
  * QSysInfo::prettyProductName(): add missing macOS product names
  * xcb: correctly disconnect xsettings callbacks
  * ibus: add SetCursorLocationRelative in InputContext.xml
* Thu Mar  2 2023 Fabian Vogt <fvogt@suse.com>
- Drop the mechanism for supporting systems without SSE2. glibc removed
  support for looking up libraries in sse2/ subdirectories and
  qtdeclarative without SSE2 crashes Plasma (boo#1208188)
* Mon Jan  9 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.8+kde160, rebased upstream:
  * Set geometry property in QXcbWindow after checking minimum size
  * Fix potential corruption with image format conversion on arm neon
  * TLS backend SecureTransport: properly clear SSLContextRef
  * Widgets: Use effect region bounds when drawing with repaint manager
  * Revert "xcb: stablilize xkb state when keymap updated"
  * forkfd/linux: add support for LoongArch
  * Fix default QT_ARCHS for non-universal builds
  * Add the missing -mfpu=neon CXX flag
  * Fix missing characters or assert with certain font sizes
  * tst_containerapisymmetry: test ranged ctors with pure input_iterator types
  * qmake/Xcode: Mark "Qt Preprocess" build phase as always out of date
  * Windows QPA: Fix cursors getting out of sync after restoring override cursors on native windows
  * evdevkeyboard: Try opening as read-write first
  * QVarLengthArray: add some basic checks for default-ctor
  * QTableWidget doc: remove wrong comment for itemExpanded()
  * Blacklist tst_QTimer::zeroTimer on Ubuntu 20.04
  * Use Yu Gothic UI as the main fallback font for Japanese
  * qxkbcommon: UCS-4-encode surrogate characters in QKeyEvent::key()
  * Replace CopyrightFile entry in libjpeg qt_attribution.json
  * androiddeployqt: Fix signing of paths with spaces
  * OpenSSL: handle renegotiate errors by comparing certs
  * Update latest qt license agreement
  * QFontDatabase: unify relevant documentation pieces
  * wasm: Fix assert/crash when tooltip window is closed and mouse moved
  * Freetype: adjust underlinePosition to match our expectations
  * SignalTransition: guard against deleted object
  * tst_QSslSocket: QSKIP the test that is known to fail with SecureTransport
  * QStringView: fix split(QRegularExpression) returning invalid data
  * Check that QStringView::split() w/rvalue QRegularExpression returns valid data
  * Teach QOpenGLTextureBlitter about GL_TEXTURE_RECTANGLE textures
  * Doc build: fix conflicting response file with moc
  * QTextDocument: fix an off-by-one in the changed signal for lists
  * Fix warnings due to enums in QSizePolicy
  * Android: Set sem_wait m_terminateSemaphore behind an atomic flag
  * QGraphicsItem: Update input context after InputMethod event
  * QSharedPointer: fix counter-productive QT_PREPEND_NAMESPACE use in qHash() impl
  * tst_qhashfunctions: check qHashRange{,Commutative}() find hidden friend qHash()
  * xcb: stablilize xkb state when keymap updated
  * Stabilize tst_QAccessibilityMac
  * Handle macOS 11 issues in softHyphens test
  * QVERIFY_EXCEPTION_THROWN: re-throw unknown exceptions
  * QAuthenticator: Filter out algorithms we don't support
  * QNX: QNX7.1 updates
  * Blacklist tst_QTcpServer::linkLocal on macOS ARM
  * Blacklist problematic network auto-tests on macOS ARM
  * Blacklist and skip failing tests on macOS ARM
  * Windows QPA: Fix multi-touch support in some devices
  * freetype/no-fc: Disambiguate fonts with different widths
  * Skip disabled proxy widgets when (back)tabbing
  * Explicitly use libc++ when creating machtest stubs
  * Don't pass CXXFLAGS when creating machtest stubs
  * QFontComboBox don't response qApp fontDatabaseChanged()
  * Update architectures in machtest to arm64+x86_64, removing i386 and ppc
  * Android: bump default QT_ANDROID_API_VERSION to 31
  * macOS: Disable PCRE JIT when running under Rosetta
  * macOS: Add helper function to check whether we're running under Rosetta
  * testlib: Disable automatic backtrace when test crashes on macOS on ARM
  * macOS: Hard-code NEON and SSE/SSE2 when building universal builds
  * macOS: Always disable pixman NEON drawhelpers
  * macOS: Scope Haswell arch flags to x86_64 compilation units
  * Guard AVX parts of qfloat16 helpers instead of emitting error
  * Granularily disable PCRE2 JIT on macOS ARM
  * Avoid claiming F16C support on non-x86 platforms
  * macOS: Respect QMAKE_APPLE_DEVICE_ARCHS by building for all those archs
  * qmake: Pick default architecture on macOS based on uname
  * macOS: Don't hard-code x86_64 as the architecture when using qmake
  * qmake: Support Visual Studio 2022
  * Avoid painting outside boundaries when printing QGraphicsProxyWidget
  * wasm:  fix network reply status attribute
  * Update Gradle to 7.2.0 and Android Gradle Plugin to 7.0.2
  * wasm: fix size of QDialogs
  * plaintextEdit draw text with clipRect should consider cusorWidth
  * iOS: Hide UIWindow before restoring mirror mode
  * iOS: Defer restoring screen mirroring until next runloop pass
  * macOS: Bump max supported SDK version to 12
  * iOS: Don't try to initialize a11y for views that have no platform window
  * qnsview_mouse, scrollWheel: do not assume zero deltas on Ending phase
  * PCRE2: upgrade to 10.39
  * wasm: fix deadlock when thread calls exit
  * Fix version number when warning about Apple platform SDK mismatch
  * Doc: Add styling for note/warning/important admonitions
  * wasm: disable the canvas resize observer
  * wasm: fix window activation
  * Fix show()/hide() for child windows on xcb
  * Add warning about QCoreApplication deferred delete
  * Fix performance regression when avoiding scrollbar flipping
  * wasm: fix changing cursor shape
  * QSKIP tst_qgl:closeAndThenShow() because of flaky crashes
  * Calculate effect bounds when drawing widget graphics effect
  * Fix treemodelcompleter example
  * gl: Try the local CacheLocation when the shared one fails
  * Android: set EXTRA_TITLE to the initially selected file in save dialog
  * qmake/vcxproj: Fix malformed <Message> tags
  * qmake/vcxproj: Fix "CONFIG += combine" extra compilers
  * Android: set allowNativeHeapPointerTagging to false in the manifest
  * Update windows version detection
  * Don't link against pthread when using cxx11_future on vxworks
  * Accessibility Linux: Fix caps lock state
  * Don't render widget to backing store if its parent has graphics effect
  * Handle DPR in QPainter's drawing methods taking a brush parameter
  * XCB: Silence clipboard warning "SelectionRequest too old"
  * QVector: Don't require default-constructible types with insert()
  * Android: Hide the keyboard when the height is less than 0
  * When filling a pixmap after an assignment ensure the set DPR is not lost
  * Fix high DPI position of foreign child windows on Windows
  * QOpenSSLBackend: Properly load 3.0 when compiled with 3.0
  * Take overshoot into account when laying out QAbstractScrollArea
  * Add suffixes to loop variables for Q_FOREACH
  * Android: Fix handling of cursor position when stop composing
  * Windows QPA: Fix mouse event position for QWindows with Qt::WindowTransparentForInput
* Thu Dec 15 2022 Fabian Vogt <fvogt@ritter-vogt.de>
- Update to version 5.15.7+kde177:
  * Fix wrong to linear conversion
  * QKeySequence: Add missing modifier names
  * Scale BMP color samples with periodic bit expansion
  * Send accessible focus event after list view has focus
  * update function argument of SSL_CTX_set_options
  * Openssl backend: reinsert a missing C in qCDebug
  * Annotate QMutex with TSAN annotations
  * Handle allocation failure in QImage rotate 90/180/270 functions
  * xcb: Replace qCWarning by qCDebug in QXcbConnection::printXcbError()
  * a11y: support GetAccessibleId for at-spi
- Drop patches, now upstream:
  * 0001-Fix-wrong-to-linear-conversion.patch
* Tue Dec  6 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix text rendering on 16bit X11 surfaces (boo#1205585):
  * 0001-Fix-wrong-to-linear-conversion.patch
* Thu Nov  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.7+kde167, rebased upstream:
  * offer an opt out of automatic xdg-desktop-portal use
  * Send string to Atspi DBus interface on name/description changed
  * Send string to Atspi DBus interface on value changed for comboboxes
  * iOS: Use generic simulator device for building apps via xcodebuild
  * xcode: Allow automatic provisioning updates when calling xcodebuild
  * Revert "[Android] Remove signal and slot mechanism to listen states in editor's"
  * Android: fix error when signing bundles
  * Doc: Fix notes in QObject
  * Allow dragging of a floating dockwidget on macOS with a custom titlebar
  * Http/2 - handle PADDED flag correctly
  * QTlsBackend (OpenSSL) : detect incompatible versions
  * Reduce the width of a hfw-widget if scrollbar would be flipping
  * QCocoaWindow: Make window key if the app's modal window is hidden
  * Doc: clarify case sensitivity in QCompleter
  * Doc: Note that qmake's CONFIG values are case-sensitive
  * Clear up QWindow::isActive() documentation
  * QWinRtFunctions::await() - introduce early exit condition
  * rhi: metal: Use the layer as the single source of truth
  * Include <QHash> explicitly
  * Update PCRE2 to 10.38
  * Add testing of QPdfWriter output to QPainter lancelot test
  * Update the COPYRIGHT.txt file
  * QTranslator: Fix loading of meta catalogs from absolute .qm path
  * tst_qtranslator: Simplify extraction of test data
  * Cocoa: Don't call makeKeyAndOrderFront for native app-modal dialogs
  * Fix querying font aliases that share name with other fonts
  * Update bundled libjpeg-turbo to version 2.1.1
  * macOS: Compute NSWindow background color without checking styleMask
  * SQLite: Update SQLite to v3.36.0
  * Android: Fix path of qmake_qmake_immediate.qrc in single_abi with qmake
  * qmake: Print error when iOS simulator device could not be found
  * Fix loading of OpenSSL on macOS versions that ship its own OpenSSL
  * QWidgetWindow: Stabilize test on Xcb
  * Blacklist flaky test
  * Fix license information for libjpeg-turbo
  * Don't unload libraries on Darwin-based operating systems
  * QThreadPool: Fix restarting of expired threads
  * Make test pass on machines with many cores
  * Blacklist tst_QSocks5SocketEngine::simpleConnectToIMAP() because of flakiness
  * Blacklist tst_qgl:closeAndThenShow() because of flakiness
  * Update Android default SDK from 29 to 30
  * Make clear why QTestLog::addB?XFail() don't add to counters
  * Fix .qm file name calculation in lrelease.prf
  * qmake/xcode: Do not create OBJECTS_DIR
  * QSslCertificate(OpenSSL plugin): fix memory leaks in extension 'parser'
  * OpenSSL: Let people opt-in to use TLS 1.3 PSK callback
  * tst_http2: Fix flaky authentication test
  * Cocoa: Make sure we can display multiple sheets for the same NSWindow
  * Fix QTextCodec::canEncode() for ICU codec
  * wasm: fix network data URI scheme
  * Doc: add more notes about full screen windows on macOS
  * macOS: Don't rely on invalidateCursorRectsForView when mouse is over view
  * Doc: add note that hiding a window doesn't close a full screen space
  * qlocale_win: Fix non-standalone month names
  * androiddeployqt: Check if apk is already aligned
  * Fix corner case in QTimeZonePrivate::dataForLocalTime()
  * Improve lancelot test of dashed line painting
  * qmake: Add support for C17/C18
  * qmake/vcxproj: Read C language standard from QMAKE_CFLAGS
  * qmake/vcxproj generator: Handle C standard compiler flags
  * qmake: Make it possible to set CONFIG += c11 with MSVC 19.28
  * qmake: Recognize MSVC 16.x as VS 2019 in the VS project generator
  * Doc: Replace the example for QFileInfo::setFile
  * QMetaEnum: avoid quadratic behavior in valueToKeys()
  * QGraphicsProxyWidget: forward Window(De)Activate events
  * QDashStroker: cap the number of repetitions of the pattern
  * Fix bug with NoFontMerging when font does not support script
  * Android: Fix unnecessary clipboard data access
  * macOS: Don't wipe NSWindowStyleMaskFullSizeContentView if set manually
  * Fix broken build when LTTng tracing is enabled
  * Attempt to unwedge tst_QThread::wait3_slowDestructor()
  * macOS: close popups on mousedown within the window frame
  * Use a scope-guard to take care of process deletion in a test
  * QVarLengthArray: add missing default-ctor documentation
- Commits dropped by the rebase:
  * Fix compile of tst_qimage in Qt5
* Fri Sep 30 2022 fvogt@suse.com
- Update to version 5.15.6+kde178:
  * ANGLE: Fix compilation on GCC 11
* Mon Sep 26 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.6+kde177, rebased upstream:
  * QStringIterator: fix UB [2/2]: use std::less to compare pointers
  * QStringIterator: fix UB [1/2]: use has{Next,Previous}() more
  * Assert validity in QStringIterator's unchecked methods
  * eglfs: Fix crash when painting the mouse cursor in a multiscreen setup
  * xcb: fix the build of native painting
  * QNetworkReplyFileImpl: Don't emit 'finished' in the ctor
  * Fix typo in code
  * Fix typo in QAbstractItemModelTester
  * sqldrivers: Fix typo in error message
  * network: Fix typos in messages
  * Remove XCB_EVENT_MASK_RESIZE_REDIRECT for Qt:WindowTransparentForInput
  * Fix build without dbus support
  * Revert "Remove the dead code for blocking methods from QtConcurrent"
  * QAIV: Reset double-click flag in mousePressEvent
  * Fix possible undefined behavior in clear_thread_data
  * Revert "xcb: implement missing bits from ICCCM 4.1.4 WM_STATE handling"
  * 3rdparty: apply a fix to the last zlib fix
  * add color picking support on wayland using the XDG desktop portal
  * Use class scope to refer to static function
  * fix AT_SPI_BUS_ADDRESS actually working
  * 3rdparty/zlib: backport the fix to CVE-2022-37434
  * widgets: avoid setting X11BypassWindowManagerHint in QToolBar
  * Don't access QObjectPrivate::declarativeData unguarded
  * Apply CVE-2022-27404-27405-27406-qtbase-5.15.diff
  * xcb: Update _NET_SUPPORTED when the window manager changes it
  * Revert "CUPS: Add support for accessible IPP printers"
  * QtConcurrent::ReduceKernel: fix race conditions
  * Fix crash in QKmsDevice::createScreenForConnector
  * Fix compile with MinGW-W64 9.0.0: Redefinition of 'struct _FILE_ID_INFO'
  * Fallback to another file dialog implementation when XDP is inaccessible
  * Add QXdgDesktopPortalFileDialog::useNativeFileDialog()
  * qmake: Ignore stderr when determining the macOS SDK version
  * Fix QDBusInterface crashing with empty path on construction
  * Network: Update expired cert
  * Android: guard getStateCount() with correct VERSION.SDK_INT
  * Add note on selecting the device which is used to run tests on Android
  * fc: Clean up current config on shutdown
  * Doc: Add see also links to operator== and operator!=
  * Fix framework dependencies in .la files
  * Fix Style java code format and warnings
  * wasm: fix network crash on abort
  * Update bundled Freetype to 2.10.4
  * CMake: Prevent multiple creation of the targets 'aab' and 'apk'
  * Android: Fix fullscreen bottom bar hide issues
  * xkb.compose: get locale from user env settings
  * xcb: implement missing bits from ICCCM 4.1.4 WM_STATE handling
  * macOS: Fix leaked NSMutableArray in applicationActivationChanged
  * StyleSheet: Use rule for ComboBox in embedded QLineEdit
  * Fix hidden API access for Android style
  * Fix memory leak if eXIf has incorrect crc
  * Fix invalid snippet reference in qtnetwork-index.html
  * Doc: Fix QList<T>::fromVector example in QList<T> documentation
  * Turn off feature timezone for emscripten
  * QXpmHandler: actually limit characters-per-pixel to four
  * QXpmHandler: fix re-entrancy bug in xpm_color_name
  * QObject: cleanup the orphaned connection lists on destruction
  * Fix crash in concurrent disconnect
  * cleanOrphanedConnectionsImpl: Allow to skip locking
  * QOrderedMutexLocker: Disable copy and provide explicit dismiss function
  * Handle even more include in enum cases
  * macOS: Stop relying on balanced CGDisplay reconfiguration callbacks
  * QFuture: fix result reporting in the filter mode
  * Doc: Minor cleanup in QWidget docs
  * Don't report results when the results list is empty
  * Windows QPA: Fix coordinates reported through UI Automation
  * Make QSqlRecord benchmarks non-fatuous
  * Halve the data-set size of tst_QSqlRecord::benchmarkRecord()
  * Update deprecated NSAccessibility method
  * H2: emit encrypted for at least the first reply, similar to H1
  * QFile benchmark: only set up and tear down the data directory once
  * Unify and clean up two identical tst_qfile::*_data() functions
  * Move QSKIP()s to _data() functions in QFile benchmark
  * Scale image with MDI icons using the correction factor
  * QNetworkDiskCache: Fix tracking of size during storeItem()
  * Always update the input method when QLineEdit receives focus
  * Fix qdbusperformance and qprocess benchmarks
  * QListView: don't scroll if selected items are removed
  * macOS: Detect sandboxed state for command line apps
  * Update obsoleted functionality in preparation for Qt 6
  * Change QCollator's default locale to QLocale().collation()
  * QDuplicateTracker: reserve() for at least Prealloc elements
  * Point out that QTreeView's expandAll/expandToDepth don't fetch data
  * QDuplicateTracker: fix the static buffer size calculation
  * macOS: Don't make frameless tool windows miniaturizable
  * macOS: Don't mangle QByteArray settings with @ prefix by decoding as UTF-8
  * tst_QtConcurrentThreadEngine: fix the threadCount() test
  * Fix QTextFormat::FullWidthSelection for right-to-left text layouts
  * Fix auto completion in QFileDialog on Windows
  * QFile benchmark: always use Unbuffered for QFSFileEngine tests
  * Fix QDirIterator benchmark to actually find its test data
  * macOS: Keep NSWindow alive after handling windowShouldClose callback
  * Windows QPA: Fix dock widget drag&drop failure
  * Remove the dead code for blocking methods from QtConcurrent
  * QtConcurrent: call the non-blocking versions in blocking ones
  * macOS 10.15: Fix focus frame for combo boxes
  * Fix placement of placeholder text in QLineEdits with action icons
  * macOS: fix separator actions not showing in menus
  * QIcc: Update test for invalid values
  * Doc: Use https for links to unicode.org
  * Doc: Add a note about a limitation in QDockWidget on macOS
  * macOS: Notify socket notifier on connection error
  * QGlobalStatic: fix warning when using cv-qualified types
  * Fix right-to-left text with DirectWrite engine + QPainterPath
  * Fix mapping between Han and other CJK scripts
  * Doc: Improve QTransform documentation
  * Documentation: Remove section advertising Amazon
  * Fix linking of debug projects against release Qt on Darwin platforms
  * Extend documentation for QFile:copy()
  * macOS: Unregister screen notification handlers on QGuiApplication shutdown
  * macOS 11: Fix positioning of focus frame around combobox
  * QString: Respect precision when reading data for %%.*s format string
  * Fix leak of transaction context handle in QSql's OCI driver
  * macOS: Allow programatically minimizing frameless windows
  * Doc: Move overrideCursor() from QApplication to QGuiApplication
  * Doc: Add note to Qt::MatchFlags about implementation dependent behavior
  * Update md4c to 0.4.8
  * Android: fix mimetype/namefilters handling for FileDialog
  * Enable glyph cache workaround for Apple M-family of GPUs
  * Fix rendering of text checkboxes when text is selected
  * Update public suffix list
  * iOS: cleanup connection when a screen disconnects
  * Windows: Read page size and orientation from setup dialog
  * qmake: Enable response files for WASM on Windows
  * QTextDocumentFragment: fix ifdef range
  * Update CLDR qt_attribution.json
  * Hangul composition: use < base + count checks, not <= checks
  * Doc: Fix snippet for QRandomGenerator64 docs
  * Fix date parsing when local time lacks the start of the day
  * Fix misplacement of placeholder text in QLineEdit with RTL content
  * Fix unaligned specialData formats
  * QWidgetTextControl: ignore GroupSwitchModifier for BackSpace
  * QFlags::testFlag: clarify the behavior in the docs
  * Android: Fix build error issue in examples
  * Silence misleading exception print in setQtContextDelegate
  * Fix scrolling of tab bar when the visible tab is wider than the visible space
  * Fix augmentation of UI language list
  * Calculate space requirement of menu items based on widest elements
  * Correct examples for int validation in QValidator documentation
  * tst_QTimer::remainingTime(): get rid of QTest::currentTestFailed()
  * macOS: allow Qt::AA_DontShowShortcutsInContextMenus overrides
  * Fix conversion of swap interval from QGLFormat to QSurfaceFormat
  * Fix rearranging of icons in listview via drag'n'drop
  * Fix flaky QTimer::remainingTime() test
  * tst_QDateTimeEdit::editingRanged(): use QScopedPointer
  * QAbstractItemView: don't block dragging after double click
  * xcb: Add more debug info for XCB_INPUT event
  * QPageSize: make PageSizeId ctor non-explicit
  * QtGui/math3d : Fix QQuaternion::getEulerAngles
- Commits dropped by the rebase:
  * Restore C++11 compatibility of QSharedPointer code
- Refresh 0001-Add-remote-print-queue-support.patch
* Fri Jul  1 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde166:
  * Drop call to setPlatformScreen in QHighDpiScaling::setScreenFactor
    (kde#450443)
* Mon Jun 27 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.5+kde165, rebased upstream:
  * QArrayData: fix UB via reinterpret_cast (crash with FORTIFY_SOURCE=3)
  * Fix compile of tst_qimage in Qt5
  * SQLite driver: fix crash when binding a QByteArray/QString
  * H2: remove a rather useless limit on the number of streams
  * Revert "Qt xcb: remove false detects of Qt::GroupSwitchModifier"
  * Revert "Windows: Add synthesized fonts also when there is a style name"
  * Revert "Android: Place cursor correctly on screen when editing"
  * QAbstractButton/QComboBox/QGroupBox: static_cast event->key() to Qt::Key
  * Widgets: use QPlatformTheme::ButtonPressKeys for pressing buttons
  * QBuffer: add missing <limits> include
  * QBuffer: fail early in seek() beyond QByteArray's max capacity
  * xcb: fix cursorTheme update issue
  * QDBusMenuConnection: Close open D-Bus connection
  * Fix QGuiApplication command line options documentation for X11
  * QColorSpace: Guard against division by zero
  * Preserve QImage metadata when converting format with color table
  * Unicode: fix the grapheme clustering algorithm
  * Ignore window icon in XCB when its size exceeds maximum request length
  * QAbstractItemDelegate: fix rect given to tooltip handing
  * QXmlStreamReader: fix integer truncation (qint64 → int)
  * QShader: fix memory leak in detach()
  * QDesktopServices: fix ABA problem in QOpenUrlHandlerRegistry
  * Unix: Correctly update options pane for PDF printer
  * JSON: When clearing duplicate object entries, also clear containers
  * Remove unused internal flag from raster painting engine
  * CUPS: Add support for accessible IPP printers
  * Initialize m_exclusive in QGtk3MenuItem constructor
  * Fix data race in QCoreApplicationPrivate::sendThroughApplicationEventFilters()
  * Fix a leak of fallback dialog helper in xdgdesktopportal
  * QCOMPARE/QVERIFY: fix huge pessimisation in QTestResult
  * QPushButton/fusion style: don't ignore QIcon::On icon
  * QAbstractItemModel: fix persistent index corruption when moving columns
  * Fix data race in QObject::moveToThread()
  * QReadWriteLock: fix data race in stateForWaitCondition()
  * QReadWriteLock: fix another data race in stateForWaitCondition()
  * QReadWriteLock: fix data race in dtor
  * Revert "a11y: Do not cache classes that don't have a factory plugin"
  * Prevent crashing when FcFontList fails
  * Fix race condition in futex-based QSemaphore
  * Fix a QDBusConnection crash with pending calls when connection is closed
  * Revert "Support family names that end/start with space"
  * QProcess/Unix: ensure we don't accidentally execute something from CWD
  * Fix compile with Qt5: Use QString::mid instead of QString::sliced
  * testlib/qasciikey: Add keypad navigation keys
  * QGnomeTheme: remove unneeded Q_D
  * QGnomeTheme: Allow Space, Return, Enter and Select to press buttons
  * QPA: add ButtonPressKeys ThemeHint
  * Update bundled zlib to version 1.2.12
  * QAction: Add NOTIFY changed declaration to priority property
  * QHostInfo/Unix: Fix resolv never unloading
  * QCompleter: fix crash when setting the same model twice
  * Windows: use QSystemLibrary instead of LoadLibrary directly
  * Qt namespace: fix QT_Q_FLAG declaration for Qt::MouseEventFlags
  * Sync QPrinter orientation when PageSetup Orientation selected
  * When clearing QPixmapCache, stop its flushing timer
  * QLabel::setPixmap(): remove the no-op self-masking
  * QFreeList: replace a Q_ASSERT(false) with Q_UNREACHABLE()
  * [qgenericunixservices] Consider kde-open5 for opening URLs
  * Fix check for malformed input when decoding translations
  * Test for nullptr before dereferencing the screen
  * Check for null driver() before trying to exec()
  * Fix crash when text shaping fails
  * Make QCursor::setPos() use the correct screen
  * Close leak of QOCIDateTime object
  * Fix UI mismatch when QPrinter::setDuplex
  * xcb: fix a typo for WindowTypes
  * QPkmHandler: make const what it never modified
  * Respect AT_SPI_BUS_ADDRESS env var on Linux
  * Fix integer overflow for broken QPainterPaths
  * QDesktopServices: fix UB (data race on handlers)
  * Make indicator-application hack work in flatpak
  * Fix infinite loop in dash stroker
  * QVersionNumber: remove "pure" declaration from fromString()
  * Android: Fix Application becomes unresponsive issue
  * Fix the crashes when animated QTreeWidgetItems are hidden
  * Add test for QTranslator::load() translation file lookup algorithm
  * QComboBox: add space for scrollbar if needed after showing popup
  * QComboBox: propagate style change on widget to internal container
  * QLocalSocket: fix inclusions in namespaced builds
  * PCRE2: upgrade to 10.37
  * minor: Clean up areMetricsTooLarge() conditions
  * wasm: fix unicode keyboard handling
  * Blacklist tst_QAccessibilityMac::notificationsTest
  * Let the h2 test server both send and receive DATA frames
  * Android: Reset m_usePrimaryClip when clearing the clip data
  * Android: Remove NoSuchMethodException error
  * QVector: fix compilation failure in C++20 mode w/strict iterators
  * macOS: respect underline attribute in menu item fonts
  * macOS: don't show invisible separator items
  * iOS: Accessibility: Don't cut off the last character from the text value
  * iOS: Accessibility: Set the correct traits for EditableText
  * tst_moc: fix returning-reference-to-local warning
  * Allow for arguments that have an equals as part of it
  * Write out the HTML correctly for nested lists
  * QSqlTableModel::orderByClause(): Quote the table name
  * macOS: Fix synthesized bold
  * SQLite: Update SQLite to v3.35.5
  * Qt xcb: remove false detects of Qt::GroupSwitchModifier
  * Do not remove non-widget items when removeWidget() called with nullptr
  * QFileSystemModel fails to locate a host from root's visible children
  * CMake: Fix automatic default linking of static svg plugins
  * Blacklist tst_QGestureRecognizer::panGesture
  * Moc: parse trailing return type
  * Extend tst_QGL::graphicsViewClipping blacklisting
  * Fix antialiasing of rotated non-smooth scaled images
  * Fix QUrl::fromLocalFile with long path prefix
  * Fix QStringView::mid() to behave as documented when passed -1 for length
  * QDockWidget, macOS: don't drag on native widgets
  * Add note about the risk of setting min-width/height in a style sheet
  * cocoa: be more careful about rejecting frame strut events
  * iOS: Keep undo/redo widgets enabled on the undo shortcut bar after undo
  * QTestlib: Fix formatting of pointers in QCOMPARE
  * Cherry-pick upstream patch for non-gcc/clang/msvc compilers
  * Windows: Add synthesized fonts also when there is a style name
  * Windows: Work-around misreporting of Script and Roman
  * Extend blacklisting of tst_QNetworkReply::ioHttpRedirectPolicy
  * Extend blacklisting of tst_QWidget::focusProxyAndInputMethods
  * Android: fix wrong position of cursor hander in split screen
  * Android: handle ImEnterKeyType flag
  * Apply the Core compile definitions to the big resource targets
  * Update bundled libjpeg-turbo to version 2.1.0
  * QSpdyProtocolHandler: don't rely on device being available
  * QVnc: clip requested screen region to available screen image
  * Simplify bundled libjpeg build
  * Blacklist tst_QWidget::multipleToplevelFocusCheck() on SLES 15
  * Apply specialData font capitalization to non-rawFont text
  * Avoid fast transform paint path on values it can't handle
  * Blacklist tst_QTimeLine::interpolation on Windows in general
  * QMdiArea: Fix top level window title when using DontMaximizeSubWindowOnActivation
  * Don't draw focus frame if widget has style rules that affect border
  * Fix rare integer overflow in text shaping
  * Blacklist tst_qnetworkreply::ioHttpRedirectMultipartPost on Linux
  * Android: Fix screen flicker issues
  * [Android]: Fix exception when using Qt to create a service on Android
  * Update CLDR-derived data to newly-released v39
  * QSsl: fix UB pointer use
  * uic/Python: Add comments for mypy to ignore star imports
  * HTTP/2 authentication required
  * Windows: Update the hasFrame setting when changing window flags
  * Fix mix-guided use of const reference variable
  * Android: Fix Touch event position depending on Surface
  * macOS: Don't override action set during drop handling
  * [Android] Fix select handles misplacement on QDialog
  * wasm: fix timestamp for events
  * Do not access internal allThreads data unlocked
  * SQLite: Handle tables and fields with a dot in the name correctly
  * Doc: Mark QSet::toList, QSet::fromList, QList::toSet, QList::fromSet as obsolete
  * Unicode: fix the extended grapheme cluster algorithm
  * Android: fix for isSoftwareKeyboard method
  * [Android] Remove signal and slot mechanism to listen states in editors
  * Fix prl generation with static dependencies take 2
  * QNetworkDiskCache: Drop the file mmap-ing
  * QFile::copy: call syncToDisk on destination
  * Read DPI from X Settings initially as well
  * Fix prl generation with static dependencies take 2
  * Re-add horizontal offsets around QPushButton
  * Fix ARM and MIPS runtime CPU feature flags
  * Minor robustness improvement of text code
  * Add null pointer check
  * Don't parse XML symbols longer than 4096 characters
  * Make POSIX transition rule parser more robust
  * Extend blacklisting for SLES 15
  * Doc: Improve deprecation messages for functions using  QString::SplitBehavior
  * Don't disable menu items that belong to the active modal window
  * Doc: Fix return type of QCursor::shape()
  * QPainterPath: fix handling of fill rules
  * Windows QPA: Fix accessibility focus event for table/tree/list
  * Fix invalid pointer return with QGridLayout::itemAt(-1)
  * qmake: Improve error message when detecting macOS platform SDK upgrade
  * Assert that pointer is not nullptr before dereferencing
  * QLocalSocket/Win: fix possible UB in _q_pipeClosed()
  * tst_qapplication: Prevent desktopaware test from deactivating main test
  * iOS: Disable three-finger-tap editing interaction menu when there's no focus object
  * Fix read-only pseudo-state in QPlainTextEdit stylesheet
  * QTextHtmlParserNode: Limit colspan to avoid segfault
  * Don't judge other people's writing systems
  * macOS: Don't draw scrollbar handle when there is no range
  * QSystemSemaphorePrivate: Fix a call to tr() to translate()
  * Fix condition that adds resources for each Android ABI
  * Avoid int overflow in QImage rotate90/180/270
  * Return the result we have already when getting an object with no name
  * Avoid attempting to parse insanely long texts as zone names
  * Doc: Fix typo in publisherid for WINRT_MANIFEST
  * Fix Editable Tree Model example model rowCount and model instance leak
  * FileChooser portal: send window id in hex
  * fix windows build when both whatsthis and tooltip are disabled
  * Fix incorrectly-drawn menu indicator for QPushButton on macOS
  * Fix label margins for pulldowns with custom styled menu indicator on macOS
  * Font style name 'Normal' and 'Regular' have the same meaning
  * QString: improve lastIndexOf(QRegularExpression) docs
  * eglfs: Newer Nvidia libdrm provide device instead driver module name
  * Android: KEYCODE_MEDIA_PLAY_PAUSE translated right
  * iOS: Protect against a possible crash after the window is deleted
  * Revert "Update commercial license headers to /util files"
  * Revert "Update commercial license headers to bin, mkspecs, qmake"
  * Consistently check for nullptr in QGraphicsTextItem::inputMethodQuery
  * Remove qualification for Julian calendar
  * Revert "Update commercial license headers"
  * Revert "Update commercial license headers"
  * Fix alpha handling of QImage::setPixel
  * Fix handling of virtual/native pixels in QAndroidPlatformWindow
  * Revert "Update commercial license headers to src/concurrent and src/corelib"
  * Revert "Update commercial license headers to src/dbus, src/gui, src/network"
  * Disable Harfbuzz/CoreText hotfix on older macOS/iOS versions
  * SQLite: Update to 3.35.2
  * tst_bench_qmetaobject: Fix test
  * QAsn1Element: Avoid overflow in QAsn1Element::toInteger
  * tst_qguimetatype: Avoid deprecated methods
  * Include minus sign in ImhFormattedNumbersOnly's available keys
  * MODULE_INCLUDEPATH is supposed to be one path
  * QEventDispatcher(Win): Always honor interrupted status to avoid races
  * Android: Place cursor correctly on screen when editing
  * QStylesheetStyle: fix push button label alignment
  * Support family names that end/start with space
  * wasm: fix opengl context stencil and depth buffer handling
  * wasm: fix screen offset logic
  * Android: Add grabWindow handling
  * tst_qdtlscookie: use a proper 'enterLoopMSecs' instead of 'enterLoop'
  * Update bundled libjpeg-turbo to version 2.0.6
  * QMenu test: turn tooltip animations off
  * Android: make calling exit() conditional on an environment variable
  * Limit value in setFontSizeFromValue()
  * xcb: unset old states and set new ones for window
  * Brush up the imageviewer example
  * Fix out-of-buffer in ICC curv parsing
  * Fix logic problems with table based grayscale ICC profiles
  * Reduce warnings from ICC parsing
  * QEventDispatcherWin32: get rid of the hook procedure
  * And fix handling and test of QImage::fill(uint) as well
  * Fix handling of virtual/native pixels in QAndroidPlatformWindow
  * QLineEdit: Fix editingFinished() not being emitted when pressing the clear button
  * macOS: don't let windows that are transparent for input become key window
  * QMdiSubWindow: Set correct ControlLabel size
  * Doc: Remove styling for hyperlinks from the simplified offline style
  * Doc: Offline CSS: Reduce excess vertical spacing
  * Fix parsing of dates with spaces in day or month names
  * Rework tst_QDateTime::toString_isoDate() to eliminate an XFAIL
  * Fix tst_QDateTime::systemTimeZoneChange() for 32-bit systems
  * Extend colorspace testing and fix bug it uncovered
  * Schannel: Fix incomplete downloads with read buffer restricted
  * MinGW: fix warning in QMatrix4x4::map functions
  * QRectF/Documentation: Fix malformed table
  * Fix QImage::fill with semi-transparent QColor
  * iOS: close edit menu upon focus transfer
  * macOS: Fix crash when showing parent-less platform menus
  * macOS: Remove warning about KVO observers on QNSWindow/QNSPanel
  * Filter cosmetic lines using transformed, not world coordinates
  * Fix recently added auto test of text layout overflow
  * wasm: don’t deadlock on event processing
  * Fix QNetworkInterface IsUp and IsRunning enum documentation
  * Clarify QWindowPrivate::maybeQuitOnLastWindowClosed
  * wasm: fix showing tooltips
  * Doc: Don’t use note when documenting enum values
  * macos: Document that Drawer is obsolete
  * Doc: Update the SQL types documentation with regards to the double types
  * Doc: link to QScopeGuard in QScopedValueRollback documentation
  * Doc: Online CSS: Fix image captions overlapping images used in tables
  * Turn off the dbus examples for qmake-generated VS projects
  * Don't show focus rect for QCommandLinkButton
  * Android: Fix the input type for date/time
  * qmake: Introduce compile_included_sources CONFIG option
  * Update QPalette() documentation to not mention the application palette
  * Android: Pass pending state to ResumePauseListener
  * Fix crash when requesting A32 glyph on Wayland
  * Android: Fix input method hints for ImhHiddenText
  * a11y: Report mixed state if QCheckBox is PartiallyChecked
  * testlib: Only consider major version for macOS 11 and later in blacklists
  * iOS: hide edit menu if typing on the input panel
  * xcb: Fix available geometry after rotation
  * Remove false Q_UNREACHABLE from shaping code
  * Fix trivial typo in QDateTime::fromString() overload doc
  * QTreeWidgetItem: fix documentation error for childIndicatorPolicy()
  * Update to CLDR v38.1, adding Yukon Standard Time
  * Avoid overflow in text layout
  * QJsonObject::take: add missing detach() call
  * macOS: Don't exec file dialogs via runModal unless they are app modal
  * QMimeDatabase/xml: support both 'xmlstarlet' and 'xml' for minifying XML
  * Use design metrics when adding text to QPainterPath
  * QDir/QFileInfo: add doc notes about paths starting with ':'
  * QSsl: fix OpenSSL DLL names for Windows on ARM
  * a11y: Do not cache classes that don't have a factory plugin
  * Update public suffix list to today's latest
  * Fix QTzTimeZonePrivate::displayName()'s fallback
  * Fix problems with offset-derived ids for QTimeZone
  * QLineEdit Cursor show white area
  * Correct item indent in checkable menus in stylesheet style
  * Fix read-only pseudo-state in QTextEdit/Browser stylesheet
  * Hold references to zone IDs alive during use
  * Correct string comparison in Android's IANA ID matching code
  * Doc: Add deprecation notice
  * Change QLineF::setLength() to work whenever length() is non-zero
  * macOS: Remove DontConfirmOverwrite workaround
  * macOS: Show system tray icon on mouse button press, not release
  * macOS: Don't restrict non-modal file dialogs to open-dialogs only
  * Check date validity in calendar methods taking a QDate
  * macOS: Only check SDK major version for compatibility
  * iOS: always hide edit menu when showing the magnifier glass
  * QInputControl: accept surrogate category character
  * Set new commandLink variable when initializing QCommandLinkButton
  * Test QDateTime behavior in DST gap
  * UndoFramework example: make the background visible
  * Windows: Fix flicker when resizing translucent windows with QSizeGrip
  * Windows QPA: Fix crashes when using screen reader with Q(Plain)TextEdit
  * Avoid int overflow in gradient drawing
  * macOS: Mark QFileDialog::DontConfirmOverwrite as unsupported
  * Fix QApplication::font returns the font unstable according to the object
  * Avoid overflowing QFixed in text layout
  * iOS: ensure we close the edit menu when the user taps outside the input area
  * iOS: ensure we hide the edit menu while dragging on the selection handles
  * Fix logicalDpi() which returns invalid value
  * Windows: Fix frame margins calculation
  * Widgets: fix setTabOrder for QAbstractSpinBox-like widgets
  * macOS: Add more padding to width of non-editable comboboxes
  * Make QPushButton on macOS use QFocusFrame to fix alignment problems
  * QTabBar: update index of last visible tab in insertTab
  * Fix that the placeholdertext of QCombobox is not drawn
  * Windows: Fix dialog moving up after closing/reshowing
  * Cocoa: When validating menus, account for modal window only if active
  * PSQL: Fix the QSqlDatabase test
  * Move the qmenu_p.h include to the QT_CONFIG(menu) block
  * Fix compilation of ibase sqldriver plugin, added override
  * Protect against sign-change of size on 32bit
  * Fix division by zero
  * SQLite: Update to 3.34.0
  * QODBC: Preserve the whole value when using HighPrecision
  * Set the PlaceholderText color in the palette from the stylesheet as well
  * Update commercial license headers to bin, mkspecs, qmake
  * Update commercial license headers to /util files
  * Update commercial license headers to src/concurrent and src/corelib
  * Update commercial license headers to src/dbus, src/gui, src/network
  * Stabilize tst_QListView::internalDragDropMove() on X11
  * [Android] Fix Text select handle misplaced on QDialog issues
  * Android: Finish composing text before Key handling
  * Fix regression with closing and then reopening widgets with QGLWidget
  * eglfs: Use drmClose in drm/EGLDevice backend
  * Handle maxImageCount 0 in QVulkanWindow
  * Make QCalendar's backend registration reentrant-safe
  * Blacklist flaky QListView::internalDragDropMove case on OpenSuSE
  * Update commercial license headers
  * Update commercial license headers
  * Doc: Link to correct location
  * Doc: Generalize timer docs
  * Doc: Explain how boundingRect handles null QRectF
  * Doc: Add details to QFont::toString
  * Document QOpenGLWidget limitations without an alpha channel
  * QTabBar test: refactor: extract checkPositions helper function
  * Add new special QObjectPrivate::{connect, disconnect} for QML
  * Add "Q_UNUSED" to (3rdparty) strtod.cc for a 32 bit code path
  * Android: Fix for accessibility potential crash
  * QTabBar/Windows: Fix close button icons being too small on high-res screens
  * Fix missing repaints with QOpenGLWidget in a QDockWidget
  * QComboBox/Fusion style: elide text when it's too long
  * Fix qt_alphaVersion and qt_opaqueVersion in the trivial case
  * Doc: Clarify setLibraryPaths behavior
  * Fix convertToRGBA64PM for Grayscale16
  * Fix setting active window as application's focus widget
  * Send Qt::Key_MediaTogglePlayPause for VK_MEDIA_PLAY_PAUSE
  * Fix VNC format conversion
  * Windows font engine: Silence warnings about not being able to enumate font families
  * Blacklist failing tests for WinRT
- Commits dropped by the rebase:
  * Add missing limits include
- Drop 0001-Revert-Bump-version.patch, it's versioned correctly now
- Rebase 0001-Add-remote-print-queue-support.patch
- Drop patches, now upstream:
  * mitigate-FORTIFY_SOURCE-3.patch
  * 0001-H2-remove-a-rather-useless-limit-on-the-number-of-st.patch
  * 0001-QProcess-Unix-ensure-we-don-t-accidentally-execute-s.patch
* Mon Jun 20 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix some HTTP/2 communication (boo#1200715, kde#455540):
  * 0001-H2-remove-a-rather-useless-limit-on-the-number-of-st.patch
* Fri Apr  8 2022 Martin Liška <mliska@suse.cz>
- Add mitigate-FORTIFY_SOURCE-3.patch that should mitigate
  new -D_FORTIFY_SOURCE=3 level as analyzed in GCC bug:
  https://gcc.gnu.org/bugzilla/show_bug.cgi?id=105078.
* Mon Feb 14 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update patch after it was merged to dev upstream and fix another
  place missed in the first version (boo#1195386, CVE-2022-23853,
  boo#1196501, CVE-2022-25255):
  * 0001-QProcess-Unix-ensure-we-don-t-accidentally-execute-s.patch
* Thu Feb  3 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to avoid unintentionally using binaries from CWD
  (boo#1195386, CVE-2022-23853, boo#1196501, CVE-2022-25255):
  * 0001-QProcess-Unix-ensure-we-don-t-accidentally-execute-s.patch
* Fri Jan 21 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde294:
  * QTzTimeZonePrivate::init(): fix handling of empty ID
  * Restore support for reading /etc/timezone for system zone name
  * QPathEdge: Fix array initialization
  * QTzTimeZonePrivate: fix UB (data race on m_icu)
  * Don't access QObject::objectName during QThread start
  * Restore C++11 compatibility after e8b9f4c28d3ab5e960dc54f2dc0c4b749b0b50e0
  * QVarLengthArray: fix size update on failed append()
  * Call statx() with AT_NO_AUTOMOUNT
  * QThread: Remove superfluous initialization of threadId on Unix
  * QThread: Reset the system thread ID when thread exits on Unix
  * Add missing macOS header file that was indirectly included before
  * QXcb: don't dereference pointer before checking
  * xcb: avoid to use invalid pointers
  * QVarLengthArray: fix insert() type/alias mismatch between decl and impl
  * Use qint64 to replace int while qt_transform_image_rasterize
  * QVarLengthArray: assert that the range passed to erase() is valid
  * Fix pattern type matching
  * QThread: fix UB (invalid enum value) on Private::Priority
  * Use block char format to render list item bullets and numbers
  * QDateTime: Don't require c++17
  * QVariantAnimation: fix UB (FP 0/0) in interpolated() arg calculation
  * QDateTime: fix UB (signed overflow) in addDays()
  * QString: fix UB (pointer arithmetic on nullptr) in qLastIndexOf
  * tst_QIODevice: fix UB (precondition violation) in SequentialReadBuffer::readData()
  * QVarLengthArray: fix UB (precondition violation) in range-erase()
  * Fix segmentation fault in QObject::dumpObjectInfo
* Fri Dec 24 2021 fabian@ritter-vogt.de
- Update to version 5.15.2+kde268:
  * Adapt for q_EVP_PKEY_base_id → q_EVP_PKEY_get_base_id rename in OpenSSL 3
  * Don't use a deprecated function if built/linked with OpenSSL v3
  * Diffie-Hellman parameters: remove useless 'fix'
  * Dont's use DTLS_MAX_VERSION when setting SSL_CTX
  * Avoid mixing atomic futex changes and QAtomic
  * Fix qtdeclarative baseline test failure for text tables
  * Don't let text table cells shrink below their minimum width (boo#1176530)
  * Don't shrink a column when it spans multiple columns
  * Use icon themes in QPrintPreviewDialog [if they exist]
  * QAbstractFileEngine: fix UB (data race) on qt_file_engine_handlers_in_use
  * Increment reference count when restoring reference
  * Reject truncated and corrupt ascii pnm images
  * Fix handling of Sunday in POSIX time-zone rules
  * Fix developer build
- Drop patches, support for OpenSSL < 1.1.0 is no longer necessary:
  * 0001-Lower-required-version-of-OpenSSL-to-1.1.0.patch
  * fix-build-openssl-1.1.0.patch
* Thu Oct 28 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde254:
  * Revert "QPushButton: fix support of style sheet rule for text alignment"
  * Revert "Fix invalid text layout data when a full layout run is interrupted"
  * Optimize mime type matching
  * fix potential mem leak on connection lost
  * tst_QSslSocket - replace an old certificate
  * tst_QSslCertificate::verify - remove QSKIP
  * tst_QSslCertificate::verify - skip auto-test
  * Doc: bump the OpenSSL minimum supported version to 1.1.1
  * QHttpSocketEngine: Fix memory leak
  * QSslCertificate(OpenSSL) - harden protection against nullpointers
  * QSslCertificate: Guard against accessing empty QByteArray
  * Make QStyle::proxy() always return the leaf proxy
  * Prefer previously used channels in QHttpNetworkConnection
  * Fix populating selection clipboard with keyboard
  * QSslCertificate::operator == - cleanup error queue
  * Revert "Fix highdpi conversion of QTabletEvent coordinates on xcb"
  * Fix highdpi conversion of QTabletEvent coordinates on xcb
  * Support transformations in pattern/texture brushes in pdf
  * Respect font stretch if set together with font style
  * Fix QPainterPath with QFont::SmallCaps
  * Avoid generating large pdf files when using dashed cosmetic pens
  * PDF generation: disentangle native pen from transforms
  * qmake: Switch to using Xcode's new build system
  * Explicitly set input files for qtpreprocess
  * Only embed launch screen when building an app
  * Explicitly set output files for qtpreprocess
  * Fix memory leak
  * Fix reading gamma from PNGs without ICC profile
  * QPlatformWindow: fix isAncestorOf not breaking recursion
  * Cater for upstream changes in eglplatform.h
  * QTextOdfWriter: fix exporting pixmaps to ODT
  * Fix access to content: URLs with transient read/write permissions
* Fri Aug 27 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde222:
  * Revert "QString::lastIndexOf: fix off-by-one for zero length matches"
  * MySQL: treat the MYSQL_FIELD as read-only
  * Remove checks for glibc < 2 from qplatformdefs.h files
  * linux-clang/qplatformdefs: fix building with musl libc
  * Refix for avoiding huge number of tiny dashes
  * Improve fix for avoiding huge number of tiny dashes
  * Avoid processing-intensive painting of high number of tiny dashes
  * xcb: add a timeout control when reading INCR property
  * Remove another usage of mysql_get_client_version()
  * MySQL: remove the version number checks in favor of actual functionality
  * QLibraryInfo: Add MSVC 2022
  * doCrypt() - check the error codes
  * Restore C++11 compatibility of QSharedPointer code
  * opengl: fix a typo in QOpenGLPaintDevice::dotsPerMeterY()
  * Fix rvalue overload of qobject_pointer_cast for GCC 9.3
  * QVarLengthArray: fix aliasing error in insert(it, n, v)
  * Fix memory leak of QOffscreenScreen in QOffscreenIntegration
  * Fix tst_moc for C++17
  * Add missing limits include
  * xcb: Avoid use-after-free in QXcbConnection::initializeScreens()
  * xcb: Remove need for QXCBScreen to resolve QXcbGlIntegration
  * Update shared-mime-info to the 2.1 release, adjust implementation
* Thu Jun 24 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Revert to the default platform plugin list ("wayland;xcb")
* Thu Jun 24 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Update to version 5.15.2+kde200:
  * Optimize quadratic-time insertion in QSortFilterProxyModel
* Mon Jun 21 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Switch to KDE's maintenance branch
- Update to version 5.15.2+kde199:
  * Too many changes to list here
- Add patch to reset version to 5.15.2:
  * 0001-Revert-Bump-version.patch
- Drop patches, now upstream:
  * 0001-Partially-revert-813a928c7c3cf98670b6043149880ed5c95.patch
  * 0001-Fix-allocated-memory-of-QByteArray.patch
  * 0001-Fix-build-with-GCC-11-include-limits.patch
  * 0001-Let-QXcbConnection-getTimestamp-properly-exit-when-X.patch
  * 0002-Build-fixes-for-GCC-11.patch
* Wed May 26 2021 Fabian Vogt <fvogt@suse.com>
- Add trailing newline to qtlogging.ini
* Tue Apr 13 2021 Fabian Vogt <fvogt@suse.com>
- Add patch to fix possible crash caused by GCC 11 build fix:
  * 0001-Partially-revert-813a928c7c3cf98670b6043149880ed5c95.patch
* Mon Feb  8 2021 Fabian Vogt <fvogt@suse.com>
- Add patch to fix build with GCC 11 (boo#1181861, QTBUG-90395):
  * 0001-Fix-build-with-GCC-11-include-limits.patch
  * 0002-Build-fixes-for-GCC-11.patch
* Tue Jan 19 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add patch to fix infinite loop in KWin on XServer exit:
  * 0001-Let-QXcbConnection-getTimestamp-properly-exit-when-X.patch
- Spec file cleanup, remove conditionals for Leap 42.x
* Tue Dec 29 2020 Arjen de Korte <suse+build@de-korte.org>
- Add patch to avoid excessive use of memory by lconvert:
  * 0001-Fix-allocated-memory-of-QByteArray.patch
* Fri Nov 20 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.2:
  * New bugfix release
  * For more details please see:
    http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.15.2/?h=5.15.2
  * Fallback to /tmp/runtime-$USER if XDG_RUNTIME_DIR is not set
    or is unsafe (bsc#1172515)
- Drop patches, now upstream:
  * 0001-Revert-Emit-QScreen-availableG-g-eometryChanged-on-l.patch
- Pass -confirm-license option, drop duplicates
- BuildRequire xcb-util
* Fri Nov 13 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to avoid coredumps with missing display:
  * 0001-Avoid-SIGABRT-on-platform-plugin-initialization-fail.patch
* Wed Oct 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Disable -reduce-relocations for now (boo#1175278, QTBUG-86173)
* Wed Oct 14 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Silence xcb errors and qml connection warnings by default, see
  boo#1115541 (xcb) and kde#418793.
* Mon Oct 12 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove some no longer required build dependencies: libpulse,
  alsa (now used via QtMultimedia), libmng (obsolete).
* Mon Sep 21 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Revert commit to fix screen geometry on startup (boo#1176750, QTBUG-86604):
  * 0001-Revert-Emit-QScreen-availableG-g-eometryChanged-on-l.patch
* Thu Sep 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.1:
  * New bugfix release
  * Fixes CVE-2020-17507, bsc#1176315
  * For more details please see:
    http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.15.1/?h=5.15.1
- Drop patches, now upstream:
  * 0001-Do-not-multithread-if-already-in-a-global-threadpool.patch
  * 0001-Fix-QToolButton-menus-showing-on-primary-screens-in-.patch
- Adjust fix-build-openssl-1.1.0.patch
* Sun Jul  5 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to prevent stuck image conversion (boo#1172599, QTBUG-84619):
  * 0001-Do-not-multithread-if-already-in-a-global-threadpool.patch
* Wed Jun 10 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix tool menu placement (boo#1172754, QTBUG-84462):
  * 0001-Fix-QToolButton-menus-showing-on-primary-screens-in-.patch
* Wed May 27 2020 Fabian Vogt <fvogt@suse.com>
- Add patch to avoid behaviour change causing crashes (kde#419526):
  * 0001-Revert-QMenu-hide-when-a-QWidgetAction-fires-the-tri.patch
* Tue May 26 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to 5.15.0:
  * No changelog available
* Wed May 20 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to 5.15.0-rc2
  * No changelog available
* Wed May  6 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-rc:
  * New bugfix release
  * For the changes between 5.14.2 and 5.15.0 please see:
    http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.15.0/?h=5.15.0
- Drop patches, now upstream:
  * 0001-QTextMarkdownImporter-fix-use-after-free-add-fuzz-ge.patch
- Add patch to fix build on Leap 15.1:
  * fix-build-openssl-1.1.0.patch
* Mon Apr 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix use-after-free (boo#1170582, CVE-2020-12267):
  * 0001-QTextMarkdownImporter-fix-use-after-free-add-fuzz-ge.patch
* Fri Apr 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta4:
  * New bugfix release
  * No changelog available
  * Qt incorrectly calls SSL_shutdown() in OpenSSL mid-handshake
    causing denial of service in TLS applications (bsc#1172726,
    CVE-2020-13962, QTBUG-83450)
* Tue Apr 14 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta3:
  * New bugfix release
  * No changelog available
- Add patch to fix build on Leap 15.1:
  * 0001-Lower-required-version-of-OpenSSL-to-1.1.0.patch
* Tue Mar 24 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Feb 28 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-beta1:
  * New bugfix release
  * No changelog available
* Wed Feb 19 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.15.0-alpha:
  * New feature release
  * For more details please see:
    https://wiki.qt.io/New_Features_in_Qt_5.15
- Replace patches with single patch
  0001-Don-t-white-list-recent-Mesa-versions-for-multithrea.patch:
  * 0001-Revert-Blacklist-nouveau-and-llvmpipe-for-multithrea.patch
  * 0002-Revert-qtlite-Fix-build-libs-with-no-feature-regular.patch:
  * 0003-Revert-White-list-more-recent-Mesa-version-for-multi.patch
- Refresh 0002-Synthesize-Enter-LeaveEvent-for-accepted-QTabletEven.patch
* Mon Jan 27 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.1:
  * New bugfix release
  * Fixes CVE-2020-0570, bsc#1161167, bsc#1162191, QTBUG-81272
  * For more details please see:
    http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.14.1/?h=v5.14.1
- Drop patch, should be addressed by applications meanwhile:
  * 0001-Revert-Always-escape-the-table-names-when-creating-t.patch
- Drop patches, now upstream:
  * 0001-Revert-Fix-text-rendering-regression-on-semi-transpa.patch
  * 0002-Revert-Fix-crash-with-gamma-corrected-text-blending-.patch
  * 0003-Revert-Handle-transparent-pen-color-in-fast-text-pat.patch
* Fri Dec 27 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update license tag
* Thu Dec 26 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to avoid regression with rendering of translucent text
  (QTBUG-80982):
  * 0001-Revert-Fix-text-rendering-regression-on-semi-transpa.patch
  * 0002-Revert-Fix-crash-with-gamma-corrected-text-blending-.patch
  * 0003-Revert-Handle-transparent-pen-color-in-fast-text-pat.patch
* Thu Dec 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0:
  * New bugfix release
  * For the changes between 5.13.2 and 5.14.0 please see:
    https://code.qt.io/cgit/qt/qtbase.git/tree/dist/changes-5.14.0?h=v5.14.0
  * For the changes between 5.13.1 and 5.13.2 please see:
    https://code.qt.io/cgit/qt/qtbase.git/tree/dist/changes-5.13.2?h=v5.14.0
* Wed Dec  4 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-rc:
  * New bugfix release
  * No changelog available
  * For more details please see:
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
- Drop patch, Qt behaviour changed now and applications can deal with
  it meanwhile:
  * 0001-Revert-QWidgetWindow-Immediately-forward-close-event.patch
* Tue Nov 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta3:
  * New bugfix release
  * No changelog available
- Drop libqt5-Fix-Gujarati-font.patch, didn't apply anymore:
  * Was probably fixed upstream a loooong time ago (QTBUG-44568)
* Thu Oct 24 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta2:
  * New bugfix release
  * No changelog available
  * Fix segfaults due to unaligned stack in QtCore5 (bsc#1155955)
  * Add support for PostgreSQL 12 (bsc#1173758)
- Refresh patches:
  * 0001-Revert-Always-escape-the-table-names-when-creating-t.patch
* Tue Oct 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-beta1:
  * New bugfix release
  * No changelog available
- Drop patches, now upstream:
  * 0001-tslib-plugin-remove-debug-print-on-old-tslib-version.patch
  * 0001-QWidget-setFocusProxy-adjust-focus-widget-properly.patch
* Wed Oct  2 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Disable relocatability, it breaks /usr/lib/sse2 (QTBUG-78948)
* Mon Sep 30 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.14.0-alpha:
  * New feature release
  * No changelog available
  * For more details about Qt 5.14 please see:
    https://wiki.qt.io/New_Features_in_Qt_5.14
- Refresh patches:
  * 0001-Add-remote-print-queue-support.patch
- Drop patches, don't apply anymore after upstream refactoring and the
  main bug for them seems fixed:
  * 0001-Sanitize-QXcbScreen-s-pixelDensity-values.patch
  * 0002-xcb-Use-the-screen-s-physical-DPI-as-logical-DPI-unl.patch
- Drop patches, now upstream:
  * 0001-Fix-notification-of-QDockWidget-when-it-gets-undocke.patch
  * 0001-Fix-CMake-config-files-for-libdir-different-from-lib.patch
  * 0001-Fix-qfloat16-methods-definition-without-declaration-.patch
- Enable zstd support again, issues got fixed upstream meanwhile
- Add patch to fix build against older tslib:
  * 0001-tslib-plugin-remove-debug-print-on-old-tslib-version.patch
* Thu Sep 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix focus in some cases (QTBUG-77364):
  * 0001-QWidget-setFocusProxy-adjust-focus-widget-properly.patch
* Fri Sep  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.13.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.13.1/?h=v5.13.1
- Refresh patches:
  * 0002-xcb-Use-the-screen-s-physical-DPI-as-logical-DPI-unl.patch
- Drop patches, now upstream:
  * 0001-Decrease-focusInTimer-timer-from-400-to-200.patch
  * 0003-Add-an-ID-for-recognition-of-UGEE-tablets.patch
  * 0001-Fix-crash-with-drag-cursor-handling.patch
  * 0001-Fix-meta-file-replacements-if-matches-are-empty.patch
  * 0002-Do-not-write-Libs-into-.pc-files-if-TEMPLATE-is-not-.patch
  * 0003-Make-sure-.pc-.prl-and-.la-files-are-created-for-hea.patch
- Replace reverts with upstream fix:
  * D 0001-Revert-Fix-QMAKE_PRL_INSTALL_REPLACE-for-macOS.patch
  * D 0001-Revert-qmake-link-qt-libraries-by-full-path.patch
  * D 0002-Revert-Replace-absolute-Qt-lib-dir-in-.prl-files.patch
  * D 0003-Revert-Fix-prl-replacements-if-libdir-is-in-QMAKE_DE.patch
  * A 0001-Fix-CMake-config-files-for-libdir-different-from-lib.patch
* Mon Sep  2 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix crash during Drag-and-Drop:
  * 0001-Fix-crash-with-drag-cursor-handling.patch
* Sun Aug 11 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix qmake pkconfig generation, broken .pc files become apparent
  when switching from pkg-config to pkgconf. (QTBUG-75901)
  * 0001-Fix-meta-file-replacements-if-matches-are-empty.patch
  * 0002-Do-not-write-Libs-into-.pc-files-if-TEMPLATE-is-not-.patch
  * 0003-Make-sure-.pc-.prl-and-.la-files-are-created-for-hea.patch
* Wed Jul  3 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to work around focus issues with VirtualBox
  (boo#1140084, QTBUG-76742):
  * 0001-Decrease-focusInTimer-timer-from-400-to-200.patch
* Tue Jul  2 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Link from Qt bindir into %%_bindir, not the other way around to fix
  applicationDirPath called from Qt binaries
- Add -qt5 suffix to all binaries in %%_bindir
* Wed Jun 26 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to restore compatibility with akonadi's PGSQL backend
  (see https://bugs.archlinux.org/task/62997):
  * 0001-Revert-Always-escape-the-table-names-when-creating-t.patch
* Wed Jun 19 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Disable libzstd support again, it breaks various existing codebases (QTBUG-76521)
* Wed Jun 19 2019 fabian@ritter-vogt.de
- Update to 5.13.0:
  * New bugfix release
  * No changelog available
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.13.0/?h=5.13
- Remove patches, now upstream:
  * 0001-Add-quoting-to-deal-with-empty-CMAKE_CXX_STANDARD_LI.patch
* Fri Jun 14 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patches to improve compatibility with Krita:
  * 0001-Fix-notification-of-QDockWidget-when-it-gets-undocke.patch
  * 0002-Synthesize-Enter-LeaveEvent-for-accepted-QTabletEven.patch
  * 0003-Add-an-ID-for-recognition-of-UGEE-tablets.patch
* Fri Jun  7 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Revert yet another commit to fix linker errors:
  * 0001-Revert-qmake-link-qt-libraries-by-full-path.patch
* Thu Jun  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Enable libzstd support
* Thu Jun  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Revert some commits in the hope of fixing some broken paths (QTBUG-76255):
  * 0001-Revert-Fix-QMAKE_PRL_INSTALL_REPLACE-for-macOS.patch
  * 0002-Revert-Replace-absolute-Qt-lib-dir-in-.prl-files.patch
  * 0003-Revert-Fix-prl-replacements-if-libdir-is-in-QMAKE_DE.patch
* Thu Jun  6 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix some cmake module config files (QTBUG-76244):
  * 0001-Add-quoting-to-deal-with-empty-CMAKE_CXX_STANDARD_LI.patch
* Tue Jun  4 2019 fabian@ritter-vogt.de
- Update to 5.13.0-rc:
  * New bugfix release
  * No changelog available
- Remove patches, now upstream:
  * 0001-Fix-page-breaking-with-large-images.patch
* Fri May 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to fix layouting of certain text documents (QTBUG-73730):
  * 0001-Fix-page-breaking-with-large-images.patch
* Mon Apr 29 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta2:
  * New bugfix release
  * No changelog available
- Refresh Mesa multithreading whitelist revert:
  * Add 0001-Revert-Blacklist-nouveau-and-llvmpipe-for-multithrea.patch
  * Refresh 0002-Revert-qtlite-Fix-build-libs-with-no-feature-regular.patch
  * Refresh 0003-Revert-White-list-more-recent-Mesa-version-for-multi.patch
* Thu Apr 25 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133242).
* Thu Apr 18 2019 fabian@ritter-vogt.de
- Update to 5.12.3:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.12.3/?h=v5.12.3
* Sat Apr 13 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-fixqt4headers.patch to use the include path used by our
  Qt5 packages.
* Thu Mar 21 2019 fabian@ritter-vogt.de
- Update to 5.13.0-beta1:
  * New feature release
  * For more details about Qt 5.13 please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.13.0/?h=5.13
  * Qt headers redefine opengl types differently than khronos headers
    (bsc#1176130)
- Remove patches, now upstream:
  * qapplication-emit-palettechanged.patch
  * reproducible-qrc-time.patch
- Refresh Mesa multithreading whitelist revert:
  * Drop 0001-Revert-Blacklist-nouveau-and-llvmpipe-for-multithrea.patch
  * Refresh 0002-Revert-qtlite-Fix-build-libs-with-no-feature-regular.patch
- libQt5XcbQpa is not static, move it to libQt5Gui-private-headers-devel
* Thu Mar 14 2019 fabian@ritter-vogt.de
- Update to 5.12.2:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.12.2/?h=5.12.2
- Replace 0001-Revert-White-list-more-recent-Mesa-version-for-multi.patch with
  * 0001-Revert-Blacklist-nouveau-and-llvmpipe-for-multithrea.patch
  * 0002-Revert-qtlite-Fix-build-libs-with-no-feature-regular.patch
  * 0003-Revert-White-list-more-recent-Mesa-version-for-multi.patch
- Remove 0002-Revert-QImage-merge-the-size-calculations-with-prope.patch,
  fixed upstream
* Tue Feb 12 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Clean %%install a bit
- Use %%license
- Add patch to fix crashes with nouveau (QTBUG-73715):
  * 0001-Revert-White-list-more-recent-Mesa-version-for-multi.patch
- Add patch to fix apparent memory leaks (QTBUG-73731):
  * 0002-Revert-QImage-merge-the-size-calculations-with-prope.patch
* Mon Feb  4 2019 wbauer@tmo.at
- Refresh tell-the-truth-about-private-api.patch to apply cleanly
* Fri Feb  1 2019 fabian@ritter-vogt.de
- Update to 5.12.1:
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.12.1/?h=v5.12.1
- xkbcommon not bundled anymore, removed now obsolete option
- Refresh patches:
  * 0001-Add-remote-print-queue-support.patch
  * 0001-Fix-qfloat16-methods-definition-without-declaration-.patch
- Drop patches, now upstream:
  * 0001-Fix-compile-issue-with-gcc-9.patch
* Wed Jan 30 2019 alarrosa@suse.com
- Add 0001-Fix-compile-issue-with-gcc-9.patch to fix building with
  the latest libstdc++ (boo#1121561)
* Fri Jan 18 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Remove workaround patch as fixed in KWin meanwhile:
  * 0001-Revert-xcb-Initialize-OpenGL-integration-only-when-r.patch
* Thu Jan 17 2019 Karl Cheng <qantas94heavy@gmail.com>
- Add 0001-Revert-xcb-Initialize-OpenGL-integration-only-when-r.patch:
  * Revert upstream commit 60cecc86f8 to work around display
    flickering issues with some display drivers
    (https://bugreports.qt.io/browse/QTBUG-73122, boo#1120090)
* Mon Jan  7 2019 bwiedemann@suse.com
- Add reproducible-qrc-time.patch to use SOURCE_DATE_EPOCH
  for qrc embedded timestamps to make bitcoin-qt build reproducible
  (https://bugreports.qt.io/browse/QTBUG-62511, boo#1047218)
* Thu Dec 20 2018 Antonio Larrosa <alarrosa@suse.com>
- Add 0001-Fix-qfloat16-methods-definition-without-declaration-.patch
  (a slightly different version of workaround-qdoc-failure.patch in
  libqt5-qtdoc, which was submitted upstream to fix libqt5-qtdoc
  building also when qt modules other than qtbase include qfloat16.h
  from the system qtbase package (boo#1092425, qtbug#72725)
* Wed Dec 19 2018 Todd R <toddrme2178@gmail.com>
- Use upstream-recommended %%{_rpmconfigdir}/macros.d directory
  for the rpm macros.
* Thu Dec  6 2018 fabian@ritter-vogt.de
- Update to 5.12.0:
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.12.0/?h=v5.12.0
* Mon Dec  3 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc2:
  * New bugfix release
  * Only important bugfixes
- Changelog for Qt 5.12.0:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.12.0/?h=5.12.0
- Remove patches, now upstream:
  * 0001-Fix-build-with-OpenSSL-1.1.0.patch
* Tue Nov 27 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Remove uikit qmake spec to avoid automatic dep on python2
* Thu Nov 22 2018 fabian@ritter-vogt.de
- Update to 5.12.0-rc:
  * New bugfix release
  * No changelog available
- Add patch to fix build with OpenSSL 1.1.0:
  * 0001-Fix-build-with-OpenSSL-1.1.0.patch
* Thu Nov  8 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta4:
  * New bugfix release
  * No changelog available
- Remove patches, now upstream:
  * 0001-xcb-Don-t-get-initial-screen-rotation.patch
* Fri Oct 26 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta3:
  * New bugfix release
  * No changelog available
- Refresh 0001-Sanitize-QXcbScreen-s-pixelDensity-values.patch
* Wed Oct 17 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta2:
  * New bugfix release
  * No changelog available
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Update to 5.12.0-beta1:
  * New bugfix release
  * No changelog available
- Remove patches, now upstream:
  * Export-qt_open64-from-QtCore.patch
* Tue Oct  2 2018 fabian@ritter-vogt.de
- Update to 5.12.0-alpha:
  * New feature release
  * For more details please see:
  * http://wiki.qt.io/New_Features_in_Qt_5.12
- Refresh patches:
  * 0001-Add-remote-print-queue-support.patch
  * 0001-xcb-Don-t-get-initial-screen-rotation.patch
- Remove patches, now upstream:
  * 0001-Hack-together-a-way-to-get-fallback-from-xcb-working.patch
  * 0001-Unix-print-dialog-Properly-initialize-duplex.patch
- Rename -platformtheme-flatpak to platformtheme-xdgdesktopportal
- Adjust libQt5PrintSupport-private-headers-devel Requires
* Thu Sep 27 2018 mischa.salle@gmail.com
- Add patch to fix boo#1096328, printer settings not remembered:
  * 0001-Unix-print-dialog-Properly-initialize-duplex.patch
* Wed Sep 26 2018 fabian@ritter-vogt.de
- Add patch to avoid lag on startup with the modesetting driver on
  intel (QTBUG-70760):
  * 0001-xcb-Don-t-get-initial-screen-rotation.patch
* Fri Sep 21 2018 fabian@ritter-vogt.de
- Update to 5.11.2
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.11.2/?h=v5.11.2
- Refresh patches:
  * 0002-xcb-Use-the-screen-s-physical-DPI-as-logical-DPI-unl.patch
  * tell-the-truth-about-private-api.patch
- Remove patches, now upstream:
  * 0001-Fix-qmake-build-with-glibc-2.28.patch
- Add patch to fix build on 32-bit:
  * Export-qt_open64-from-QtCore.patch
* Tue Sep 11 2018 schwab@suse.de
- 0001-Fix-qmake-build-with-glibc-2.28.patch: Fix qmake build with glibc 2.28
* Mon Aug 27 2018 fabian@ritter-vogt.de
- Pass CFLAGS and CXXFLAGS to configure explicitly to ensure that
  they are used
* Fri Jun 29 2018 fabian@ritter-vogt.de
- Revert upstream commit to avoid regressions (kde#395988):
  * 0001-Revert-QWidgetWindow-Immediately-forward-close-event.patch
* Sat Jun 23 2018 fabian@ritter-vogt.de
- Add patches to improve OOTB experience with HiDPI (boo#1089932):
  * 0001-Sanitize-QXcbScreen-s-pixelDensity-values.patch
  * 0002-xcb-Use-the-screen-s-physical-DPI-as-logical-DPI-unl.patch
* Tue Jun 19 2018 fabian@ritter-vogt.de
- Update to 5.11.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.11.1/?h=v5.11.1
- Drop patches, now upstream:
  * force-cmake-private-headers.patch
  * 0001-sqlite-Allow-for-duplicated-placeholders-with-just-o.patch
  * xcb-fix-regression-with-remote-X11-clients.patch
* Wed Jun 13 2018 fabian@ritter-vogt.de
- Add patch allow fallback from the xcb platform to others (QTBUG-68859):
  * 0001-Hack-together-a-way-to-get-fallback-from-xcb-working.patch
- Use "xcb;wayland" as default platform plugin list
* Tue Jun 12 2018 wbauer@tmo.at
- Add patch to fix running Qt applications via ssh (boo#1096806,
  boo#1097227):
  * xcb-fix-regression-with-remote-X11-clients.patch
* Thu May 24 2018 fabian@ritter-vogt.de
- Add patch to fix yet another sqlite named placeholder issue:
  * 0001-sqlite-Allow-for-duplicated-placeholders-with-just-o.patch
* Tue May 22 2018 fabian@ritter-vogt.de
- Update to 5.11.0
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.11.0/?h=v5.11.0
- Remove patches, now upstream:
  * 0001-Do-a-static_cast-in-bit-blasts-that-are-UB.patch
  * 0001-sqlite-Check-that-there-are-values-to-be-set-when-bi.patch
  * 0002-sqlite-Bind-duplicated-named-placeholders-correctly.patch
  * 0003-sqlite-Prevent-a-crash-when-sqlite-does-not-detect-a.patch
- Includes fix to prevent crash with pixmap cursors on XRender-less
  X servers (bsc#1108889, QTBUG-66935)
- Includes fix to load libGL.so.1 library if there's no libGL.so symlink
  (boo#1099874, QTBUG-67537)
- Includes fix to allow to disable logging of XCB errors (boo#1115541,
  QTBUG-55167)
* Tue May  8 2018 fabian@ritter-vogt.de
- Update to 5.11.0-rc
  * New bugfix release
  * No changelog available
* Fri Apr 27 2018 fabian@ritter-vogt.de
- Add patches to fix crashes with certain sqlite queries:
  * 0001-sqlite-Check-that-there-are-values-to-be-set-when-bi.patch
  * 0002-sqlite-Bind-duplicated-named-placeholders-correctly.patch
  * 0003-sqlite-Prevent-a-crash-when-sqlite-does-not-detect-a.patch
* Mon Apr 23 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta4
  * New bugfix release
  * No changelog available
- Refresh patches:
  * force-cmake-private-headers.patch
- Remove patches, now upstream:
  * 0001-Extend-the-MariaDB-define-check-to-cover-the-later-v.patch
* Wed Apr 11 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta3
  * New bugfix release
  * No changelog available
* Wed Mar 28 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta2
  * New bugfix release
  * No changelog available
* Tue Mar 27 2018 fabian@ritter-vogt.de
- Add patch to fix build with GCC 8 (boo#1087073):
  * 0001-Do-a-static_cast-in-bit-blasts-that-are-UB.patch
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Fri Mar  9 2018 crrodriguez@opensuse.org
- Further review of build dependencies:
  * pcre-devel is not required, only pcre2-devel, Remove
    from buildrequires
  * add explicit buildrequires on pkgconfig(libdrm) and
    pkgconfig(pango)
  * sources do not use libtiff-devel at all, remove from
    buildrequires
* Thu Mar  8 2018 crrodriguez@opensuse.org
- Replace xorg-x11-devel for a long list of individual
  pkgconfig() buildrequires
* Thu Mar  1 2018 alarrosa@suse.com
- Rework 0001-Add-remote-print-queue-support.patch so now the remote
  print queue discovery is disabled by default and is only enabled when
  the QT_ENABLE_PRINTER_DISCOVERY environment variable is set
  (QT_DISABLE_PRINTER_DISCOVERY is no longer used) (fixes boo#1064872)
* Thu Mar  1 2018 fabian@ritter-vogt.de
- Update to 5.11.0-beta1
  * New feature release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.11.0-beta1/?h=v5.11.0-beta1
- Remove patches, now upstream:
  * libqt5-do-not-use-shm-if-display-name-doesnt-look-local.patch
  * opengl-Bail-if-cached-shader-fails-to-load.patch
  * 0001-Revert-QHeaderView-properly-restore-section-data-aft.patch
  * 0002-Revert-QHeaderView-Simplify-and-fix-layoutChange-han.patch
* Fri Feb 23 2018 fabian@ritter-vogt.de
- Enable journald support (boo#1050461)
* Tue Feb 20 2018 fabian@ritter-vogt.de
- Update to 5.11.0-alpha
  * New feature release
  * For more details please see:
  * https://wiki.qt.io/New_Features_in_Qt_5.11
- Refresh patches:
  * 0001-Add-remote-print-queue-support.patch
  * 0001-Revert-QHeaderView-properly-restore-section-data-aft.patch
- Remove patches, now upstream:
  * 0001-QSimpleDrag-Fix-mouse-release-coords-for-delayed-eve.patch
  * 0001-Remove-QPrintDialogPrivate-applyPrinterProperties-no.patch
  * 0002-CUPS-Use-default-cups-job-priority-instead-of-50.patch
  * 0002-Remove-QUnixPrintWidgetPrivate-applyPrinterPropertie.patch
  * 0003-QPageSetupWidget-setPrinter-Use-printdevice-default-paper-size.patch
  * 0003-Remove-QPrintPropertiesDialog-applyPrinterProperties.patch
  * 0004-Fix-custom-page-size-handling-in-the-Unix-print-dial.patch
  * 0004-Remove-QCupsJobWidget-setPrinter.patch
  * 0005-CUPS-Refactor-the-code-a-bit.patch
  * 0005-Remove-QPrintPropertiesDialog-selectPrinter.patch
  * 0006-Refactor-QPPDOptionsModel-a-bit.patch
  * 0006-Remove-QPageSetupWidget-selectPrinter.patch
  * 0007-CUPS-Fix-advanced-options-cancel-of-the-print-properties-dialog.patch
  * 0007-Introduce-QPrintDevice-property-setProperty.patch
  * 0008-Allow-access-to-ppd-file-and-ppdMarkOption-via-QPpdP.patch
  * 0008-CUPS-Fix-conflict-handling.patch
  * 0009-CUPS-Use-printer-job-sheets-as-default-instead-of-none-none.patch
  * 0009-QPlatformPrintDevice-use-QVector-not-QList-in-the-AP.patch
  * 0010-CUPS-Use-printer-job-billing-as-default-instead-of-the-empty-string.patch
  * 0010-Reintroduce-the-Advanced-tab-in-the-QPrintProperties.patch
  * 0011-CUPS-Use-printer-job-hold-until-as-default-instead-of-the-nohold.patch
  * 0011-QtPrintSupport-Fix-build.patch
  * 0012-Unix-Fix-usability-of-the-print-properties-dialog.patch
  * 0013-cups-Dont-show-InstallableOptions-in-the-advanced-properties-tab.patch
  * 0014-CUPS-Enable-printing-arbitrary-pages-and-page-ranges.patch
  * 0015-CUPS-Dont-show-choices-that-conflict-with-the-printer-installed-options.patch
  * 0016-CUPS-Rework-set-clearCupsOption-API.patch
  * 0017-Cups-Print-Dialog-Change-the-message-box-titles-to-C.patch
  * 0018-Fix-build-due-to-missing-QDebug-include.patch
* Mon Feb 19 2018 fabian@ritter-vogt.de
- Revert upstream commits to make saving of header sections work again:
  * 0001-Revert-QHeaderView-properly-restore-section-data-aft.patch
  * 0002-Revert-QHeaderView-Simplify-and-fix-layoutChange-han.patch
* Wed Feb 14 2018 fabian@ritter-vogt.de
- Update to 5.10.1
  * New bugfix release
  * For more details please see:
  * http://code.qt.io/cgit/qt/qtbase.git/plain/dist/changes-5.10.1/?h=v5.10.1
- Drop patches, now upstream:
  * 0001-xcb-verify-if-xrandr-present-before-using-xcb_randr-.patch
  * 0001-Avoid-providing-bad-pixelDeltas-on-X11.patch
- Refresh patches:
  * 0001-Extend-the-MariaDB-define-check-to-cover-the-later-v.patch
  * 0003-Remove-QPrintPropertiesDialog-applyPrinterProperties.patch
  * 0004-Remove-QCupsJobWidget-setPrinter.patch
  * 0005-Remove-QPrintPropertiesDialog-selectPrinter.patch
  * 0006-Remove-QPageSetupWidget-selectPrinter.patch
  * 0003-QPageSetupWidget-setPrinter-Use-printdevice-default-paper-size.patch
  * 0004-Fix-custom-page-size-handling-in-the-Unix-print-dial.patch
  * 0011-CUPS-Use-printer-job-hold-until-as-default-instead-of-the-nohold.patch
  * 0012-Unix-Fix-usability-of-the-print-properties-dialog.patch
* Mon Feb 12 2018 mstaudt@suse.com
- Add opengl-Bail-if-cached-shader-fails-to-load.patch:
  Fixing broken OpenGL rendering with cached shaders.
  This is especially systems with Mesa 18.0.0 or newer.
  Many thanks to Michal Srb and Fabian Vogt for hunting this down.
  This was truly a joint effort.
  Fixes boo#1080578 and all duplicates of boo#1079465.
* Mon Feb 12 2018 fvogt@suse.com
- Add -force-debug-info to also generate debug info in release builds
  (boo#1080551)
* Thu Feb  8 2018 fabian@ritter-vogt.de
- Add patch to fix plugin loading with newer MariaDB versions (boo#1080048):
  * 0001-Extend-the-MariaDB-define-check-to-cover-the-later-v.patch
* Fri Feb  2 2018 alarrosa@suse.com
- Add 0001-QSimpleDrag-Fix-mouse-release-coords-for-delayed-eve.patch
  to fix a bug causing the wrong desktop icon to look hovered
  after dragging an icon on the desktop in plasma (QTBUG-66103, boo#1080044).
* Fri Jan 26 2018 alarrosa@suse.com
- Moved 0001-Avoid-providing-bad-pixelDeltas-on-X11.patch to use a patch
  number in the 1000-1999 range  since it was approved in the 5.9 branch
  upstream.
* Fri Jan 26 2018 alarrosa@suse.com
- Add 0001-Avoid-providing-bad-pixelDeltas-on-X11.patch to avoid using
  the hardcoded resolution that libinput is giving as a real pixel
  delta (QTBUG-59261).
* Thu Jan 25 2018 alarrosa@suse.com
- Add patches to fix the custom page size handling in the print dialog as
  well as other printer issues (QTBUG-58733, boo#994809):
  * 0002-CUPS-Use-default-cups-job-priority-instead-of-50.patch
  * 0003-QPageSetupWidget-setPrinter-Use-printdevice-default-paper-size.patch
  * 0004-Fix-custom-page-size-handling-in-the-Unix-print-dial.patch
  * 0005-CUPS-Refactor-the-code-a-bit.patch
  * 0006-Refactor-QPPDOptionsModel-a-bit.patch
  * 0007-CUPS-Fix-advanced-options-cancel-of-the-print-properties-dialog.patch
  * 0008-CUPS-Fix-conflict-handling.patch
  * 0009-CUPS-Use-printer-job-sheets-as-default-instead-of-none-none.patch
  * 0010-CUPS-Use-printer-job-billing-as-default-instead-of-the-empty-string.patch
  * 0011-CUPS-Use-printer-job-hold-until-as-default-instead-of-the-nohold.patch
  * 0012-Unix-Fix-usability-of-the-print-properties-dialog.patch
  * 0013-cups-Dont-show-InstallableOptions-in-the-advanced-properties-tab.patch
  * 0014-CUPS-Enable-printing-arbitrary-pages-and-page-ranges.patch
  * 0015-CUPS-Dont-show-choices-that-conflict-with-the-printer-installed-options.patch
  * 0016-CUPS-Rework-set-clearCupsOption-API.patch
  * 0017-Cups-Print-Dialog-Change-the-message-box-titles-to-C.patch
  * 0018-Fix-build-due-to-missing-QDebug-include.patch
- Dropped 0001-Fix-custom-page-size-handling-in-the-Unix-print-dial.patch
  which is now included in the previous patchset with order 0004.
* Fri Dec 29 2017 fabian@ritter-vogt.de
- Add patch to fix crash if X RanR is not present (boo#1073572):
  * 0001-xcb-verify-if-xrandr-present-before-using-xcb_randr-.patch
* Wed Dec 20 2017 alarrosa@suse.com
- Add 0001-Fix-custom-page-size-handling-in-the-Unix-print-dial.patch
  to fix custom page size handling in the Unix print dialog (QTBUG-58733)
* Fri Dec 15 2017 alarrosa@suse.com
- Add patches from upstream to reintroduce the advanced tab in
  the Qt printer properties dialog:
  0001-Remove-QPrintDialogPrivate-applyPrinterProperties-no.patch
  0002-Remove-QUnixPrintWidgetPrivate-applyPrinterPropertie.patch
  0003-Remove-QPrintPropertiesDialog-applyPrinterProperties.patch
  0004-Remove-QCupsJobWidget-setPrinter.patch
  0005-Remove-QPrintPropertiesDialog-selectPrinter.patch
  0006-Remove-QPageSetupWidget-selectPrinter.patch
  0007-Introduce-QPrintDevice-property-setProperty.patch
  0008-Allow-access-to-ppd-file-and-ppdMarkOption-via-QPpdP.patch
  0009-QPlatformPrintDevice-use-QVector-not-QList-in-the-AP.patch
  0010-Reintroduce-the-Advanced-tab-in-the-QPrintProperties.patch
  0011-QtPrintSupport-Fix-build.patch
- Small change in 0001-Add-remote-print-queue-support.patch so
  0007-Allow-access-to-ppd-file-and-ppdMarkOption-via-QPpdP.patch
  applies cleanly.
* Fri Dec  8 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Dec  7 2017 fabian@ritter-vogt.de
- Update to 5.10.0 final
  * New bugfix release
* Sun Dec  3 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 2
  * New bugfix release
* Thu Nov 30 2017 fabian@ritter-vogt.de
- Update to 5.10.0 RC 1
  * New bugfix release
- Refresh tell-the-truth-about-private-api.patch
* Sat Nov 25 2017 fabian@ritter-vogt.de
- Update to 5.9.3
  * New bugfix release
  * For more details, see:
    http://code.qt.io/cgit/qt/qtbase.git/tree/dist/changes-5.9.3/?h=v5.9.3
- Drop patches, now upstream:
  * qglxconvenience-avoid-null-pointer-deref.patch
* Wed Nov 15 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 4
- Contains bugfixes
- Refresh tell-the-truth-about-private-api.patch
* Thu Nov  2 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 3
- Contains bugfixes
- Remove patches, now upstream:
  * 0001-Cups-Check-the-created-QPrintDevice-is-valid-before-.patch
* Mon Oct 30 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 2
- Contains bugfixes
- Remove patches, now upstream:
  * qglxconvenience-avoid-null-pointer-deref.patch
* Fri Oct 27 2017 fabian@ritter-vogt.de
- Update 0001-QSslSocket-OpenSSL-1.1-backend.patch from git
* Tue Oct 24 2017 fabian@ritter-vogt.de
- Add patch to potentially fix printing:
  * 0001-Cups-Check-the-created-QPrintDevice-is-valid-before-.patch
* Mon Oct  9 2017 fabian@ritter-vogt.de
- Update to 5.10 Beta 1
- For more information visit:
    https://blog.qt.io/blog/2017/10/09/qt-5-10-beta-released/
* Sun Oct  8 2017 lbeltrame@kde.org
- Update to 5.9.2
  * For more details please see:
  https://blog.qt.io/blog/2017/10/06/qt-5-9-2-released/
- Drop patches, now upstream:
  * 0001-Fix-open-chmod-race-condition-in-QSaveFile.patch
  * de63bbd2f806b0219a60775017899cedb121581f.patch
  * 0001-Fix-at-spi2-build.patch
  * 0001-Fix-Qt5DBusMacros.cmake-for-CMake-3.9.patch
  * dont-abort-missing-display.patch
* Fri Sep 29 2017 jengelh@inai.de
- Update package descriptions and grouping.
- Use find -exec's "+" strategy
* Mon Sep 25 2017 fabian@ritter-vogt.de
- Update to 5.10 Alpha 1:
  * Qt Core
    + Added rudimentary implementation of QStringView. It is missing some (important) const-QString functions, but is fully functional as an interface type. To be completed for Qt 5.11.
    + Added many more functions to QLatin1String, too, co-evolving QLatin1String as the const char*-Latin-1-version of QStringView.
    + Added QIODevice::skip() to improve performance in read operations.
    + Explicitly little and big-endian integer types exposed (for instance qint16_le, quint32_be) for machine-independent data-type parsing.
    + Added QRandomGenerator providing a simple API for high-quality (optionally seed-less) random numbers.
    + Added accessors for metadata time fields of files to QFileInfo.
    + Added QSemaphoreReleaser a RAII-style class for QSemaphore.
    + Added QKeyValueIterator for more efficient iteration over keys of an associative container
  * Qt GUI
    + Added cross-platform Vulkan enablers for Windows, Linux (xcb) and Android (level 23+): QVulkanInstance, QWindow with type VulkanSurface, and QVulkanWindow
    + Added new flags and functions to QSurfaceFormat and QOpenGLWidget to request sRGB-capable default/backing framebuffers
    + The OpenGL ES 3.2 API is now exposed in a cross-platform manner via QOpenGLExtraFunctions.
    + QImages can now use more than 2GByte of pixel data.
    + Added QFont::PreferNoShaping style strategy.
  * Qt Widgets
    + QWidget::createWindowContainer() is now functional on Android
    + QOpenGLWidget is now usable for rendering and reading back (grabbing) offscreen content.
    + Added AA_DisableWindowContextHelpButton attribute that prevents the automatic" What's this" button on dialogs on Windows
    + Added tabStopDistance property in QTextOption, QTextEdit and QPlainTextEdit
    + Added selectionEnd(), selectionLength() to QLineEdit, complementing selectionStart()
    + Added setDoubleStep to QInputDialog, to enable changing of the step amount for getDouble()
    + Added isPersistentEditorOpen() to QAbstractItemView, QTreeWidget, QTableWidget and QListWidget
    + Added new style hint: SH_TitleBar_ShowToolTipsOnButtons
    + Added support for specifying custom internal texture formats in QOpenGLWidget
    + QDockWidget acquired the ability to be dropped together side by side
  * Qt Network
    + OpenSSL 1.1 back-end.
    + Persistent store of HSTS policies in QNAM (QSettings-based).
    + Implemented the h2c procotol upgrade used by non-SSL HTTP/2.
- For more information visit:
    https://blog.qt.io/blog/2017/09/13/qt-5-10-alpha-released/
- Remove patches, now upstream:
  * de63bbd2f806b0219a60775017899cedb121581f.patch
  * 0001-Fix-Qt5DBusMacros.cmake-for-CMake-3.9.patch
  * 0001-QSslSocket-OpenSSL-1.1-backend.patch
  * 0001-Fix-open-chmod-race-condition-in-QSaveFile.patch
  * 0001-Fix-at-spi2-build.patch
  * dont-abort-missing-display.patch
- Refresh qglxconvenience-avoid-null-pointer-deref.patch
- Build against pcre2
- Enable EGLFS with GBM, SCTP, Vulkan
* Wed Sep 13 2017 fabian@ritter-vogt.de
- Add patch to fix crash with XLIB_SKIP_ARGB_VISUALS set:
  * qglxconvenience-avoid-null-pointer-deref.patch (boo#1057971, kde#384540)
* Thu Aug 31 2017 christophe@krop.fr
- Add 0001-Fix-Qt5DBusMacros.cmake-for-CMake-3.9.patch.
  Fixes a race condition when building KMail due to the DBus
  interface files being used in several places.
* Tue Aug 29 2017 fabian@ritter-vogt.de
- Add patch to fix runtime changes to the palette:
  * qapplication-emit-palettechanged.patch
* Thu Aug 24 2017 mlin@suse.com
- Backport patch from dev to 5.9 what implements a new QSslSocket
  backend based on OpenSSL 1.1. (bsc#1042658)
  * 0001-QSslSocket-OpenSSL-1.1-backend.patch
* Wed Aug  9 2017 matz@suse.com
- Don't special case sse2 libs on i586 for SLE-15, it supports
  only SSE2 capable CPUs.
* Thu Aug  3 2017 mlin@suse.com
- Remove openSUSE specific %%ifs (bsc#1051900)
* Tue Jul 25 2017 fabian@ritter-vogt.de
- Add patch to not abort if no $DISPLAY is available (boo#1050046)
  * dont-abort-missing-display.patch
* Mon Jul 24 2017 fabian@ritter-vogt.de
- Add patch to fix include path for private headers of modules
  built in a shadow directory (QTBUG-37417)
  * force-cmake-private-headers.patch
* Wed Jul  5 2017 fabian@ritter-vogt.de
- Recommend libqt5-qttranslations in libQt5Core5 (boo#1027925)
* Sun Jul  2 2017 fabian@ritter-vogt.de
- Fix typo in description (boo#1043338)
* Sat Jul  1 2017 lbeltrame@kde.org
- Update to 5.9.1
  * For more details please see:
    http://blog.qt.io/blog/2017/06/30/qt-5-9-1-released/
- Drop upstreamed patches:
  - fix-cmake-module-version.patch
  - dont-destroy-foreign-windows.patch
  - native-children-hidpi-offset.patch
- Force use of libproxy, that switch got lost apparently
- Add patch to allow build with at-spi2: 0001-Fix-at-spi2-build.patch
* Thu Jun 22 2017 fabian@ritter-vogt.de
- Use the correct (edited) version of the revert to not break ABI:
  * de63bbd2f806b0219a60775017899cedb121581f.patch
* Tue Jun 20 2017 fabian@ritter-vogt.de
- Add upstream patch to fix version string of CMake modules (boo#1045102)
  * fix-cmake-module-version.patch
* Tue Jun  6 2017 alarrosa@suse.com
- Add 0001-Add-remote-print-queue-support.patch to support remote print
  queues. This adds a delay the first time the print dialog is opened in
  order to search for print queues. If you don't have any network printer
  queue and you find the delay too annoying, it can be disabled by setting
  the QT_DISABLE_PRINTER_DISCOVERY environment variable to 1 (fate#322052,
  bsc#955432).
- Add 0001-Fix-open-chmod-race-condition-in-QSaveFile.patch to fix
  a potential info leak due to race condition in QSaveFile (bsc#1034005).
* Fri Jun  2 2017 fabian@ritter-vogt.de
- Revert upstream commit to workaround QTBUG-61197:
  * de63bbd2f806b0219a60775017899cedb121581f.patch
* Fri Jun  2 2017 fabian@ritter-vogt.de
- Add upstream patch to fix QTBUG-61140:
  * dont-destroy-foreign-windows.patch
- Replaces c585802e946d97e7d177ea334a162dc7bc286b84.patch
* Fri Jun  2 2017 fabian@ritter-vogt.de
- Add upstream patch to fix various HiDPI-related issues:
  * native-children-hidpi-offset.patch (QTBUG-59017, kde#363548)
* Wed May 31 2017 fabian@ritter-vogt.de
- Revert upstream commit to workaround QTBUG-61140:
  c585802e946d97e7d177ea334a162dc7bc286b84.patch
* Wed May 31 2017 fabian@ritter-vogt.de
- Update to 5.9.0 final
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 5.9.0 RC:
  * For more details please see:
    http://lists.qt-project.org/pipermail/announce/2017-May/000115.html
    and https://wiki.qt.io/New_Features_in_Qt_5.9
- Remove patches, now upstream:
  * Stop-unloading-plugins-in-QPluginLoader-and-QFactoryLoader.patch
  * Fix-some-QtDBus-crashes-during-application-destruction.patch
  * Merge-the-QDBusMetaTypes-custom-information-to-QDBusConnectionManager.patch
- Refresh patches:
  * Fix-some-QtDBus-crashes-during-application-destruction.patch
  * Merge-the-QDBusMetaTypes-custom-information-to-QDBusConnectionManager.patch
  * libqt5-prioritise-gtk2-platformtheme.patch
  * tell-the-truth-about-private-api.patch
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Update to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
- Drop upstreamed patches:
  xcb-Dont-activate-bypassed-windows-on-mouse-press.patch,
  Fix-unwanted-cache-flush-in-Freetype-engine.patch,
  xcb-Send-also-text-plain-when-a-text-uri-list-is-dropped.patch,
  xcb-Dont-send-QtWindowNoState-event-when-hiding-minimized-window.patch,
  XCB-Drop-from-external-app-fix-keyboard-modifier-state.patch,
  xcb-Use-the-state-of-the-key-event-to-process-it.patch,
  Make-QDBusConnectionPrivaterelaySignal-be-called-in-the-right-thread.patch
  and use-freetype-default.patch
* Sun Oct  9 2016 sor.alexei@meowr.ru
- Add libqt5-prioritise-gtk2-platformtheme.patch: Give
  Gtk2 Platform Theme (from qtstyleplugins) a priority over
  Gtk3 Platform Theme which currently lacks QGtk3Style
  (boo#1002900).
* Sun Oct  9 2016 hrvoje.senjan@gmail.com
- Add some QtDBus fixes from upstream:
  Make-QDBusConnectionPrivaterelaySignal-be-called-in-the-right-thread.patch
  Merge-the-QDBusMetaTypes-custom-information-to-QDBusConnectionManager.patch
  Fix-some-QtDBus-crashes-during-application-destruction.patch
* Thu Sep 29 2016 hrvoje.senjan@gmail.com
- Move gtk platformtheme again out of the libQt5Gui5 package (now
  it's gtk-3 based)
* Tue Sep 27 2016 schwab@suse.de
- Fix filelist for %%gles configuration
* Tue Sep 27 2016 hrvoje.senjan@gmail.com
- Added Stop-unloading-plugins-in-QPluginLoader-and-QFactoryLoader.patch
  (boo#1001362, boo#965653)
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * For more details please see:
    https://www.qt.io/qt5-7/
- Drop dead/absorbed patches:
  xcb-Fix-drop-of-text-uri-list-and-text-html.patch and
  xcb-Fix-dropping-URL-on-Firefox-window.patch
- Added Fix-unwanted-cache-flush-in-Freetype-engine.patch
  and xcb-Dont-activate-bypassed-windows-on-mouse-press.patch
- Don't pass axed options to configure
- Add double-conversion-devel, libproxy-devel and pkgconfig(gtk+-3.0)
  (instead of pkgconfig(gtk+-2.0)) BuildRequires
* Sat Sep 24 2016 hrvoje.senjan@gmail.com
- Another set of upstream patches for the XCB plugin:
  XCB-Drop-from-external-app-fix-keyboard-modifier-state.patch
  xcb-Dont-send-QtWindowNoState-event-when-hiding-minimized-window.patch
  xcb-Use-the-state-of-the-key-event-to-process-it.patch
* Sat Jul  2 2016 hrvoje.senjan@gmail.com
- Add drag-and-drop fixes from upstream:
  xcb-Fix-drop-of-text-uri-list-and-text-html.patch
  xcb-Fix-dropping-URL-on-Firefox-window.patch
  xcb-Send-also-text-plain-when-a-text-uri-list-is-dropped.patch
* Wed Jun  8 2016 hrvoje.senjan@gmail.com
- Update to 5.6.1
  * For more details please see:
    http://blog.qt.io/blog/2016/06/08/qt-5-6-1-released/
- Drop upstreamed patches:
  0005-xcb-Properly-initialize-available-geometry-when-XRan.patch
  Fix-QtDBus-deadlock-inside-kded-kiod.patch
  0007-xcb-Deliver-mouse-enter-event-to-window-when-closing.patch
  0009-Expose-the-number-of-X-screen-through-the-QXcbScreen.patch
  0001-xcb-XInput2-fixes-enter-leave-event-fixes.patch
  0002-xcb-Correct-enter-leave-event-handling-when-mouse-bu.patch
  0015-Use-the-state-of-the-key-event-to-process-it.patch
  0012-xcb-Merge-_NET_WM_STATE-hints-instead-of-overwriting.patch
  0004-xcb-Fix-drag-and-drop-between-xcb-screens.patch
  QtDBus-finish-all-pending-call-with-error-if-disconnected.patch
  0010-xcb-mark-mouse-events-from-tablet-devices-as-synthes.patch
  0011-xcb-Initialize-all-xcb_client_message_event_t-member.patch
  0008-xcb-resourceType-names-must-have-only-small-letters.patch
  0016-xcb-Fix-drag-and-drop-to-applications-like-Emacs-and.patch
  0013-xcb-Fix-interpretation-of-the-size-from-RRCrtcChange.patch
  0006-xcb-properly-initialize-size-in-millimeters-if-XRand.patch
  0003-xcb-Fix-not-delivering-focusIn-event-on-hide-show.patch
  QtDBus-clean-up-signal-hooks-and-object-tree-in-closeConnection.patch
  0014-xcb-Properly-process-enter-leave-events.patch
* Sat Apr 23 2016 hrvoje.senjan@gmail.com
- Add patches from upstream:
  0001-xcb-XInput2-fixes-enter-leave-event-fixes.patch
  0002-xcb-Correct-enter-leave-event-handling-when-mouse-bu.patch
  0003-xcb-Fix-not-delivering-focusIn-event-on-hide-show.patch
  0004-xcb-Fix-drag-and-drop-between-xcb-screens.patch
  0005-xcb-Properly-initialize-available-geometry-when-XRan.patch
  0006-xcb-properly-initialize-size-in-millimeters-if-XRand.patch
  0007-xcb-Deliver-mouse-enter-event-to-window-when-closing.patch
  0008-xcb-resourceType-names-must-have-only-small-letters.patch
  0009-Expose-the-number-of-X-screen-through-the-QXcbScreen.patch
  0010-xcb-mark-mouse-events-from-tablet-devices-as-synthes.patch
  0011-xcb-Initialize-all-xcb_client_message_event_t-member.patch
  0012-xcb-Merge-_NET_WM_STATE-hints-instead-of-overwriting.patch
  0013-xcb-Fix-interpretation-of-the-size-from-RRCrtcChange.patch
  0014-xcb-Properly-process-enter-leave-events.patch
  0015-Use-the-state-of-the-key-event-to-process-it.patch
  0016-xcb-Fix-drag-and-drop-to-applications-like-Emacs-and.patch
* Fri Mar 18 2016 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * For more details please see:
    http://blog.qt.io/blog/2016/03/16/qt-5-6-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.6
- Added patches for various QtDBus issues:
  Fix-QtDBus-deadlock-inside-kded-kiod.patch,
  QtDBus-clean-up-signal-hooks-and-object-tree-in-closeConnection.patch
  and QtDBus-finish-all-pending-call-with-error-if-disconnected.patch
- Added tell-the-truth-about-private-api.patch: mark private and QPA API
  with symbols for only current patch release
- Drop obsolete and/or upstreamed patches:
  xcb-fix-yet-another-crash-when-screens-are-disconnected.patch,
  xcb-dont-crash-in-mapToNativemapFromNative-if-the-screen-is-null.patch,
  qtwidgets_do_not-hide_show_via_WA_OutsideWSRange_for_native_widgets.patch,
  protect-geometry-QTBUG-40584.patch,
  move-the-official-Qt-version-from-qglobal-to-qmake-conf.patch,
  QMimeDatabase-follow-symlinks-when-checking-for-FIFO.patch,
  Fix-QtCore-compilation-with-clang.patch,
  Add-option-to-disable-session-management-by-closing-windows.patch,
  Add-an-automatic-use-of-the-ELF-versioned-QtCore-symbol.patch,
  Add-a-qt_version_tag-symbol-to-QtCore-that-uses-ELF-versions.patch,
  Add-a-linker-version-script-to-Qt-libraries.patch,
  0005-Restore-documented-behavior-for-the-WA_X11NetWmWindo.patch,
  0001-Fix-exclusion-of-anonymous-ciphers.patch and
  0001-Fix-QWidget-setWindowRole.patch
* Wed Mar  9 2016 mlin@suse.com
- Merge libqt5-qtbase-platformtheme-gtk2 back into libQt5Gui5 (bsc#969935)
  * align with old libQt5Gui5 where libqgtk2.so has provided
* Sun Feb 21 2016 wbauer@tmo.at
- Added QMimeDatabase-follow-symlinks-when-checking-for-FIFO.patch
  to fix dolphin freeze when opening a folder containing symlinks
  to special files (boo#957006, qtbug#48529)
* Sat Feb 20 2016 hrvoje.senjan@gmail.com
- Update Add-option-to-disable-session-management-by-closing-windows.patch
  to version actually commited upstream
* Wed Feb 10 2016 alarrosa@suse.com
- Added 0001-Fix-exclusion-of-anonymous-ciphers.patch from upstream
  to disable exp-adh and aecdh ciphers.
- Added disable-rc4-ciphers-bnc865241.diff to disable RC4 based ciphers
  which are now considered insecure (bnc#865241)
* Sat Jan 30 2016 hrvoje.senjan@gmail.com
- Added Add-option-to-disable-session-management-by-closing-windows.patch
  API adition to QSessionManager as first step in resolving
  kde#354724 and boo#955280
* Wed Oct 28 2015 hrvoje.senjan@gmail.com
- Added qtwidgets_do_not-hide_show_via_WA_OutsideWSRange_for_native_widgets.patch
  (qtbug#48321)
* Fri Oct 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.1 (boo#954149)
  * For more details please see:
    http://blog.qt.io/blog/2015/10/15/qt-5-5-1-released/
- Drop patches merged upstream:
  0002-xcb-Fix-getting-the-window-types-from-the-property-o.patch
  0003-Fix-centering-dialogs.patch
  0004-xcb-Set-_NET_WM_WINDOW_TYPE-from-a-single-place.patch
  0006-xcb-set-SM_CLIENT_ID-property.patch
  Fix-compile-error-on-big-endian.patch
  Fix-shortcuts-with-keypad-keys.patch
  QDate_QTime-fix-SiC-introduced-by-adding-new-non-explicit-ctors.patch
  QMimeDatabase-use-QElapsedTimer.patch
  ignore-disabling-of-outputs-in-the-middle-of-the-mode-switch.patch
  when-a-screen-comes-back-online-the-windows-need-to-be-told-about-it.patch
- Added Fix-QtCore-compilation-with-clang.patch and
  move-the-official-Qt-version-from-qglobal-to-qmake-conf.patch in
  order to remove link-time warnings (warning: type and size of dynamic
  symbol `qt_version_tag@@Qt_5.5' are not defined)
* Mon Oct 12 2015 hrvoje.senjan@gmail.com
- Added xcb-dont-crash-in-mapToNativemapFromNative-if-the-screen-is-null.patch
  and xcb-fix-yet-another-crash-when-screens-are-disconnected.patch
  (kde#341497, qtbug#47385)
* Fri Oct  9 2015 hrvoje.senjan@gmail.com
- Added QDate_QTime-fix-SiC-introduced-by-adding-new-non-explicit-ctors.patch
* Wed Oct  7 2015 alarrosa@suse.com
- When in SLE12, use the internal Harfbuzz version instead of the system
  one (which is too old for Qt's requirements)
* Sun Sep 27 2015 schwab@suse.de
- Fix-compile-error-on-big-endian.patch: Fix compile error on big endian
* Tue Aug 18 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  ignore-disabling-of-outputs-in-the-middle-of-the-mode-switch.patch
  (qtbug#44158, qtbug#46786, qtbug#46822)
  when-a-screen-comes-back-online-the-windows-need-to-be-told-about-it.patch
  (qtbug#47041)
* Sun Aug 16 2015 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * For more details please see:
    http://blog.qt.io/blog/2015/07/01/qt-5-5-released/
    and https://wiki.qt.io/New_Features_in_Qt_5.5
- Drop patches merged upstream:
  0001-Speed-up-compose-file-parsing-in-the-X11-composition.patch,
  0002-Speed-up-application-startup-on-X11.patch,
  Fix-regression-in-compose-table-parsing.patch,
  libqt5-libtool-nodate.diff and
  make-qdbusxml2cpp-output-reproducible.patch
- Add patches from upstream:
  Add-a-linker-version-script-to-Qt-libraries.patch,
  Add-a-qt_version_tag-symbol-to-QtCore-that-uses-ELF-versions.patch
  and Add-an-automatic-use-of-the-ELF-versioned-QtCore-symbol.patch
- Added tslib-devel and libinput-devel (Build)Requires
- Drop all openSUSE 13.1 conditionals, we won't build Qt >= 5.5 on
  that distro version anymore
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update QMimeDatabase-use-QElapsedTimer.patch to latest version
* Tue Jul 28 2015 hrvoje.senjan@gmail.com
- Added QMimeDatabase-use-QElapsedTimer.patch: reduces the number
  of syscalls greatly, by avoiding the timezone conversion every time;
  massively improves kbuildsycoca5 speed
* Sun Jul 26 2015 hrvoje.senjan@gmail.com
- Fix the suse_version condition checks - treat Leap equally as 13.2
  wrt which system libs shall be used
* Tue Jun  9 2015 hrvoje.senjan@gmail.com
- Add patches from upstream:
  0001-Fix-QWidget-setWindowRole.patch
  0002-xcb-Fix-getting-the-window-types-from-the-property-o.patch
  0003-Fix-centering-dialogs.patch
  0004-xcb-Set-_NET_WM_WINDOW_TYPE-from-a-single-place.patch
  0005-Restore-documented-behavior-for-the-WA_X11NetWmWindo.patch
  0006-xcb-set-SM_CLIENT_ID-property.patch
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 5.4.2
  * Important Behavior Changes:
  - EXIF orientation is no longer applied to JPEG images on read.
    EXIF orientation on JPEG was introduced in 5.4.0, but due to
    a bug the most common EXIF-format (big-endian) was not working
    until 5.4.1. 5.4.2 restores the behavior of 5.4.0 and earlier
    for most EXIF-tagged JPEGs.
    EXIF orientation will be an opt-in starting with Qt 5.5.
  - On x86 and x86-64 systems with ELF binaries (especially Linux),
    due to a new optimization in GCC 5.x in combination with a recent
    version of GNU binutils, compiling Qt applications with -fPIE
    is no longer enough with GCC 5.x. Applications now need to be
    compiled with the -fPIC option if Qt's option "reduce relocations"
    is active. For backward compatibility only, Qt accepts the use
    of -fPIE for GCC 4.x versions.
    Note that Clang is known to generate incompatible code even
    with -fPIC if the -flto option is active.
    Applications using qmake or cmake >= 2.8.12 as their build
    system will adapt automatically. Applications using an older
    release of cmake in combination with GCC 5.x need to change
    their CMakeLists.txt to add Qt5Core_EXECUTABLE_COMPILE_FLAGS
    to CMAKE_CXX_FLAGS. In particular, applications using
    cmake >= 2.8.9 and < 2.8.11 will continue to build   with the
  - fPIE option and invoke the special compatibility mode
    if using GCC 4.x.
  * Bugfix release, for more details please see:
    http://blog.qt.io/blog/2015/06/02/qt-5-4-2-released/
- Drop patches merged upstream:
  Call-ofono-nm-Registered-delayed-in-constructor-othe.patch
  Fix-Meta-shortcuts-on-XCB.patch
  Fix-upload-corruptions-when-server-closes-connection.patch
  Fixed-a-deadlock-when-the-lock-file-is-corrupted.patch
  Handle-SelectionWindowDestroy-in-QXcbClipboard.patch
  Make-qglobal.h-complain-if-you-use-fPIE.patch
  Make-sure-theres-a-scene-before-using-it.patch
  QSystemTrayIcon-handle-submenus-correctly.patch
  Require-fPIC-instead-of-just-fPIE-for-reduce-relocations.patch
  Try-to-ensure-that-fPIC-is-used-in-CMake-builds.patch
  Update-mouse-buttons-from-MotionNotify-events.patch
  fix-a-division-by-zero-when-processing-malformed-BMP-files.patch
- Added cmake (Build)Requires to get autoprovides for all Qt modules
* Mon May 18 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  Try-to-ensure-that-fPIC-is-used-in-CMake-builds.patch,
  Require-fPIC-instead-of-just-fPIE-for-reduce-relocations.patch
  and Make-qglobal.h-complain-if-you-use-fPIE.patch
  (qtbug#45755)
* Sat May 16 2015 hrvoje.senjan@gmail.com
- Add Fix-shortcuts-with-keypad-keys.patch
  (qtbug#20191,qtbug#33093,kde#344638)
* Tue May  5 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  Fix-upload-corruptions-when-server-closes-connection.patch and
  Fixed-a-deadlock-when-the-lock-file-is-corrupted.patch (qtbug#44771)
* Sat Apr 25 2015 hrvoje.senjan@gmail.com
- Fixup previous change to also handle arguments in specs using %%qmake5
- Also add QMAKE_LFLAGS to the macro
* Fri Apr 24 2015 joerg.lorenzen@ki.tng.de
- Added QMAKE_CXXFLAGS and QMAKE_CFLAGS to macro %%qmake5.
* Wed Apr 15 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Speed-up-compose-file-parsing-in-the-X11-composition.patch
  0002-Speed-up-application-startup-on-X11.patch and
  Fix-regression-in-compose-table-parsing.patch
* Thu Apr  9 2015 hrvoje.senjan@gmail.com
- Add cleaning of QMAKE_PRL_BUILD_DIR from prl files in
  %%qmake5_install macro
* Fri Feb 27 2015 hrvoje.senjan@gmail.com
-  Added fix-a-division-by-zero-when-processing-malformed-BMP-files.patch,
  CVE-2015-0295
* Tue Feb 24 2015 hrvoje.senjan@gmail.com
- Update to 5.4.1:
  * Important Behavior Changes:
  * Restored binary compatibility with Qt 5.3.2 on Windows when
    using MSVC 2012 or MSVC 2013. This means that Qt 5.4.1 is no
    longer binary compatible with Qt 5.4.0 when using either of
    those compilers.
  * [QTBUG-42594] OS X binary package: fixed incorrect linking
    to libraries in /opt/local/lib
  * Library:
  * QtCore:
  * [QTBUG-43893] Fixed memory leak in qSetMessagePattern
  * [QTBUG-43513] QXmlStreamReader: Correctly parse XML
    containing NUL bytes in the input stream
  * [QTBUG-43352] QTemporaryDirectory: Properly clean up in
    case of a failure
  * [QTBUG-43827] Fixed regression in QSortFilterProxyModel
    which crashed when sorting a tree model
  * QtGui:
  * [QTBUG-44273] Fixed misplacement of outlined text with
    native text rendering
  * [QTBUG-44147] Fixed VNC not working on some VNC servers
  * [QTBUG-43850] Fixed crash with multi-threaded font usage
  * [QTBUG-43850] Made the old harfbuzz fallback available
    at runtime
  * Improvements to the experimental high-dpi support
  * [QTBUG-43318] Better resolving of GLES3 functions to
    avoid issues when deploying on systems with GLES 2.0 only
  * QtWidgets:
  * [QTBUG-43830] Fixed crash in stylesheets when
    styling QProgressBar
  * [QTBUG-43663] QColorDialog: Don't lose focus while
    color picking
  * QtNetwork:
  * [QTBUG-43793] Fixed disconnections of QSSLSocket after
    starting encryption
  * QtSql:
  * [QTBUG-36211] qpsql: Added timezone support for
    datetime fields.
  * qodbc: Fixed converted string values on Microsoft SQL
    Server 2012
  * [QTBUG-43874] QSqlQuery: Fixed failure of multiple
    execBatch() calls after  a single prepare() call
  * QtPrintSupport:
  * [QTBUG-43124] Fixed QPrinter::{width,height} return values
  * Platform Specific Changes:
  * Linux/XCB:
  * [QTBUG-43436] Fixed regression when drag and drop to
    other applications
  * [QTBUG-43809] Turned off font hinting when doing
    high DPI scaling
  * [QTBUG-43743] Fixed constantly resizing bigger window when
    devicePixelRatio is greater than 1
  * [QTBUG-43713] Fixed problems with multiple screens with
    different device pixel ratios regarding window mapping
    and font sizes.
  * [QTBUG-43688] Fixed physical DPI and size for
    rotated screens on X11
  * [QTBUG-43049] Fixed grabKeyboard and grabMouse
  * [QTBUG-36862] Now sends a leave event to the other window
    when a popup shows which grabs the input
  * [QTBUG-41590] Turned off subpixel gamma-correction on XCB
  * Added support for SelectionClientClose in QXcbClipboard
  * Fixed -nograb and -dograb arguments
  * [QTBUG-43623] Fixed use after free
  * [QTBUG-43436] Fixed regression in DnD. Make sure to preserve
    the QDrag until all data has been received.
  * Tools:
  * configure & build system:
  * configure will now reject invalid -no-feature-* options.
  * pkg-config assisted libudev detection was fixed.
  * [QTBUG-43302][Android] The Android style is included
    when cross-building on Windows as well.
  * [QTBUG-43205][Unix] Fixed build D-Bus headers cannot be found.
  * qmake:
  * [QTBUG-39690][Windows] Fixed file separators in 'make clean'.
  * [QTBUG-40264][Unix] Fixed 'make distclean' for a dynamic
    library target.
  * [QTBUG-42678] 'make distclean' now removes .qmake.{stash|super}.
  * [QTBUG-43026][VS2010+] Fixed compilation of .rc files.
  * [QTBUG-43457][MSVC] Fixed QMAKE_TARGET.arch for
    amd64_x86 x-build.
  * INCLUDEPATH+=. is now unnecessary with all generators.
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-5-4-1-released/
- Drop merged or obsolete patches:
  qmake-add-usr-include.diff, QTBUG41590.patch,
  Handle-SelectionClientClose-in-QXcbClipboard.patch,
  qimage_conversions.cpp-Fix-build-on-big-endian-syste.patch,
  Fix-use-after-free-bug.patch, fix-drag-and-drop-regression.patch,
  Fix-detection-of-GCC5.patch, Fix-typo-in-Qt5CoreMacroscmake.patch,
  Fix-physical-DPI-and-size-for-rotated-screens-on-X11.patch,
  X11-devicePixelRatio-screen-mapping-fix.patch,
  Multi-screen-DPI-support-for-X11.patch and
  xcb-Dont-return-0-from-QXcbKeyboard-possibleKeys.patch
- Added Handle-SelectionWindowDestroy-in-QXcbClipboard.patch and
  Call-ofono-nm-Registered-delayed-in-constructor-othe.patch from
  upstrean
- Make sure each lib requires equal version of other qtbase libs
  it needs (added filtering for shlib-fixed-dependency to rpmlintrc
  accordingly)
* Wed Feb 18 2015 hrvoje.senjan@gmail.com
- Added patches from upstream:
  Fix-Meta-shortcuts-on-XCB.patch (qtbug#43572),
  Fix-detection-of-GCC5.patch,
  Fix-physical-DPI-and-size-for-rotated-screens-on-X11.patch
  (qtbug#43688), Fix-typo-in-Qt5CoreMacroscmake.patch,
  Make-sure-theres-a-scene-before-using-it.patch (qtbug#44509),
  Multi-screen-DPI-support-for-X11.patch (qtbug#43713),
  QSystemTrayIcon-handle-submenus-correctly.patch,
  Update-mouse-buttons-from-MotionNotify-events.patch
  (qtbug#32609, qtbug#35065, qtbug#43776, qtbug#44166, qtbug#44231),
  X11-devicePixelRatio-screen-mapping-fix.patch (qtbug#43713) and
  xcb-Dont-return-0-from-QXcbKeyboard-possibleKeys.patch
  (qtcreatorbug#9589)
* Tue Feb  3 2015 hrvoje.senjan@gmail.com
- Fixed qt_instdate generation, so the Qt5Core library doesn't have
  DATE embedded
- Drop fdupes usage as it provides unpredictable results, and fools
  build-compare
- Add libqt5-qtbase-rpmlintrc due to duplicates waste warnings: we
  rather have a few bytes more than to republish same binaries due
  to fdupes
- Added make-qdbusxml2cpp-output-reproducible.patch: don't include
  date/time in the generated include guards; prevents unnecessary
  rebuilds
- Added fix-drag-and-drop-regression.patch from upstream,
  fixes QTBUG-43436
* Mon Jan 12 2015 hrvoje.senjan@gmail.com
- Added Fix-use-after-free-bug.patch from upstream
  (qtbug#43623, boo#870151)
* Thu Dec 25 2014 schwab@suse.de
- qimage_conversions.cpp-Fix-build-on-big-endian-syste.patch: Fix build on
  big endian systems
* Tue Dec 16 2014 hrvoje.senjan@gmail.com
- Don't override the shlib generator, but split gtk platformtheme
  into platformtheme-gtk2 subpackage, the former approach is creating
  problems with other dependant packages
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 5.4 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-5-4-released/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- Added Handle-SelectionClientClose-in-QXcbClipboard.patch, kde#329174
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 5.4 RC
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-5-4-release-candidate-available/
    and http://qt-project.org/wiki/New-Features-in-Qt-5.4
- New libQt5PlatformHeaders-devel subpackage
- Use one global define for gles on arm and aarch
- (Build)Require Mesa-libGLESv3-devel when building with gles
- Use system harfbuzz on 13.2 and newer
- Filter out requires obtained by dependency generators.
  gtk platformtheme now won't pull in gtk libraries, so users can
  have a gtk-free envirement if wanted. Those DE's that do need that
  platformplugin will already have gtk present
- Drop patches merged upstream:
  0001-Add-QFont-strategy-to-disable-subpixel-antialiasing.patch
  0001-Allow-panels-outside-of-availableGeometry.patch
  0001-QFileDialog-emit-urlsSelected-urlSelected-in-accept.patch
  0001-QKdeTheme-use-system-wide-kdeglobals-as-a-fallback.patch
  00010-Replace-the-const-QString-global-static-with-a-QStri.patch
  00011-Use-correct-signal-name-when-disconnecting.patch
  0002-Always-lock-the-DBus-dispatcher-before-dbus_connecti.patch
  0002-Move-SubpixelAntialiasingType-from-QFontEngineFT-to-.patch
  0002-QUrl-fromLocalFile-QString-should-lead-to-an-empty-U.patch
  0003-QDBusConnection-Merge-the-dispatch-and-the-watch-and.patch
  0003-QFileDialog-turn-workingDirectory-into-a-QUrl.patch
  0003-Support-autohint-and-lcdfilter-fontconfig-configurat.patch
  0004-GTK2-theme-should-use-GTK-configured-font-variant.patch
  0004-Partially-revert-Fix-a-deadlock-introduced-by-the-ra.patch
  0004-QFileDialog-implement-getOpenFileUrl-and-friends-for.patch
  f1ee10f81ac18789e9a7dc715b464415ba2bc2b8.patch
  libqt5-add-support-for-byte-swapping.patch
  libqt5-byte-order-byte-is-address0.patch
* Tue Nov 11 2014 hrvoje.senjan@gmail.com
- Update QTBUG41590.patch for commit that was pushed upstream
* Wed Nov  5 2014 hrvoje.senjan@gmail.com
- Added patches from upstream:
  0001-Allow-panels-outside-of-availableGeometry.patch (kde#339846)
  and 0002-Always-lock-the-DBus-dispatcher-before-dbus_connecti.patch,
  0003-QDBusConnection-Merge-the-dispatch-and-the-watch-and.patch,
  0004-Partially-revert-Fix-a-deadlock-introduced-by-the-ra.patch,
  for QTBUG#42189
* Wed Oct 29 2014 hrvoje.senjan@gmail.com
- Don't install CMake files for plugins, they are useful only for
  bundled Qt builds
- Downgrade sql-plugins from libQt5Sql-devel's requires to suggests
- Added QTBUG41590.patch, improve font rendering
  (QTBUG41590,QTBUG40971)
* Sun Oct 12 2014 hrvoje.senjan@gmail.com
- Added 0001-QFileDialog-emit-urlsSelected-urlSelected-in-accept.patch,
  0002-QUrl-fromLocalFile-QString-should-lead-to-an-empty-U.patch,
  0003-QFileDialog-turn-workingDirectory-into-a-QUrl.patch and
  0004-QFileDialog-implement-getOpenFileUrl-and-friends-for.patch
  from upstream to improve QFileDialog behaviour with both local
  and remote URL's
- Added 0001-QKdeTheme-use-system-wide-kdeglobals-as-a-fallback.patch:
  QTBUG-36184
- Added 0001-Add-QFont-strategy-to-disable-subpixel-antialiasing.patch,
  0002-Move-SubpixelAntialiasingType-from-QFontEngineFT-to-.patch,
  0003-Support-autohint-and-lcdfilter-fontconfig-configurat.patch
  and 0004-GTK2-theme-should-use-GTK-configured-font-variant.patch
  QTBUG-40396, QTBUG-32254, QTBUG-39643
* Wed Sep 24 2014 mlin@suse.com
- Add libqt5-do-not-use-shm-if-display-name-doesnt-look-local.patch
  from Michal Srb, bnc#888858
  * additional check the display name before use SHM, this patch is
    equivalent to what has been did in Qt4:
    https://qt.gitorious.org/qt/qt/source/6a7f06d70e1267d3d995a3c863ba8f748d45e531:src/gui/kernel/qapplication_x11.cpp#L1986
* Mon Sep 22 2014 hrvoje.senjan@gmail.com
- Build without sse2 instructions by default for %%ix86 architecture,
  and rebuild QtCore and QtuGui modules with sse2 (they are installed
  to %%_libdir/sse2 (bnc#897758)
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2 final
  * No changes since previous snapshot
  * Use official tars
* Thu Sep  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2~git20140904 (r05670f5):
  * Tip of the bugfix 5.3.2 branch:
  * Recreate child windows when changing screens
  * QCoreTextFontDatabase: Remove number type asserts.
  * QGLXContext survives screen removal
  * CoreWLan: terminate scan thread in QCoreWlanEngine destructor
  * Also print the class name in the QObject::killTimer error msg
  * Initialize textureId in platform backing store
  * Doc: corrected autolink errors corelib io
  * Avoid crash if querying device that has gone away
  * Doc: corrected autolink errors Qjsonvalue
  * Network: Fix NTLM (SSPI) with HTTP and HTTPS proxies
  * remove always ask option.
  * Fix handling QT_IM_MODULE=none
  * xcb: use keyboard event source window to determine
    auto-repeat valuen
  * Fix invalid memcpy(dst, src) calls where dst == src
  * Fix several regressions in font selection
  * Detect wrongly labelled wheel buttons
  * Make QWindowContainer handle drag'n'drop
  * Resize correctly on orientation change.
  * Use correct size in fullscreen mode
  * Properly null-terminate ifreq::irf_name
  * fingerpaint example: be sensitive to pressure only
    when supported
  * Fix a memory leak in QFseventsFileSystemWatcherEngine
  * Do not set QMAKE_{INC,LIB}DIR_{OPENGL,X11} in the
    freebsd mkspecs.
  * refactor disconnectFromFtp to remove cached entries
    when necessary
  * Remove reference to gdb_dwarf_index from the
    freebsd-clang mkspec.
  * Fix mistake in function extraTryFontsForFamily
  * Fix rendering of fonts matched based on stretch
  * Fix x86/32-bit build when using an old version of gcc
  * Fix selection of fonts based on styleName
  * QFusionStyle paints sliders outside of clip
  * Set iMX device specific compiler flags to QMAKE_CFLAGS
  * Fix QPainter::drawPolyline() painting errors with
    cosmetic pen
  * Let QImage::mirrored() retain dots-per-meter settings
  * Make sure we don't cache old file sizes prior to new writes
  * Correct the SYNC hint for the release barrier
  * Fix QT_NO_REGULAREXPRESSION build
  * Fix QT_NO_ANIMATION build
  * Fix build with QT_NO_MDIAREA
  * Show the correct cursor for QLineEdit's side buttons.
  * Fix disconnect()ing from signals declared in a base class
  * Fix rendering alpha-blended text which needs to be
    clipped at the top.
  * Fix build due to missing include when using a minimal config.
  * Fix build with QT_NO_DRAGANDDROP
  * Font Database: Add support for private, system UI
    font families
  * Apply upstream patch r1498 to our PCRE copy
  * Apply upstream patch r1495 to our PCRE copy
  * Initialize member.
  * Document missing QLatin1String methods
  * network tests: add manual test for auth / proxy auth
  * Uncomment some tests which accidently got commented
  * Both HiQualAA and normal AA should mean
    antialiasing in rasterengine.
  * Check if Start/EndPage returns non-positive value
    when error checking
  * GTK file dialog: pre-fill the filename if given to a
    Save dialog
  * QFileDialog docs: remove misleading sentence about
    static functions
  * Doc: Placed Qt OpenGL class convention in code block.
  * Undo: Fix state entry bug for parallel state groups
  * Do not add QOffscreenSurface windows to the global list
  * tst_QHash: check which of several equal keys is inserted
  * OpenGL: destroy QGLContext allocated by
    QGLContext::fromOpenGLContext
  * tst_QSet: check which of several equal elements is inserted
  * fix paths in installed qtmain.prl
  * add /ENTRY:main only for target builds
  * avoid that CROSS_COMPILE affects host builds
  * Add missing power button keycode to keymap
  * Android: export ANDROID_SDK_BUILD_TOOLS_REVISION.
  * cocoa: Fix compiler warnings about unused functions.
  * Propagate swapInterval to QGLFormat
  * Fix double clicks in eglfs
  * Work around ICC bug in local static symbols for
    Q_GLOBAL_STATIC
  * QCoreTextFontDatabase: Fix font weight value when
    populating a family
  * Don't convert signed to unsigned when we need all 32bit
  * Fix compilation if EC is disabled in OpenSSL
  * Fix warning message when re-setting text on tooltip
  * Improve dbus cross compilation
  * Fix buffer overrun error with some proxy servers
  * QNAM: Fix CPU load for limited upload QIODevice
  * qmake: Document the "aux" template type.
  * Use the stateless UTF-8 encoder in QStringRef::toUtf8
  * Doc: corrected autolink errors in qnamespace.qdoc
  * QPixmap::fromImage() should detach when changing
    QImage format
  * generate QGL header file from qgl.h
  * Ensure transient parents are top level widgets.
  * Added stream version into network cache file format
  * make QtWidgets claim style plugins
  * CMake: Don't check the existence of GL files in the
    Qt5Gui package.
  * QSplitter: Exclude top level widgets from child
    event handling.
  * Doc: Hide QTextInlineObject constructor from
    the documentation
  * Work around ICC bug in brace initializations
    containing constexpr
  * Doc: edited qtxml.qdocconf
  * xcb: QTabletEvents and proximity events correctly
    identify the tool
  * Fixed wrong function name in a file snippet
  * XCB: Enable loading of the Qt::DragLinkCursor
  * Fix fallbacks for adapted common script
  * Fix fallbacks for adapted common script
  * QSslCertificate: blacklist NIC certificates from India
  * Doc: moved saxbookmarks example files
  * tst_qdir: Move QFINDTESTDATA() from init() to constructor.
  * Doc: moved streambookmarks example files
  * Don't assert when HB-old is unable to deal with surrogates
  * REG: Fix nbsp in QTextLayout
  * Support getting test data from qrc
  * Document QApplication::cursorFlashTime() can return -1
  * Fix for code snippet in commandlineparser documentation
  * Doc: removed trolltech.com from namespace in manual
    qdocconf file.
  * Fix typo in QGraphicsView documentation.
  * Fix QTimer with negative interval in
    QWidgetLineControl::setCursorBlinkPeriod
  * Attempt to work with Visual Studio in -Za (strict ANSI) mode
  * Improve QListWidget documentation.
  * Fix debug output of QTouchEvent.
  * Doc: fix a link in QAbstractOpenGLFunctions documentation
  * Accessibility Linux: Fix crashes when accessing
    invalid functions
  * move loading of testability driver from QApplication
    to QGuiApplication
  * QPdf::addImage(): avoid a QImage detach when it's in an
    acceptable Format
  * Make QDom/QXmlSimpleReader reentrant.
  * Move QXmlReaderPrivate to private header.
  * Mac: Don't register for Pan Gestures.
  * Add opt-out environment variable for @2x images
  * Listen to touch events on the master device instead of slave.
  * add support for device linux-arm-hisilicon-hix5hd2-g++
  * Make tst_QLocale::macDefaultLocale() more robust
  * Fix some tst_qwidget test cases
  * xcb: make sure to update window title when it is changed
  * Skip unstable autotests in QtBase.
  * Empty icons and Cocoa menu items.
  * Address Book example: Fix QTableView column sorting
  * QOpenGLTexture: fix the feature test for Buffer Textures
  * qDebug: fix data race in qt_message_print
  * [bcm97425] Fix parameter issue in platformDestroy hook
  * Doc: Various \note fixes in Qt namespace documentation.
  * Fix QFileInfoGatherer threading issue
  * Doc: Fix typo in QScopedValueRollback
  * Fix pixel noise in X11 systray icons that are not 22x22
  * Don't compare the target methods for SlotObject connections
  * qtoolbar: add missing header on OSX.
  * Remove bogus nullptr check for reference
  * Support MIPS atomic on pre-MIPS32 architectures
  * Enable sparc detection.
  * Remove -Wcast-align from QMAKE_CXXFLAGS.
  * Create the 64 bits version strings for MIPS, SPARC and S390
  * Add a comment stating QMutex::isRecursive should be made
    const in Qt6
  * Fix QMutex documentation saying some function are static
    while they are not
  * Delete qml_plugin_import.cpp file only during distclean
  * WinRT: no read-only paths in QStandardpaths::writableLocation
  * Fix compilation on Windows without precompiled headers
  * QColorDialog: Do not update custom/standard color cells
    while picking.
  * Fix -Werror compilation on big-endian
  * CMake: Allow modules to specify the location of tests.
  * Mark behavior of QFileInfo::absoluteFilePath as undefined in
    corner cases
  * Translate Super/Hyper keys to MetaModifier
  * Fix logging file location docs
  * CMake: Report an error if unit tests are not found for
    a module.
  * Fix QRingBuffer::readPointerAtPosition()
  * Make the fetchAndAddRelaxed function a member template
  * Doc: qInstallMessageHandler cannot return 0.
  * GIF decoding: do not seek() if the image is loaded
    over the network
  * network internals: do not try to cache a deleted entry
  * Fix memory leaks in QFseventsFileSystemWatcherEngine
  * Simplify mirroring code and add tests for non-aliged
    1 bit images
  * Add that the corner settings are saved/restored
    with the state
  * Correct grammar of missing Q_OBJECT macro warning.
  * Doc: Fix docs for QFontMetrics::height() to match code
  * Fix installation of private headers generated
    by wayland-scanner
  * add buildsystem/qmake changelog
  * CMake: Load plugin files unconditionally if present.
  * QIcon: Prefer high-quality images of Windows .ico files.
  * tst_qicon: Resolve all files using QFINDTESTDATA().
  * Move most of the QLibraryPrivate initialization to
    its constructor
  * QComboBox: update focus policy when setting a new line edit
  * QDBus: fix data race on isDebugging bool
  * When filling the path it should use the painter's pen
    not the state's
  * Fix data race on QLoggingCategory when using qDebug
    from multiple threads
  * Remove the use of QT_STATIC_CONST in QtSql
  * Fix compilation with /Zc:strictStrings
  * Correct QImage::fill(uint) on RGBA8888 formats
  * XCB: Fix leak with touch devices
  * pass a pointer instead of a reference to initFrom()
  * Properly check which OpenGL features are supported
  * Do not overwrite existing event mask of root window
  * Remove the widget from the stylesheet cache before polishing
  * QDnsLookup: Fix build with uClibc
  * Remove unused define XCB_USE_IBUS.
  * Attempt to fix intel compiler build error.
  * Use QModelIndex to get the data from underlying model
  * QGuiApplication: Document -plugin command line argument.
  * Fix compilation in under -no-c++11 mode
  * Fix compilation with the Intel compiler on certain systems
- Drop patches merged upstream:
  0001-Do-not-overwrite-existing-event-mask-of-root-window.patch,
  0002-Properly-check-which-OpenGL-features-are-supported.patch,
  0003-Fix-data-race-on-QLoggingCategory-when-using-qDebug-.patch,
  0004-QDBus-fix-data-race-on-isDebugging-bool.patch,
  0005-Translate-Super-Hyper-keys-to-MetaModifier.patch,
  libqt5-avoid-crash-during-querying-device.patch,
  libqt5-fix-leak-with-touch-devices-in-xcb.patch and
  libqt5-listen-to-touch-events-on-the-master-device.patch
- Added protect-geometry-QTBUG-40584.patch, to workaround QTBUG-40584,
  so widget geometry is preserved
- Reorder patches
* Fri Aug 29 2014 mlin@suse.com
- Added upstream patches for bnc#890168
  * libqt5-fix-leak-with-touch-devices-in-xcb.patch, QTBUG-39596
  * * fixed a leak what did not free m_touchDevices.
  * libqt5-listen-to-touch-events-on-the-master-device.patch, QTBUG-38625
  * * listen to touch events on the master device instead of slave, was also
    affects by fdo#78345
  * libqt5-avoid-crash-during-querying-device.patch, QTBUG-40820
  * * avoid crashes if querying device that has gone away
* Thu Jul  3 2014 hrvoje.senjan@gmail.com
- Added 00010-Replace-the-const-QString-global-static-with-a-QStri.patch,
  fixes segfaulting in global destructor, for more details see:
  http://mail.kde.org/pipermail/kde-frameworks-devel/2014-June/017086.html
- Added 00011-Use-correct-signal-name-when-disconnecting.patch,
  fixes crash on QtDBus unload
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
- Drop libqt5-fix-the-modal-dialogs-can-go-behind.patch, merged upstream
- Added patches from upstream:
  0001-Do-not-overwrite-existing-event-mask-of-root-window.patch -- QTBUG-39648
  0002-Properly-check-which-OpenGL-features-are-supported.patch -- QTBUG-39730
  0003-Fix-data-race-on-QLoggingCategory-when-using-qDebug-.patch -- Fix data race on QLoggingCategory
  0004-QDBus-fix-data-race-on-isDebugging-bool.patch -- fix data race on isDebugging bool
  0005-Translate-Super-Hyper-keys-to-MetaModifier.patch -- QTBUG-38428
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Improve baselibs
- Improve situation with rpmlints duplicates warnings
- Make private headers noarch
* Tue May 27 2014 hrvoje.senjan@gmail.com
- Build with pkgconfig(libudev), not pkgconfig(udev)
* Fri May 23 2014 mlin@suse.com
- Fix the modal dialogs can go behind other process windows (QTBUG-35302)
  * libqt5-fix-the-modal-dialogs-can-go-behind.patch
* Thu May 22 2014 tiwai@suse.de
- Fix broken Gujarati rendering (bnc#878292):
  libqt5-Fix-Gujarati-font.patch
* Wed May 21 2014 hrvoje.senjan@gmail.com
- Only enable reducing relocations on x86 and x86_64 arches; fixes
  build for arm, ppc, etc (QTBUG-36129)
* Mon May 19 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 final
  * Minor bugfixes over previous RC
* Sat May 17 2014 hrvoje.senjan@gmail.com
- Disable logging to journald for now, as it creates significant
  performance penalty
- Don't pass /usr/include to qmake, not needed
* Thu May  8 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 RC
  * For more details, please see
  http://blog.qt.digia.com/blog/2014/05/08/qt-5-3-release-candidate-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
- Drop libqt5-add-better-support-for-keymap-update-handling.patch,
  libqt5-fix-build-failure-xcb.patch,
  libqt5-fix-regression-in-key-handling.patch,
  libqt5-improve-keymap-error-handling.patch and
  libqt5-update-bundled-libxkbcommon-version-to-041.patch; merged upstream
* Tue Apr  8 2014 mlin@suse.com
- Add support for byte swapping, bnc#866709
  * Add libqt5-add-support-for-byte-swapping.patch
  * Add libqt5-byte-order-byte-is-address0.patch
- Fix keyboard remapping not applied on Qt5, bnc#866051
  * Add backported libqt5-add-better-support-for-keymap-update-handling.patch
  * Add backported libqt5-improve-keymap-error-handling.patch
  * Add backported libqt5-fix-build-failure-xcb.patch
  * Add backported libqt5-update-bundled-libxkbcommon-version-to-041.patch
  * Add backported libqt5-fix-regression-in-key-handling.patch
* Fri Mar 28 2014 hrvoje.senjan@gmail.com
- The no-neon switch no longer exists with 5.3, so drop it: fixes
  build on arm/aarch64
* Tue Mar 25 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0 beta
  * New feature release, please see
  http://blog.qt.digia.com/blog/2014/03/25/qt-5-3-beta-released/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.3
- Drop qtbase-qatomic-ppc.patch, merged upstream
- Added f1ee10f81ac18789e9a7dc715b464415ba2bc2b8.patch: prefer QPA
  implementation in qsystemtrayicon_x11 if available
- Added pkgconfig(libsystemd-journal) BuildRequires and activate
  journald support
- Added pkgconfig(xkbcommon-x11) BuildRequires with 13.2+: it's now
  needed for full xkb support, for lower version added xkeyboard-config
  BuildRequires
- Ommit QMAKE_STRIP flags in mkspecs/common/linux.conf, otherwise no
  debuginfo is generated for packages which use qmake buildsystem
- Droped passing of -javascript-jit, as per upstream changes
- Rebase libqt5-libtool-nodate.diff for this release
* Thu Mar 20 2014 hrvoje.senjan@gmail.com
- Added use-freetype-default.patch: allow using lcd-default filter
  regardless of how freetype2 library has been built (w/ & w/o subpixel)
- Build examples (added examples subpackage)
- Make sure that Qt5Gui devel package requires libdrm-devel, as it
  references it's includes in CMake config
* Sat Mar  1 2014 hrvoje.senjan@gmail.com
- Fix wrong libQt5OpenGLExtensions-devel-static requires:
  pkgconfig(GL) -> pkgconfig(gl)
* Thu Feb 27 2014 schwab@suse.de
- Enable jit only on supported archs
* Mon Feb 10 2014 mlin@suse.com
- Update LICENSE files to %%doc
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-5-2-1-released/
- Split out (private) devel packages for each library. Also added
  common-devel package, which contains mkspecs, and basic binaries
  (e.g. moc, qmake, rcc, syncqt and uic)
- Only create qt5 symlinks for binaries which conflict with
  Qt4 version
- Remove libtool archives from packages
- Apply conditionals for %%arm also for aarch64
- Removed unneeded or upstreamed patches:
  * 0001-Remove-the-GLES-2-dependency-for-eglfs-and-kms.patch
  * 0002-Fix-configure-script-to-not-dictate-OpenGL-ES-2-when.patch
  * 0003-EGL-convenience-deal-with-DefaultRenderableType-when.patch
  * 0004-Do-not-disable-egl-on-desktop-gl-automatically.patch
  * qt-never-strip.diff
  * qtbase-opensource-src-5.1.1-bigendian.patch
- modified patches:
  * qmake-add-usr-include.diff
* Fri Jan  3 2014 hrvoje.senjan@gmail.com
- Explicitly (Build)Require pkgconfig(harfbuzz) for 13.1+
- Explicitly activate system-harfbuzz, system-freetype and
  fontconfig options
- Drop clucene-core-devel and giflib-devel Build(Requires): unused
- Drop pkgconfig(atspi-2) (Build)Requires: external libatspi2 is not
  used during build time (see qtbase commit 4c1c820)
* Thu Dec 12 2013 uweigand@de.ibm.com
- Do not force -javascript-jit on ppc platforms that do not support it.
* Thu Dec 12 2013 hrvoje.senjan@gmail.com
- Update to 5.2.0 final:
  * For more details please see:
    http://blog.qt.digia.com/blog/2013/12/12/qt-5-2-released-the-best-qt-yet/
    http://qt-project.org/qt5/qt52
    http://qt.digia.com/Product/Whats-New/Qt-52/
* Wed Dec  4 2013 hrvoje.senjan@gmail.com
- Import patches from upstream which make possible to build EGL
  support without requiring GLES2:
  0001-Remove-the-GLES-2-dependency-for-eglfs-and-kms.patch
  0002-Fix-configure-script-to-not-dictate-OpenGL-ES-2-when.patch
  0003-EGL-convenience-deal-with-DefaultRenderableType-when.patch
  0004-Do-not-disable-egl-on-desktop-gl-automatically.patch
- Enable EGL support by adding (Build)Requiring pkgconfig(egl)
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 5.2 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-5-2-release-candidate-1-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
- Droped xcb_193.patch, included in this release
- Drop gstreamer-0_10-plugins-base-devel BuildRequires, nothing in
  qtbase uses gstreamer, and config tests where false positive before
- Temporary disable qt-never-strip.diff, we can use configure flags
  for no-strip
* Wed Nov 27 2013 hrvoje.senjan@gmail.com
- Added xcb_193.patch from upstream, for resolving SiC and BiC change
  in xcb 1.9.2/3 (fdo#71502,fdo#71507,qtbug#34748)
* Wed Nov  6 2013 hrvoje.senjan@gmail.com
- Fix translations macro
* Thu Oct 24 2013 hrvoje.senjan@gmail.com
- gstreamer-0_10-plugins-base-devel are not required for devel
  subpackage, so remove the Requires
* Wed Oct 23 2013 hrvoje.senjan@gmail.com
- Update to 5.2 beta1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/10/23/qt-5-2-beta-available/
  and http://qt-project.org/wiki/New-Features-in-Qt-5.2
- Change obsoletes of new library and sql plugins packages
* Fri Oct 18 2013 hrvoje.senjan@gmail.com
- Added qtbase-opensource-src-5.1.1-bigendian.patch, also needed
  for building on PowerPC, otherwise fromWordToBytes is
  left undeclared
* Fri Oct 18 2013 hrvoje.senjan@gmail.com
- Added qtbase-qatomic-ppc.patch, fixes PowerPC build
* Wed Oct 16 2013 hrvoje.senjan@gmail.com
- Further split libqt5-qtbase package to libQt5Concurrent5,
  libQt5Core5, libQt5DBus5, libQt5Network5, libQt5Xml5,
  libQt5PrintSupport5 and libQt5OpenGL5
- Rename sql plugin subpackages for more consistent naming with the
  rest of libraries
- Apply the same solution as with Qt4 with regards to rebuilds:
  don't use current build date, but rather last changes date
* Fri Oct  4 2013 hrvoje.senjan@gmail.com
- Add convenient macros for packages building against Qt5:
  %%_libqt5_qmake, %%qmake5, %%make_jobs and %%qmake5_install
* Thu Sep 12 2013 hrvoje.senjan@gmail.com
- Added missing pkgconfig(xkbcommon) BuildRequires
- Drop checks for older openSUSE versions
- Enable GL ES and kms only on arm for now
* Thu Sep  5 2013 duwe@suse.com
- enable support for opengl es2 and kms
* Thu Aug 29 2013 hrvoje.senjan@gmail.com
- Update to version 5.1.1:
  * Bugfix release, please see
  http://blog.qt.digia.com/blog/2013/08/28/qt-5-1-1-released/
  http://qt.gitorious.org/qt/qtbase/blobs/release/dist/changes-5.1.1
  and http://qt-project.org/wiki/Qt511KnownIssues for known issues
- Small spec cleanup
- Explicitly activate desktop openGL, and only BuildRequire
  pkgconfig(gl) so whole Mesa stack isn't pulled
* Sat Aug  3 2013 tittiatcoke@gmail.com
- Adjust packaging naming conform Factory standards
* Sun Jul  7 2013 hrvoje.senjan@gmail.com
- Allow co-existance of Qt5 and Qt4:
  * Install headers in %%_includedir/qt5
  * Install binaries in %%_libdir/qt5/bin, create symlinks with -qt5
    suffixes in %%_libdir/qt5/bin and %%_bindir
- Spec cleanup:
  * Removed checks for obsolete opensuse versions
- Add new macros.qt5, which should be utilized for other Qt5 modules
- Added baselibs.conf
* Sun Jul  7 2013 stephan.binner@basyskom.com
- update to Qt 5.1 release
* Tue Jun 18 2013 stephan.binner@basyskom.com
- update to Qt 5.1 RC 1
* Mon May 20 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Beta 1
* Tue Apr  9 2013 stephan.binner@basyskom.com
- update to Qt 5.1 Alpha 1
* Fri Mar 29 2013 stephan.binner@basyskom.com
- update to Qt 5.0.2 RC1
* Wed Jan 30 2013 stephan.binner@basyskom.com
- update to Qt 5.0.1
* Wed Dec 19 2012 stephan.binner@basyskom.com
- update to Qt 5.0 release
* Thu Dec 13 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 2
* Thu Dec  6 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Release Candidate 1
* Thu Nov 15 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 2
* Thu Aug 30 2012 stephan.binner@basyskom.com
- update to Qt 5.0 Beta 1 release
* Thu May 24 2012 stephan.binner@basyskom.com
- update to newer Alpha snapshot / Beta candidate
* Fri Apr 13 2012 stephan.binner@basyskom.com
- rework package splitting for Qt 5 modularization
* Thu Apr  5 2012 dmueller@suse.com
- Initial packaging (Qt 5.0 Alpha)
